@@ -47,7 +47,6 @@ import org.apache.iceberg.expressions.ExpressionVisitors;
 import org.apache.iceberg.expressions.UnboundPredicate;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.util.ByteBuffers;
-import org.assertj.core.api.Assertions;
 import org.objenesis.strategy.StdInstantiatorStrategy;
 
 public class TestHelpers {
@@ -110,9 +109,7 @@ public class TestHelpers {
   }
 
   public static void assertSameSchemaList(List<Schema> list1, List<Schema> list2) {
-    Assertions.assertThat(list1)
-        .as("Should have same number of schemas in both lists")
-        .hasSameSizeAs(list2);
+    assertThat(list1).as("Should have same number of schemas in both lists").hasSameSizeAs(list2);
 
     IntStream.range(0, list1.size())
         .forEach(
@@ -151,9 +148,7 @@ public class TestHelpers {
   }
 
   public static void assertSameSchemaMap(Map<Integer, Schema> map1, Map<Integer, Schema> map2) {
-    Assertions.assertThat(map1)
-        .as("Should have same number of schemas in both maps")
-        .hasSameSizeAs(map2);
+    assertThat(map1).as("Should have same number of schemas in both maps").hasSameSizeAs(map2);
 
     map1.forEach(
         (schemaId, schema1) -> {
