@@ -18,8 +18,9 @@
  */
 package org.apache.iceberg.util;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import java.time.ZonedDateTime;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 
 public class TestDateTimeUtil {
@@ -27,12 +28,11 @@ public class TestDateTimeUtil {
   @Test
   public void formatTimestampMillis() {
     String timestamp = "1970-01-01T00:00:00.001+00:00";
-    Assertions.assertThat(DateTimeUtil.formatTimestampMillis(1L)).isEqualTo(timestamp);
-    Assertions.assertThat(ZonedDateTime.parse(timestamp).toInstant().toEpochMilli()).isEqualTo(1L);
+    assertThat(DateTimeUtil.formatTimestampMillis(1L)).isEqualTo(timestamp);
+    assertThat(ZonedDateTime.parse(timestamp).toInstant().toEpochMilli()).isEqualTo(1L);
 
     timestamp = "1970-01-01T00:16:40+00:00";
-    Assertions.assertThat(DateTimeUtil.formatTimestampMillis(1000000L)).isEqualTo(timestamp);
-    Assertions.assertThat(ZonedDateTime.parse(timestamp).toInstant().toEpochMilli())
-        .isEqualTo(1000000L);
+    assertThat(DateTimeUtil.formatTimestampMillis(1000000L)).isEqualTo(timestamp);
+    assertThat(ZonedDateTime.parse(timestamp).toInstant().toEpochMilli()).isEqualTo(1000000L);
   }
 }
