@@ -19,6 +19,8 @@
 package org.apache.iceberg.aws.glue;
 
 import static org.apache.iceberg.expressions.Expressions.truncate;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
 import java.util.Locale;
@@ -49,9 +51,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.types.Types.NestedField;
 import org.apache.iceberg.util.LockManagers;
-import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import software.amazon.awssdk.services.glue.model.Column;
 import software.amazon.awssdk.services.glue.model.CreateTableRequest;
 import software.amazon.awssdk.services.glue.model.EntityNotFoundException;
@@ -76,51 +76,43 @@ public class TestGlueCatalogTable extends GlueTestBase {
     String tableDescription = "Test table";
     Map<String, String> tableProperties =
         ImmutableMap.<String, String>builder()
-            .putAll(tableLocationProperties)
+            .putAll(TABLE_LOCATION_PROPERTIES)
             .put(IcebergToGlueConverter.GLUE_DESCRIPTION_KEY, tableDescription)
             .build();
     glueCatalog.createTable(
         TableIdentifier.of(namespace, tableName), schema, partitionSpec, tableProperties);
     // verify table exists in Glue
     GetTableResponse response =
-        glue.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
-    Assert.assertEquals(namespace, response.table().databaseName());
-    Assert.assertEquals(tableName, response.table().name());
-    Assert.assertEquals(
-        BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE.toUpperCase(Locale.ENGLISH),
-        response.table().parameters().get(BaseMetastoreTableOperations.TABLE_TYPE_PROP));
-    Assert.assertTrue(
-        response
-            .table()
-            .parameters()
-            .containsKey(BaseMetastoreTableOperations.METADATA_LOCATION_PROP));
-    Assert.assertEquals(
-        schema.columns().size(), response.table().storageDescriptor().columns().size());
-    Assert.assertEquals(partitionSpec.fields().size(), response.table().partitionKeys().size());
-    Assert.assertEquals(
-        "additionalLocations should match",
-        tableLocationProperties.values().stream().sorted().collect(Collectors.toList()),
-        response.table().storageDescriptor().additionalLocations().stream()
-            .sorted()
-            .collect(Collectors.toList()));
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+    assertThat(response.table().databaseName()).isEqualTo(namespace);
+    assertThat(response.table().name()).isEqualTo(tableName);
+    assertThat(response.table().parameters())
+        .containsEntry(
+            BaseMetastoreTableOperations.TABLE_TYPE_PROP,
+            BaseMetastoreTableOperations.ICEBERG_TABLE_TYPE_VALUE.toUpperCase(Locale.ENGLISH))
+        .containsKey(BaseMetastoreTableOperations.METADATA_LOCATION_PROP);
+    assertThat(response.table().storageDescriptor().columns()).hasSameSizeAs(schema.columns());
+    assertThat(response.table().partitionKeys()).hasSameSizeAs(partitionSpec.fields());
+    assertThat(response.table().storageDescriptor().additionalLocations())
+        .containsExactlyInAnyOrderElementsOf(TABLE_LOCATION_PROPERTIES.values());
     // verify metadata file exists in S3
     String metaLocation =
         response.table().parameters().get(BaseMetastoreTableOperations.METADATA_LOCATION_PROP);
-    String key = metaLocation.split(testBucketName, -1)[1].substring(1);
-    s3.headObject(HeadObjectRequest.builder().bucket(testBucketName).key(key).build());
+    String key = metaLocation.split(TEST_BUCKET_NAME, -1)[1].substring(1);
+    S3.headObject(HeadObjectRequest.builder().bucket(TEST_BUCKET_NAME).key(key).build());
     Table table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
-    Assert.assertEquals(partitionSpec, table.spec());
-    Assert.assertEquals(schema.toString(), table.schema().toString());
-    Assert.assertEquals(
-        tableDescription, table.properties().get(IcebergToGlueConverter.GLUE_DESCRIPTION_KEY));
-    Assert.assertEquals(tableDescription, response.table().description());
+    assertThat(table.spec()).isEqualTo(partitionSpec);
+    assertThat(table.schema()).asString().isEqualTo(schema.toString());
+    assertThat(table.properties())
+        .containsEntry(IcebergToGlueConverter.GLUE_DESCRIPTION_KEY, tableDescription);
+    assertThat(response.table().description()).isEqualTo(tableDescription);
   }
 
   @Test
   public void testCreateTableDuplicate() {
     String namespace = createNamespace();
     String tableName = createTable(namespace);
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 glueCatalog.createTable(
                     TableIdentifier.of(namespace, tableName), schema, partitionSpec))
@@ -132,7 +124,7 @@ public class TestGlueCatalogTable extends GlueTestBase {
   @Test
   public void testCreateTableBadName() {
     String namespace = createNamespace();
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 glueCatalog.createTable(
                     TableIdentifier.of(namespace, "table-1"), schema, partitionSpec))
@@ -145,18 +137,18 @@ public class TestGlueCatalogTable extends GlueTestBase {
   public void testCreateAndLoadTableWithoutWarehouseLocation() {
     GlueCatalog glueCatalogWithoutWarehouse = new GlueCatalog();
     glueCatalogWithoutWarehouse.initialize(
-        catalogName,
+        CATALOG_NAME,
         null,
         new AwsProperties(),
         new S3FileIOProperties(),
-        glue,
+        GLUE,
         LockManagers.defaultLockManager(),
         ImmutableMap.of());
     String namespace = createNamespace();
     String tableName = getRandomName();
     TableIdentifier identifier = TableIdentifier.of(namespace, tableName);
     try {
-      glueCatalog.createTable(identifier, schema, partitionSpec, tableLocationProperties);
+      glueCatalog.createTable(identifier, schema, partitionSpec, TABLE_LOCATION_PROPERTIES);
       glueCatalog.loadTable(identifier);
     } catch (RuntimeException e) {
       throw new RuntimeException(
@@ -167,20 +159,17 @@ public class TestGlueCatalogTable extends GlueTestBase {
   @Test
   public void testListTables() {
     String namespace = createNamespace();
-    Assert.assertTrue(
-        "list namespace should have nothing before table creation",
-        glueCatalog.listTables(Namespace.of(namespace)).isEmpty());
+    assertThat(glueCatalog.listTables(Namespace.of(namespace))).isEmpty();
     String tableName = createTable(namespace);
     List<TableIdentifier> tables = glueCatalog.listTables(Namespace.of(namespace));
-    Assert.assertEquals(1, tables.size());
-    Assert.assertEquals(TableIdentifier.of(namespace, tableName), tables.get(0));
+    assertThat(tables).hasSize(1).first().isEqualTo(TableIdentifier.of(namespace, tableName));
   }
 
   @Test
   public void testTableExists() {
     String namespace = createNamespace();
     String tableName = createTable(namespace);
-    Assert.assertTrue(glueCatalog.tableExists(TableIdentifier.of(namespace, tableName)));
+    assertThat(glueCatalog.tableExists(TableIdentifier.of(namespace, tableName))).isTrue();
   }
 
   @Test
@@ -190,14 +179,16 @@ public class TestGlueCatalogTable extends GlueTestBase {
     // current should be null
     TableOperations ops = glueCatalog.newTableOps(TableIdentifier.of(namespace, tableName));
     TableMetadata current = ops.current();
-    Assert.assertNull(current);
+    assertThat(current).isNull();
     // create table, refresh should update
     createTable(namespace, tableName);
+    String description = "test description";
+    updateTableDescription(namespace, tableName, description);
     current = ops.refresh();
-    Assert.assertEquals(schema.toString(), current.schema().toString());
-    Assert.assertEquals(partitionSpec, current.spec());
+    assertThat(current.schema()).asString().isEqualTo(schema.toString());
+    assertThat(current.spec()).isEqualTo(partitionSpec);
     Table table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
-    Assert.assertTrue("initial table history should be empty", table.history().isEmpty());
+    assertThat(table.history()).isEmpty();
     // commit new version, should create a new snapshot
     table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
     DataFile dataFile =
@@ -208,15 +199,89 @@ public class TestGlueCatalogTable extends GlueTestBase {
             .build();
     table.newAppend().appendFile(dataFile).commit();
     table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
-    Assert.assertEquals("commit should create a new table version", 1, table.history().size());
+    assertThat(table.history()).hasSize(1);
     // check table in Glue
     GetTableResponse response =
-        glue.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
-    Assert.assertEquals(
-        "external table type is set after update", "EXTERNAL_TABLE", response.table().tableType());
-    Assert.assertEquals(
-        schema.columns().size(), response.table().storageDescriptor().columns().size());
-    Assert.assertEquals(partitionSpec.fields().size(), response.table().partitionKeys().size());
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+    assertThat(response.table().tableType())
+        .as("external table type is set after update")
+        .isEqualTo("EXTERNAL_TABLE");
+    assertThat(response.table().storageDescriptor().columns()).hasSameSizeAs(schema.columns());
+    assertThat(response.table().partitionKeys()).hasSameSizeAs(partitionSpec.fields());
+    assertThat(response.table().description()).isEqualTo(description);
+
+    String updatedComment = "test updated comment";
+    table
+        .updateProperties()
+        .set(IcebergToGlueConverter.GLUE_DESCRIPTION_KEY, updatedComment)
+        .commit();
+    // check table in Glue
+    response =
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+    assertThat(response.table().description()).isEqualTo(updatedComment);
+  }
+
+  @Test
+  public void testDropColumn() {
+    String namespace = createNamespace();
+    String tableName = createTable(namespace);
+    Table table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
+    table
+        .updateSchema()
+        .addColumn("c2", Types.StringType.get(), "updated from Iceberg API")
+        .addColumn("c3", Types.StringType.get())
+        .commit();
+
+    updateTableColumns(
+        namespace,
+        tableName,
+        column -> {
+          if (column.name().equals("c3")) {
+            return column.toBuilder().comment("updated from Glue API").build();
+          } else {
+            return column;
+          }
+        });
+
+    table.updateSchema().deleteColumn("c2").deleteColumn("c3").commit();
+
+    GetTableResponse response =
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+    List<Column> actualColumns = response.table().storageDescriptor().columns();
+
+    List<Column> expectedColumns =
+        ImmutableList.of(
+            Column.builder()
+                .name("c1")
+                .type("string")
+                .comment("c1")
+                .parameters(
+                    ImmutableMap.of(
+                        IcebergToGlueConverter.ICEBERG_FIELD_ID, "1",
+                        IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "false",
+                        IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "true"))
+                .build(),
+            Column.builder()
+                .name("c2")
+                .type("string")
+                .comment("updated from Iceberg API")
+                .parameters(
+                    ImmutableMap.of(
+                        IcebergToGlueConverter.ICEBERG_FIELD_ID, "2",
+                        IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "true",
+                        IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "false"))
+                .build(),
+            Column.builder()
+                .name("c3")
+                .type("string")
+                .comment("updated from Glue API")
+                .parameters(
+                    ImmutableMap.of(
+                        IcebergToGlueConverter.ICEBERG_FIELD_ID, "3",
+                        IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "true",
+                        IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "false"))
+                .build());
+    assertThat(actualColumns).isEqualTo(expectedColumns);
   }
 
   @Test
@@ -229,10 +294,10 @@ public class TestGlueCatalogTable extends GlueTestBase {
     glueCatalog.renameTable(
         TableIdentifier.of(namespace, tableName), TableIdentifier.of(namespace, newTableName));
     Table renamedTable = glueCatalog.loadTable(TableIdentifier.of(namespace, newTableName));
-    Assert.assertEquals(table.location(), renamedTable.location());
-    Assert.assertEquals(table.schema().toString(), renamedTable.schema().toString());
-    Assert.assertEquals(table.spec(), renamedTable.spec());
-    Assert.assertEquals(table.currentSnapshot(), renamedTable.currentSnapshot());
+    assertThat(renamedTable.location()).isEqualTo(table.location());
+    assertThat(renamedTable.schema()).asString().isEqualTo(table.schema().toString());
+    assertThat(renamedTable.spec()).isEqualTo(table.spec());
+    assertThat(renamedTable.currentSnapshot()).isEqualTo(table.currentSnapshot());
   }
 
   @Test
@@ -243,12 +308,12 @@ public class TestGlueCatalogTable extends GlueTestBase {
     Table table = glueCatalog.loadTable(id);
     // create a new table in Glue, so that rename to that table will fail
     String newTableName = tableName + "_2";
-    glue.createTable(
+    GLUE.createTable(
         CreateTableRequest.builder()
             .databaseName(namespace)
             .tableInput(TableInput.builder().name(newTableName).build())
             .build());
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 glueCatalog.renameTable(
                     TableIdentifier.of(namespace, tableName),
@@ -258,10 +323,10 @@ public class TestGlueCatalogTable extends GlueTestBase {
         .hasMessageContaining("Table already exists");
     // old table can still be read with same metadata
     Table oldTable = glueCatalog.loadTable(id);
-    Assert.assertEquals(table.location(), oldTable.location());
-    Assert.assertEquals(table.schema().toString(), oldTable.schema().toString());
-    Assert.assertEquals(table.spec(), oldTable.spec());
-    Assert.assertEquals(table.currentSnapshot(), oldTable.currentSnapshot());
+    assertThat(oldTable.location()).isEqualTo(table.location());
+    assertThat(oldTable.schema()).asString().isEqualTo(table.schema().toString());
+    assertThat(oldTable.spec()).isEqualTo(table.spec());
+    assertThat(oldTable.currentSnapshot()).isEqualTo(table.currentSnapshot());
   }
 
   @Test
@@ -272,12 +337,12 @@ public class TestGlueCatalogTable extends GlueTestBase {
     Table table = glueCatalog.loadTable(id);
     // delete the old table metadata, so that drop old table will fail
     String newTableName = tableName + "_2";
-    glue.updateTable(
+    GLUE.updateTable(
         UpdateTableRequest.builder()
             .databaseName(namespace)
             .tableInput(TableInput.builder().name(tableName).parameters(Maps.newHashMap()).build())
             .build());
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 glueCatalog.renameTable(
                     TableIdentifier.of(namespace, tableName),
@@ -285,9 +350,9 @@ public class TestGlueCatalogTable extends GlueTestBase {
         .isInstanceOf(ValidationException.class)
         .as("should fail to rename")
         .hasMessageContaining("Input Glue table is not an iceberg table");
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
-                glue.getTable(
+                GLUE.getTable(
                     GetTableRequest.builder().databaseName(namespace).name(newTableName).build()))
         .isInstanceOf(EntityNotFoundException.class)
         .as("renamed table should be deleted")
@@ -299,21 +364,20 @@ public class TestGlueCatalogTable extends GlueTestBase {
     String namespace = createNamespace();
     String tableName = createTable(namespace);
     glueCatalog.dropTable(TableIdentifier.of(namespace, tableName), false);
-    Assertions.assertThatThrownBy(
-            () -> glueCatalog.loadTable(TableIdentifier.of(namespace, tableName)))
+    assertThatThrownBy(() -> glueCatalog.loadTable(TableIdentifier.of(namespace, tableName)))
         .isInstanceOf(NoSuchTableException.class)
         .as("should not have table")
         .hasMessageContaining("Table does not exist");
     String warehouseLocation =
         glueCatalog.defaultWarehouseLocation(TableIdentifier.of(namespace, tableName));
-    String prefix = warehouseLocation.split(testBucketName + "/", -1)[1];
+    String prefix = warehouseLocation.split(TEST_BUCKET_NAME + "/", -1)[1];
     ListObjectsV2Response response =
-        s3.listObjectsV2(
+        S3.listObjectsV2(
             ListObjectsV2Request.builder()
-                .bucket(testBucketName)
+                .bucket(TEST_BUCKET_NAME)
                 .prefix(prefix + "/metadata/")
                 .build());
-    Assert.assertTrue(response.hasContents());
+    assertThat(response.hasContents()).isTrue();
     boolean hasMetaFile = false;
     for (S3Object s3Object : response.contents()) {
       if (s3Object.key().contains(".json")) {
@@ -321,7 +385,7 @@ public class TestGlueCatalogTable extends GlueTestBase {
         break;
       }
     }
-    Assert.assertTrue("metadata json file exists after delete without purge", hasMetaFile);
+    assertThat(hasMetaFile).as("metadata json file exists after delete without purge").isTrue();
   }
 
   @Test
@@ -353,23 +417,22 @@ public class TestGlueCatalogTable extends GlueTestBase {
     txn.commitTransaction();
 
     glueCatalog.dropTable(TableIdentifier.of(namespace, tableName));
-    Assertions.assertThatThrownBy(
-            () -> glueCatalog.loadTable(TableIdentifier.of(namespace, tableName)))
+    assertThatThrownBy(() -> glueCatalog.loadTable(TableIdentifier.of(namespace, tableName)))
         .isInstanceOf(NoSuchTableException.class)
         .as("should not have table")
         .hasMessageContaining("Table does not exist");
     String warehouseLocation =
         glueCatalog.defaultWarehouseLocation(TableIdentifier.of(namespace, tableName));
-    String prefix = warehouseLocation.split(testBucketName + "/", -1)[1];
+    String prefix = warehouseLocation.split(TEST_BUCKET_NAME + "/", -1)[1];
     ListObjectsV2Response response =
-        s3.listObjectsV2(
-            ListObjectsV2Request.builder().bucket(testBucketName).prefix(prefix).build());
+        S3.listObjectsV2(
+            ListObjectsV2Request.builder().bucket(TEST_BUCKET_NAME).prefix(prefix).build());
     if (response.hasContents()) {
       // might have directory markers left
       for (S3Object s3Object : response.contents()) {
         Optional<Long> size = s3Object.getValueForField("Size", Long.class);
-        Assert.assertTrue(size.isPresent());
-        Assert.assertEquals(0L, (long) size.get());
+        assertThat(size.isPresent()).isTrue();
+        assertThat(size.get()).isEqualTo(0);
       }
     }
   }
@@ -378,7 +441,7 @@ public class TestGlueCatalogTable extends GlueTestBase {
   public void testCommitTableSkipArchive() {
     // create ns
     String namespace = getRandomName();
-    namespaces.add(namespace);
+    NAMESPACES.add(namespace);
     glueCatalog.createNamespace(Namespace.of(namespace));
     // create table and commit without skip
     Schema schema = new Schema(Types.NestedField.required(1, "c1", Types.StringType.get(), "c1"));
@@ -387,11 +450,11 @@ public class TestGlueCatalogTable extends GlueTestBase {
     AwsProperties properties = new AwsProperties();
     properties.setGlueCatalogSkipArchive(false);
     glueCatalog.initialize(
-        catalogName,
-        testBucketPath,
+        CATALOG_NAME,
+        TEST_BUCKET_PATH,
         properties,
         new S3FileIOProperties(),
-        glue,
+        GLUE,
         LockManagers.defaultLockManager(),
         ImmutableMap.of());
     glueCatalog.createTable(TableIdentifier.of(namespace, tableName), schema, partitionSpec);
@@ -403,45 +466,43 @@ public class TestGlueCatalogTable extends GlueTestBase {
             .withRecordCount(1)
             .build();
     table.newAppend().appendFile(dataFile).commit();
-    Assert.assertEquals(
-        2,
-        glue.getTableVersions(
-                GetTableVersionsRequest.builder()
-                    .databaseName(namespace)
-                    .tableName(tableName)
-                    .build())
-            .tableVersions()
-            .size());
+    assertThat(
+            GLUE.getTableVersions(
+                    GetTableVersionsRequest.builder()
+                        .databaseName(namespace)
+                        .tableName(tableName)
+                        .build())
+                .tableVersions())
+        .hasSize(2);
     // create table and commit with skip
     tableName = getRandomName();
-    glueCatalog.initialize(catalogName, ImmutableMap.of());
+    glueCatalog.initialize(CATALOG_NAME, ImmutableMap.of());
     glueCatalog.createTable(TableIdentifier.of(namespace, tableName), schema, partitionSpec);
     table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
     table.newAppend().appendFile(dataFile).commit();
-    Assert.assertEquals(
-        "skipArchive should not create new version",
-        1,
-        glue.getTableVersions(
-                GetTableVersionsRequest.builder()
-                    .databaseName(namespace)
-                    .tableName(tableName)
-                    .build())
-            .tableVersions()
-            .size());
+    assertThat(
+            GLUE.getTableVersions(
+                    GetTableVersionsRequest.builder()
+                        .databaseName(namespace)
+                        .tableName(tableName)
+                        .build())
+                .tableVersions())
+        .as("skipArchive should not create new version")
+        .hasSize(1);
   }
 
   @Test
   public void testCommitTableSkipNameValidation() {
     String namespace = "dd-dd";
-    namespaces.add(namespace);
+    NAMESPACES.add(namespace);
     glueCatalogWithSkipNameValidation.createNamespace(Namespace.of(namespace));
     String tableName = "cc-cc";
     glueCatalogWithSkipNameValidation.createTable(
-        TableIdentifier.of(namespace, tableName), schema, partitionSpec, tableLocationProperties);
+        TableIdentifier.of(namespace, tableName), schema, partitionSpec, TABLE_LOCATION_PROPERTIES);
     GetTableResponse response =
-        glue.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
-    Assert.assertEquals(namespace, response.table().databaseName());
-    Assert.assertEquals(tableName, response.table().name());
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+    assertThat(response.table().databaseName()).isEqualTo(namespace);
+    assertThat(response.table().name()).isEqualTo(tableName);
   }
 
   @Test
@@ -461,7 +522,7 @@ public class TestGlueCatalogTable extends GlueTestBase {
     table.updateSpec().addField(truncate("c1", 8)).commit();
     table.updateSchema().deleteColumn("c3").renameColumn("c4", "c5").commit();
     GetTableResponse response =
-        glue.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
     List<Column> actualColumns = response.table().storageDescriptor().columns();
 
     List<Column> expectedColumns =
@@ -513,7 +574,73 @@ public class TestGlueCatalogTable extends GlueTestBase {
                         IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "true",
                         IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "false"))
                 .build());
-    Assert.assertEquals("Columns do not match", expectedColumns, actualColumns);
+    assertThat(actualColumns).isEqualTo(expectedColumns);
+  }
+
+  @Test
+  public void testGlueTableColumnCommentsPreserved() {
+    String namespace = createNamespace();
+    String tableName = createTable(namespace);
+    Table table = glueCatalog.loadTable(TableIdentifier.of(namespace, tableName));
+    table
+        .updateSchema()
+        .addColumn("c2", Types.StringType.get())
+        .addColumn("c3", Types.StringType.get())
+        .commit();
+
+    updateTableColumns(
+        namespace,
+        tableName,
+        column -> {
+          if (column.name().equals("c2") || column.name().equals("c3")) {
+            return column.toBuilder().comment("updated from Glue API").build();
+          } else {
+            return column;
+          }
+        });
+
+    table
+        .updateSchema()
+        .updateColumn("c2", Types.StringType.get(), "updated from Iceberg API")
+        .commit();
+
+    GetTableResponse response =
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+    List<Column> actualColumns = response.table().storageDescriptor().columns();
+
+    List<Column> expectedColumns =
+        ImmutableList.of(
+            Column.builder()
+                .name("c1")
+                .type("string")
+                .comment("c1")
+                .parameters(
+                    ImmutableMap.of(
+                        IcebergToGlueConverter.ICEBERG_FIELD_ID, "1",
+                        IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "false",
+                        IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "true"))
+                .build(),
+            Column.builder()
+                .name("c2")
+                .type("string")
+                .comment("updated from Iceberg API")
+                .parameters(
+                    ImmutableMap.of(
+                        IcebergToGlueConverter.ICEBERG_FIELD_ID, "2",
+                        IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "true",
+                        IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "true"))
+                .build(),
+            Column.builder()
+                .name("c3")
+                .type("string")
+                .comment("updated from Glue API")
+                .parameters(
+                    ImmutableMap.of(
+                        IcebergToGlueConverter.ICEBERG_FIELD_ID, "3",
+                        IcebergToGlueConverter.ICEBERG_FIELD_OPTIONAL, "true",
+                        IcebergToGlueConverter.ICEBERG_FIELD_CURRENT, "true"))
+                .build());
+    assertThat(actualColumns).isEqualTo(expectedColumns);
   }
 
   @Test
@@ -528,7 +655,7 @@ public class TestGlueCatalogTable extends GlueTestBase {
             "table-default.key3", "catalog-default-key3",
             "table-override.key3", "catalog-override-key3",
             "table-override.key4", "catalog-override-key4",
-            "warehouse", "s3://" + testBucketName + "/" + testPathPrefix);
+            "warehouse", "s3://" + TEST_BUCKET_NAME + "/" + TEST_PATH_PREFIX);
 
     glueCatalog.initialize("glue", catalogProps);
 
@@ -545,28 +672,19 @@ public class TestGlueCatalogTable extends GlueTestBase {
             .withProperty("key5", "table-key5")
             .create();
 
-    Assert.assertEquals(
-        "Table defaults set for the catalog must be added to the table properties.",
-        "catalog-default-key1",
-        table.properties().get("key1"));
-    Assert.assertEquals(
-        "Table property must override table default properties set at catalog level.",
-        "table-key2",
-        table.properties().get("key2"));
-    Assert.assertEquals(
-        "Table property override set at catalog level must override table default"
-            + " properties set at catalog level and table property specified.",
-        "catalog-override-key3",
-        table.properties().get("key3"));
-    Assert.assertEquals(
-        "Table override not in table props or defaults should be added to table properties",
-        "catalog-override-key4",
-        table.properties().get("key4"));
-    Assert.assertEquals(
-        "Table properties without any catalog level default or override should be added to table"
-            + " properties.",
-        "table-key5",
-        table.properties().get("key5"));
+    assertThat(table.properties())
+        .as("Table defaults set for the catalog must be added to the table properties.")
+        .containsEntry("key1", "catalog-default-key1")
+        .as("Table property must override table default properties set at catalog level.")
+        .containsEntry("key2", "table-key2")
+        .as(
+            "Table property override set at catalog level must override table default properties set at catalog level and table property specified.")
+        .containsEntry("key3", "catalog-override-key3")
+        .as("Table override not in table props or defaults should be added to table properties")
+        .containsEntry("key4", "catalog-override-key4")
+        .as(
+            "Table properties without any catalog level default or override should be added to table properties")
+        .containsEntry("key5", "table-key5");
   }
 
   @Test
@@ -577,15 +695,15 @@ public class TestGlueCatalogTable extends GlueTestBase {
     TableIdentifier identifier = TableIdentifier.of(namespace, tableName);
     Table table = glueCatalog.loadTable(identifier);
     String metadataLocation = ((BaseTable) table).operations().current().metadataFileLocation();
-    Assertions.assertThat(glueCatalog.dropTable(identifier, false)).isTrue();
+    assertThat(glueCatalog.dropTable(identifier, false)).isTrue();
     Table registeredTable = glueCatalog.registerTable(identifier, metadataLocation);
-    Assertions.assertThat(registeredTable).isNotNull();
+    assertThat(registeredTable).isNotNull();
     String expectedMetadataLocation =
         ((BaseTable) table).operations().current().metadataFileLocation();
-    Assertions.assertThat(metadataLocation).isEqualTo(expectedMetadataLocation);
-    Assertions.assertThat(glueCatalog.loadTable(identifier)).isNotNull();
-    Assertions.assertThat(glueCatalog.dropTable(identifier, true)).isTrue();
-    Assertions.assertThat(glueCatalog.dropNamespace(Namespace.of(namespace))).isTrue();
+    assertThat(metadataLocation).isEqualTo(expectedMetadataLocation);
+    assertThat(glueCatalog.loadTable(identifier)).isNotNull();
+    assertThat(glueCatalog.dropTable(identifier, true)).isTrue();
+    assertThat(glueCatalog.dropNamespace(Namespace.of(namespace))).isTrue();
   }
 
   @Test
@@ -596,15 +714,15 @@ public class TestGlueCatalogTable extends GlueTestBase {
     TableIdentifier identifier = TableIdentifier.of(namespace, tableName);
     Table table = glueCatalog.loadTable(identifier);
     String metadataLocation = ((BaseTable) table).operations().current().metadataFileLocation();
-    Assertions.assertThatThrownBy(() -> glueCatalog.registerTable(identifier, metadataLocation))
+    assertThatThrownBy(() -> glueCatalog.registerTable(identifier, metadataLocation))
         .isInstanceOf(AlreadyExistsException.class);
-    Assertions.assertThat(glueCatalog.dropTable(identifier, true)).isTrue();
-    Assertions.assertThat(glueCatalog.dropNamespace(Namespace.of(namespace))).isTrue();
+    assertThat(glueCatalog.dropTable(identifier, true)).isTrue();
+    assertThat(glueCatalog.dropNamespace(Namespace.of(namespace))).isTrue();
   }
 
   @Test
   public void testTableLevelS3Tags() {
-    String testBucketPath = "s3://" + testBucketName + "/" + testPathPrefix;
+    String testBucketPath = "s3://" + TEST_BUCKET_NAME + "/" + TEST_PATH_PREFIX;
     Map<String, String> properties =
         ImmutableMap.of(
             S3FileIOProperties.WRITE_TABLE_TAG_ENABLED,
@@ -612,11 +730,11 @@ public class TestGlueCatalogTable extends GlueTestBase {
             S3FileIOProperties.WRITE_NAMESPACE_TAG_ENABLED,
             "true");
     glueCatalog.initialize(
-        catalogName,
+        CATALOG_NAME,
         testBucketPath,
         new AwsProperties(properties),
         new S3FileIOProperties(properties),
-        glue,
+        GLUE,
         null);
     String namespace = createNamespace();
     String tableName = getRandomName();
@@ -624,19 +742,18 @@ public class TestGlueCatalogTable extends GlueTestBase {
 
     // Get metadata object tag from S3
     GetTableResponse response =
-        glue.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
+        GLUE.getTable(GetTableRequest.builder().databaseName(namespace).name(tableName).build());
     String metaLocation =
         response.table().parameters().get(BaseMetastoreTableOperations.METADATA_LOCATION_PROP);
-    String key = metaLocation.split(testBucketName, -1)[1].substring(1);
+    String key = metaLocation.split(TEST_BUCKET_NAME, -1)[1].substring(1);
     List<Tag> tags =
-        s3.getObjectTagging(
-                GetObjectTaggingRequest.builder().bucket(testBucketName).key(key).build())
+        S3.getObjectTagging(
+                GetObjectTaggingRequest.builder().bucket(TEST_BUCKET_NAME).key(key).build())
             .tagSet();
     Map<String, String> tagMap = tags.stream().collect(Collectors.toMap(Tag::key, Tag::value));
 
-    Assert.assertTrue(tagMap.containsKey(S3FileIOProperties.S3_TAG_ICEBERG_TABLE));
-    Assert.assertEquals(tableName, tagMap.get(S3FileIOProperties.S3_TAG_ICEBERG_TABLE));
-    Assert.assertTrue(tagMap.containsKey(S3FileIOProperties.S3_TAG_ICEBERG_NAMESPACE));
-    Assert.assertEquals(namespace, tagMap.get(S3FileIOProperties.S3_TAG_ICEBERG_NAMESPACE));
+    assertThat(tagMap)
+        .containsEntry(S3FileIOProperties.S3_TAG_ICEBERG_TABLE, tableName)
+        .containsEntry(S3FileIOProperties.S3_TAG_ICEBERG_NAMESPACE, namespace);
   }
 }
