@@ -18,9 +18,10 @@
  */
 package org.apache.iceberg.aws;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import java.util.Map;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.Test;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mockito;
@@ -45,8 +46,8 @@ public class AwsClientPropertiesTest {
     awsClientProperties.applyClientRegionConfiguration(mockS3ClientBuilder);
     Mockito.verify(mockS3ClientBuilder).region(regionArgumentCaptor.capture());
     Region region = regionArgumentCaptor.getValue();
-    Assertions.assertThat(region.id())
-        .withFailMessage("region parameter should match what is set in CLIENT_REGION")
+    assertThat(region.id())
+        .as("region parameter should match what is set in CLIENT_REGION")
         .isEqualTo("us-east-1");
   }
 
@@ -56,9 +57,9 @@ public class AwsClientPropertiesTest {
     AwsCredentialsProvider credentialsProvider =
         awsClientProperties.credentialsProvider(null, null, null);
 
-    Assertions.assertThat(credentialsProvider instanceof DefaultCredentialsProvider)
-        .withFailMessage("Should use default credentials if nothing is set")
-        .isTrue();
+    assertThat(credentialsProvider)
+        .as("Should use default credentials if nothing is set")
+        .isInstanceOf(DefaultCredentialsProvider.class);
   }
 
   @Test
@@ -69,8 +70,8 @@ public class AwsClientPropertiesTest {
     AwsCredentialsProvider credentialsProvider2 =
         awsClientProperties.credentialsProvider(null, null, null);
 
-    Assertions.assertThat(credentialsProvider)
-        .withFailMessage("Should create a new instance in each call")
+    assertThat(credentialsProvider)
+        .as("Should create a new instance in each call")
         .isNotSameAs(credentialsProvider2);
   }
 
@@ -81,17 +82,15 @@ public class AwsClientPropertiesTest {
     AwsCredentialsProvider credentialsProvider =
         awsClientProperties.credentialsProvider("key", "secret", null);
 
-    Assertions.assertThat(credentialsProvider.resolveCredentials() instanceof AwsBasicCredentials)
-        .withFailMessage(
-            "Should use basic credentials if access key ID and secret access key are set")
-        .isTrue();
-    Assertions.assertThat(credentialsProvider.resolveCredentials().accessKeyId())
-        .withFailMessage("The access key id should be the same as the one set by tag ACCESS_KEY_ID")
+    assertThat(credentialsProvider.resolveCredentials())
+        .as("Should use basic credentials if access key ID and secret access key are set")
+        .isInstanceOf(AwsBasicCredentials.class);
+    assertThat(credentialsProvider.resolveCredentials().accessKeyId())
+        .as("The access key id should be the same as the one set by tag ACCESS_KEY_ID")
         .isEqualTo("key");
 
-    Assertions.assertThat(credentialsProvider.resolveCredentials().secretAccessKey())
-        .withFailMessage(
-            "The secret access key should be the same as the one set by tag SECRET_ACCESS_KEY")
+    assertThat(credentialsProvider.resolveCredentials().secretAccessKey())
+        .as("The secret access key should be the same as the one set by tag SECRET_ACCESS_KEY")
         .isEqualTo("secret");
   }
 
@@ -102,15 +101,14 @@ public class AwsClientPropertiesTest {
     AwsCredentialsProvider credentialsProvider =
         awsClientProperties.credentialsProvider("key", "secret", "token");
 
-    Assertions.assertThat(credentialsProvider.resolveCredentials() instanceof AwsSessionCredentials)
-        .withFailMessage("Should use session credentials if session token is set")
-        .isTrue();
-    Assertions.assertThat(credentialsProvider.resolveCredentials().accessKeyId())
-        .withFailMessage("The access key id should be the same as the one set by tag ACCESS_KEY_ID")
+    assertThat(credentialsProvider.resolveCredentials())
+        .as("Should use session credentials if session token is set")
+        .isInstanceOf(AwsSessionCredentials.class);
+    assertThat(credentialsProvider.resolveCredentials().accessKeyId())
+        .as("The access key id should be the same as the one set by tag ACCESS_KEY_ID")
         .isEqualTo("key");
-    Assertions.assertThat(credentialsProvider.resolveCredentials().secretAccessKey())
-        .withFailMessage(
-            "The secret access key should be the same as the one set by tag SECRET_ACCESS_KEY")
+    assertThat(credentialsProvider.resolveCredentials().secretAccessKey())
+        .as("The secret access key should be the same as the one set by tag SECRET_ACCESS_KEY")
         .isEqualTo("secret");
   }
 }
