@@ -18,6 +18,8 @@
  */
 package org.apache.iceberg.aws.s3;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.mockito.AdditionalAnswers.delegatesTo;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doReturn;
@@ -68,7 +70,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Streams;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.SerializableSupplier;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Disabled;
@@ -131,25 +132,25 @@ public class TestS3FileIO {
     random.nextBytes(expected);
 
     InputFile in = s3FileIO.newInputFile(location);
-    Assertions.assertThat(in.exists()).isFalse();
+    assertThat(in.exists()).isFalse();
 
     OutputFile out = s3FileIO.newOutputFile(location);
     try (OutputStream os = out.createOrOverwrite()) {
       IOUtil.writeFully(os, ByteBuffer.wrap(expected));
     }
 
-    Assertions.assertThat(in.exists()).isTrue();
+    assertThat(in.exists()).isTrue();
     byte[] actual = new byte[1024 * 1024];
 
     try (InputStream is = in.newStream()) {
       IOUtil.readFully(is, actual, 0, expected.length);
     }
 
-    Assertions.assertThat(actual).isEqualTo(expected);
+    assertThat(actual).isEqualTo(expected);
 
     s3FileIO.deleteFile(in);
 
-    Assertions.assertThat(s3FileIO.newInputFile(location).exists()).isFalse();
+    assertThat(s3FileIO.newInputFile(location).exists()).isFalse();
   }
 
   @Test
@@ -171,7 +172,7 @@ public class TestS3FileIO {
   public void testDeleteEmptyList() throws IOException {
     String location = "s3://bucket/path/to/file.txt";
     InputFile in = s3FileIO.newInputFile(location);
-    Assertions.assertThat(in.exists()).isFalse();
+    assertThat(in.exists()).isFalse();
     OutputFile out = s3FileIO.newOutputFile(location);
     try (OutputStream os = out.createOrOverwrite()) {
       IOUtil.writeFully(os, ByteBuffer.wrap(new byte[1024 * 1024]));
@@ -179,9 +180,9 @@ public class TestS3FileIO {
 
     s3FileIO.deleteFiles(Lists.newArrayList());
 
-    Assertions.assertThat(s3FileIO.newInputFile(location).exists()).isTrue();
+    assertThat(s3FileIO.newInputFile(location).exists()).isTrue();
     s3FileIO.deleteFile(in);
-    Assertions.assertThat(s3FileIO.newInputFile(location).exists()).isFalse();
+    assertThat(s3FileIO.newInputFile(location).exists()).isFalse();
   }
 
   @Test
@@ -193,7 +194,7 @@ public class TestS3FileIO {
             .build();
     doReturn(deleteObjectsResponse).when(s3mock).deleteObjects((DeleteObjectsRequest) any());
 
-    Assertions.assertThatThrownBy(() -> s3FileIO.deleteFiles(Lists.newArrayList(location)))
+    assertThatThrownBy(() -> s3FileIO.deleteFiles(Lists.newArrayList(location)))
         .isInstanceOf(BulkDeletionFailureException.class)
         .hasMessage("Failed to delete 1 files");
   }
@@ -216,7 +217,7 @@ public class TestS3FileIO {
     int expectedDeleteRequests = expectedNumberOfBatchesPerBucket * numBucketsForBatchDeletion;
     verify(s3mock, times(expectedDeleteRequests)).deleteObjects((DeleteObjectsRequest) any());
     for (String path : paths) {
-      Assertions.assertThat(s3FileIO.newInputFile(path).exists()).isFalse();
+      assertThat(s3FileIO.newInputFile(path).exists()).isFalse();
     }
   }
 
@@ -232,7 +233,7 @@ public class TestS3FileIO {
     byte[] data = TestHelpers.serialize(pre);
     SerializableSupplier<S3Client> post = TestHelpers.deserialize(data);
 
-    Assertions.assertThat(post.get().serviceName()).isEqualTo("s3");
+    assertThat(post.get().serviceName()).isEqualTo("s3");
   }
 
   @Test
@@ -248,13 +249,12 @@ public class TestS3FileIO {
               String scalePrefix = String.format("%s/%s/", prefix, scale);
 
               createRandomObjects(scalePrefix, scale);
-              Assertions.assertThat(Streams.stream(s3FileIO.listPrefix(scalePrefix)).count())
+              assertThat(Streams.stream(s3FileIO.listPrefix(scalePrefix)).count())
                   .isEqualTo((long) scale);
             });
 
     long totalFiles = scaleSizes.stream().mapToLong(Integer::longValue).sum();
-    Assertions.assertThat(Streams.stream(s3FileIO.listPrefix(prefix)).count())
-        .isEqualTo(totalFiles);
+    assertThat(Streams.stream(s3FileIO.listPrefix(prefix)).count()).isEqualTo(totalFiles);
   }
 
   /**
@@ -273,8 +273,7 @@ public class TestS3FileIO {
 
           createRandomObjects(scalePrefix, scale);
           s3FileIO.deletePrefix(scalePrefix);
-          Assertions.assertThat(Streams.stream(s3FileIO.listPrefix(scalePrefix)).count())
-              .isEqualTo(0);
+          assertThat(Streams.stream(s3FileIO.listPrefix(scalePrefix)).count()).isEqualTo(0);
         });
   }
 
@@ -283,7 +282,7 @@ public class TestS3FileIO {
     String location = "s3://bucket/path/to/data.parquet";
     InputFile in = s3FileIO.newInputFile(location);
 
-    Assertions.assertThatThrownBy(() -> in.newStream().read())
+    assertThatThrownBy(() -> in.newStream().read())
         .isInstanceOf(NotFoundException.class)
         .hasMessage("Location does not exist: " + location);
   }
@@ -313,12 +312,12 @@ public class TestS3FileIO {
       long start = System.currentTimeMillis();
       // to test NotFoundException, load the table again. refreshing the existing table doesn't
       // require reading metadata
-      Assertions.assertThatThrownBy(() -> catalog.loadTable(ident))
+      assertThatThrownBy(() -> catalog.loadTable(ident))
           .isInstanceOf(NotFoundException.class)
           .hasMessageStartingWith("Location does not exist");
 
       long duration = System.currentTimeMillis() - start;
-      Assertions.assertThat(duration < 10_000).as("Should take less than 10 seconds").isTrue();
+      assertThat(duration < 10_000).as("Should take less than 10 seconds").isTrue();
     }
   }
 
@@ -333,8 +332,8 @@ public class TestS3FileIO {
 
     String json = FileIOParser.toJson(s3FileIO);
     try (FileIO deserialized = FileIOParser.fromJson(json, conf)) {
-      Assertions.assertThat(deserialized).isInstanceOf(S3FileIO.class);
-      Assertions.assertThat(deserialized.properties()).isEqualTo(s3FileIO.properties());
+      assertThat(deserialized).isInstanceOf(S3FileIO.class);
+      assertThat(deserialized.properties()).isEqualTo(s3FileIO.properties());
     }
   }
 
@@ -346,8 +345,7 @@ public class TestS3FileIO {
     testS3FileIO.initialize(ImmutableMap.of("k1", "v1"));
     FileIO roundTripSerializedFileIO = TestHelpers.KryoHelpers.roundTripSerialize(testS3FileIO);
 
-    Assertions.assertThat(roundTripSerializedFileIO.properties())
-        .isEqualTo(testS3FileIO.properties());
+    assertThat(roundTripSerializedFileIO.properties()).isEqualTo(testS3FileIO.properties());
   }
 
   @Test
@@ -358,8 +356,7 @@ public class TestS3FileIO {
     testS3FileIO.initialize(ImmutableMap.of());
     FileIO roundTripSerializedFileIO = TestHelpers.KryoHelpers.roundTripSerialize(testS3FileIO);
 
-    Assertions.assertThat(roundTripSerializedFileIO.properties())
-        .isEqualTo(testS3FileIO.properties());
+    assertThat(roundTripSerializedFileIO.properties()).isEqualTo(testS3FileIO.properties());
   }
 
   @Test
@@ -370,8 +367,7 @@ public class TestS3FileIO {
     testS3FileIO.initialize(ImmutableMap.of("k1", "v1"));
     FileIO roundTripSerializedFileIO = TestHelpers.roundTripSerialize(testS3FileIO);
 
-    Assertions.assertThat(roundTripSerializedFileIO.properties())
-        .isEqualTo(testS3FileIO.properties());
+    assertThat(roundTripSerializedFileIO.properties()).isEqualTo(testS3FileIO.properties());
   }
 
   @Test
@@ -384,7 +380,7 @@ public class TestS3FileIO {
             .hiddenImpl(ResolvingFileIO.class, String.class)
             .build(resolvingFileIO)
             .invoke("s3://foo/bar");
-    Assertions.assertThat(result).isInstanceOf(S3FileIO.class);
+    assertThat(result).isInstanceOf(S3FileIO.class);
   }
 
   @Test
@@ -405,7 +401,7 @@ public class TestS3FileIO {
     InputFile inputFile = s3FileIO.newInputFile(dataFile);
     reset(s3mock);
 
-    Assertions.assertThat(inputFile.getLength())
+    assertThat(inputFile.getLength())
         .as("Data file length should be determined from the file size stats")
         .isEqualTo(123L);
     verify(s3mock, never()).headObject(any(HeadObjectRequest.class));
@@ -431,7 +427,7 @@ public class TestS3FileIO {
     InputFile inputFile = s3FileIO.newInputFile(manifest);
     reset(s3mock);
 
-    Assertions.assertThat(inputFile.getLength()).isEqualTo(manifest.length());
+    assertThat(inputFile.getLength()).isEqualTo(manifest.length());
     verify(s3mock, never()).headObject(any(HeadObjectRequest.class));
   }
 
