@@ -18,6 +18,9 @@
  */
 package org.apache.iceberg.aws.s3;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import com.adobe.testing.s3mock.junit5.S3MockExtension;
 import java.io.IOException;
 import java.util.Arrays;
@@ -25,7 +28,6 @@ import java.util.Random;
 import org.apache.iceberg.io.IOUtil;
 import org.apache.iceberg.io.RangeReadable;
 import org.apache.iceberg.io.SeekableInputStream;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
@@ -88,7 +90,7 @@ public class TestS3InputStream {
       SeekableInputStream in, long rangeStart, int size, byte[] original, boolean buffered)
       throws IOException {
     in.seek(rangeStart);
-    Assertions.assertThat(in.getPos()).isEqualTo(rangeStart);
+    assertThat(in.getPos()).isEqualTo(rangeStart);
 
     long rangeEnd = rangeStart + size;
     byte[] actual = new byte[size];
@@ -102,9 +104,8 @@ public class TestS3InputStream {
       }
     }
 
-    Assertions.assertThat(in.getPos()).isEqualTo(rangeEnd);
-    Assertions.assertThat(actual)
-        .isEqualTo(Arrays.copyOfRange(original, (int) rangeStart, (int) rangeEnd));
+    assertThat(in.getPos()).isEqualTo(rangeEnd);
+    assertThat(actual).isEqualTo(Arrays.copyOfRange(original, (int) rangeStart, (int) rangeEnd));
   }
 
   @Test
@@ -145,7 +146,7 @@ public class TestS3InputStream {
       throws IOException {
     in.readFully(position, buffer, offset, length);
 
-    Assertions.assertThat(Arrays.copyOfRange(buffer, offset, offset + length))
+    assertThat(Arrays.copyOfRange(buffer, offset, offset + length))
         .isEqualTo(Arrays.copyOfRange(original, offset, offset + length));
   }
 
@@ -154,7 +155,7 @@ public class TestS3InputStream {
     S3URI uri = new S3URI("s3://bucket/path/to/closed.dat");
     SeekableInputStream closed = new S3InputStream(s3, uri);
     closed.close();
-    Assertions.assertThatThrownBy(() -> closed.seek(0))
+    assertThatThrownBy(() -> closed.seek(0))
         .isInstanceOf(IllegalStateException.class)
         .hasMessage("already closed");
   }
@@ -170,7 +171,7 @@ public class TestS3InputStream {
       in.seek(expected.length / 2);
       byte[] actual = new byte[expected.length / 2];
       IOUtil.readFully(in, actual, 0, expected.length / 2);
-      Assertions.assertThat(actual)
+      assertThat(actual)
           .isEqualTo(Arrays.copyOfRange(expected, expected.length / 2, expected.length));
     }
   }
