@@ -134,7 +134,7 @@ class BaseRewriteFiles extends MergingSnapshotProducer<RewriteFiles> implements
   @Override
   protected void validate(TableMetadata base, Snapshot parent) {
     validateReplacedAndAddedFiles();
-    if (replacedDataFiles.size() > 0) {
+    if (!replacedDataFiles.isEmpty()) {
       // if there are replaced data files, there cannot be any new row-level deletes for those data
       // files
       validateNoNewDeletesForDataFiles(base, startingSnapshotId, replacedDataFiles, parent);
