@@ -737,22 +737,10 @@ class DeleteFileIndex {
       return wrapped;
     }
 
-    public PartitionSpec spec() {
-      return spec;
-    }
-
-    public StructLike partition() {
-      return wrapped.partition();
-    }
-
     public long applySequenceNumber() {
       return applySequenceNumber;
     }
 
-    public FileContent content() {
-      return wrapped.content();
-    }
-
     public List<Types.NestedField> equalityFields() {
       if (equalityFields == null) {
         synchronized (this) {
@@ -778,10 +766,6 @@ class DeleteFileIndex {
       return wrapped.nullValueCounts();
     }
 
-    public Map<Integer, Long> nanValueCounts() {
-      return wrapped.nanValueCounts();
-    }
-
     public boolean hasLowerAndUpperBounds() {
       return wrapped.lowerBounds() != null && wrapped.upperBounds() != null;
     }
