@@ -167,6 +167,10 @@ public class TableProperties {
       "write.parquet.bloom-filter-max-bytes";
   public static final int PARQUET_BLOOM_FILTER_MAX_BYTES_DEFAULT = 1024 * 1024;
 
+  public static final String PARQUET_BLOOM_FILTER_COLUMN_FPP_PREFIX =
+      "write.parquet.bloom-filter-fpp.column.";
+  public static final double PARQUET_BLOOM_FILTER_COLUMN_FPP_DEFAULT = 0.01;
+
   public static final String PARQUET_BLOOM_FILTER_COLUMN_ENABLED_PREFIX =
       "write.parquet.bloom-filter-enabled.column.";
 
