@@ -31,6 +31,7 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.UUID;
 import java.util.function.Supplier;
 import org.apache.avro.Schema;
@@ -44,6 +45,7 @@ import org.apache.iceberg.common.DynConstructors;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.types.Types;
+import org.apache.iceberg.util.Pair;
 import org.apache.iceberg.util.UUIDUtil;
 
 public class ValueReaders {
@@ -53,6 +55,14 @@ public class ValueReaders {
     return NullReader.INSTANCE;
   }
 
+  public static <T> ValueReader<T> constant(T value) {
+    return new ConstantReader<>(value);
+  }
+
+  public static <T> ValueReader<T> replaceWithConstant(ValueReader<?> reader, T value) {
+    return new ReplaceWithConstantReader<>(reader, value);
+  }
+
   public static ValueReader<Boolean> booleans() {
     return BooleanReader.INSTANCE;
   }
@@ -61,6 +71,10 @@ public class ValueReaders {
     return IntegerReader.INSTANCE;
   }
 
+  public static ValueReader<Long> intsAsLongs() {
+    return IntegerAsLongReader.INSTANCE;
+  }
+
   public static ValueReader<Long> longs() {
     return LongReader.INSTANCE;
   }
@@ -69,6 +83,10 @@ public class ValueReaders {
     return FloatReader.INSTANCE;
   }
 
+  public static ValueReader<Double> floatsAsDoubles() {
+    return FloatAsDoubleReader.INSTANCE;
+  }
+
   public static ValueReader<Double> doubles() {
     return DoubleReader.INSTANCE;
   }
@@ -125,6 +143,10 @@ public class ValueReaders {
     return new UnionReader(readers);
   }
 
+  public static ValueReader<Long> positions() {
+    return new PositionReader();
+  }
+
   public static <T> ValueReader<Collection<T>> array(ValueReader<T> elementReader) {
     return new ArrayReader<>(elementReader);
   }
@@ -149,6 +171,16 @@ public class ValueReaders {
     return new IndexedRecordReader<>(readers, recordClass, recordSchema);
   }
 
+  public static ValueReader<?> record(
+      Schema recordSchema, List<Pair<Integer, ValueReader<?>>> readPlan) {
+    return new PlannedRecordReader(recordSchema, readPlan);
+  }
+
+  public static <R extends IndexedRecord> ValueReader<R> record(
+      Schema recordSchema, Class<R> recordClass, List<Pair<Integer, ValueReader<?>>> readPlan) {
+    return new PlannedIndexedReader<>(recordSchema, recordClass, readPlan);
+  }
+
   private static class NullReader implements ValueReader<Object> {
     private static final NullReader INSTANCE = new NullReader();
 
@@ -159,6 +191,47 @@ public class ValueReaders {
       decoder.readNull();
       return null;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.readNull();
+    }
+  }
+
+  private static class ConstantReader<T> implements ValueReader<T> {
+    private final T constant;
+
+    private ConstantReader(T constant) {
+      this.constant = constant;
+    }
+
+    @Override
+    public T read(Decoder decoder, Object reuse) throws IOException {
+      return constant;
+    }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {}
+  }
+
+  private static class ReplaceWithConstantReader<T> extends ConstantReader<T> {
+    private final ValueReader<?> replaced;
+
+    private ReplaceWithConstantReader(ValueReader<?> replaced, T constant) {
+      super(constant);
+      this.replaced = replaced;
+    }
+
+    @Override
+    public T read(Decoder decoder, Object reuse) throws IOException {
+      replaced.read(decoder, reuse);
+      return super.read(decoder, reuse);
+    }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      replaced.skip(decoder);
+    }
   }
 
   private static class BooleanReader implements ValueReader<Boolean> {
@@ -170,6 +243,11 @@ public class ValueReaders {
     public Boolean read(Decoder decoder, Object ignored) throws IOException {
       return decoder.readBoolean();
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.readBoolean();
+    }
   }
 
   private static class IntegerReader implements ValueReader<Integer> {
@@ -181,6 +259,27 @@ public class ValueReaders {
     public Integer read(Decoder decoder, Object ignored) throws IOException {
       return decoder.readInt();
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.readInt();
+    }
+  }
+
+  private static class IntegerAsLongReader implements ValueReader<Long> {
+    private static final IntegerAsLongReader INSTANCE = new IntegerAsLongReader();
+
+    private IntegerAsLongReader() {}
+
+    @Override
+    public Long read(Decoder decoder, Object ignored) throws IOException {
+      return (long) decoder.readInt();
+    }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.readInt();
+    }
   }
 
   private static class LongReader implements ValueReader<Long> {
@@ -192,6 +291,11 @@ public class ValueReaders {
     public Long read(Decoder decoder, Object ignored) throws IOException {
       return decoder.readLong();
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.readLong();
+    }
   }
 
   private static class FloatReader implements ValueReader<Float> {
@@ -203,6 +307,27 @@ public class ValueReaders {
     public Float read(Decoder decoder, Object ignored) throws IOException {
       return decoder.readFloat();
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipFixed(4);
+    }
+  }
+
+  private static class FloatAsDoubleReader implements ValueReader<Double> {
+    private static final FloatAsDoubleReader INSTANCE = new FloatAsDoubleReader();
+
+    private FloatAsDoubleReader() {}
+
+    @Override
+    public Double read(Decoder decoder, Object ignored) throws IOException {
+      return (double) decoder.readFloat();
+    }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipFixed(4);
+    }
   }
 
   private static class DoubleReader implements ValueReader<Double> {
@@ -214,6 +339,11 @@ public class ValueReaders {
     public Double read(Decoder decoder, Object ignored) throws IOException {
       return decoder.readDouble();
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipFixed(8);
+    }
   }
 
   private static class StringReader implements ValueReader<String> {
@@ -231,6 +361,11 @@ public class ValueReaders {
       //      byte[] bytes = new byte[length];
       //      decoder.readFixed(bytes, 0, length);
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipString();
+    }
   }
 
   private static class Utf8Reader implements ValueReader<Utf8> {
@@ -250,6 +385,11 @@ public class ValueReaders {
       //      byte[] bytes = new byte[length];
       //      decoder.readFixed(bytes, 0, length);
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipString();
+    }
   }
 
   private static class UUIDReader implements ValueReader<UUID> {
@@ -275,6 +415,11 @@ public class ValueReaders {
 
       return UUIDUtil.convert(buffer);
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipFixed(16);
+    }
   }
 
   private static class FixedReader implements ValueReader<byte[]> {
@@ -298,6 +443,11 @@ public class ValueReaders {
       decoder.readFixed(bytes, 0, length);
       return bytes;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipFixed(length);
+    }
   }
 
   private static class GenericFixedReader implements ValueReader<GenericData.Fixed> {
@@ -323,6 +473,11 @@ public class ValueReaders {
       decoder.readFixed(bytes, 0, length);
       return new GenericData.Fixed(schema, bytes);
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipFixed(length);
+    }
   }
 
   private static class BytesReader implements ValueReader<byte[]> {
@@ -344,6 +499,11 @@ public class ValueReaders {
       //      decoder.readFixed(bytes, 0, length);
       //      return bytes;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipBytes();
+    }
   }
 
   private static class ByteBufferReader implements ValueReader<ByteBuffer> {
@@ -364,6 +524,11 @@ public class ValueReaders {
       //      decoder.readFixed(bytes, 0, length);
       //      return bytes;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.skipBytes();
+    }
   }
 
   private static class DecimalReader implements ValueReader<BigDecimal> {
@@ -381,6 +546,11 @@ public class ValueReaders {
       byte[] bytes = bytesReader.read(decoder, null);
       return new BigDecimal(new BigInteger(bytes), scale);
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      bytesReader.skip(decoder);
+    }
   }
 
   private static class UnionReader implements ValueReader<Object> {
@@ -398,6 +568,12 @@ public class ValueReaders {
       int index = decoder.readIndex();
       return readers[index].read(decoder, reuse);
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      int index = decoder.readIndex();
+      readers[index].skip(decoder);
+    }
   }
 
   private static class EnumReader implements ValueReader<String> {
@@ -415,6 +591,11 @@ public class ValueReaders {
       int index = decoder.readEnum();
       return symbols[index];
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      decoder.readEnum();
+    }
   }
 
   private static class ArrayReader<T> implements ValueReader<Collection<T>> {
@@ -456,6 +637,16 @@ public class ValueReaders {
 
       return resultList;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      long itemsToSkip;
+      while ((itemsToSkip = decoder.skipArray()) != 0) {
+        for (int i = 0; i < itemsToSkip; i += 1) {
+          elementReader.skip(decoder);
+        }
+      }
+    }
   }
 
   private static class ArrayMapReader<K, V> implements ValueReader<Map<K, V>> {
@@ -509,6 +700,17 @@ public class ValueReaders {
 
       return resultMap;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      long itemsToSkip;
+      while ((itemsToSkip = decoder.skipArray()) != 0) {
+        for (int i = 0; i < itemsToSkip; i += 1) {
+          keyReader.skip(decoder);
+          valueReader.skip(decoder);
+        }
+      }
+    }
   }
 
   private static class MapReader<K, V> implements ValueReader<Map<K, V>> {
@@ -562,6 +764,133 @@ public class ValueReaders {
 
       return resultMap;
     }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      long itemsToSkip;
+      while ((itemsToSkip = decoder.skipMap()) != 0) {
+        for (int i = 0; i < itemsToSkip; i += 1) {
+          keyReader.skip(decoder);
+          valueReader.skip(decoder);
+        }
+      }
+    }
+  }
+
+  public abstract static class PlannedStructReader<S>
+      implements ValueReader<S>, SupportsRowPosition {
+    private final ValueReader<?>[] readers;
+    private final Integer[] positions;
+
+    protected PlannedStructReader(List<Pair<Integer, ValueReader<?>>> readPlan) {
+      this.readers = readPlan.stream().map(Pair::second).toArray(ValueReader[]::new);
+      this.positions = readPlan.stream().map(Pair::first).toArray(Integer[]::new);
+    }
+
+    @Override
+    public void setRowPositionSupplier(Supplier<Long> posSupplier) {
+      for (ValueReader<?> reader : readers) {
+        if (reader instanceof SupportsRowPosition) {
+          ((SupportsRowPosition) reader).setRowPositionSupplier(posSupplier);
+        }
+      }
+    }
+
+    protected abstract S reuseOrCreate(Object reuse);
+
+    protected abstract Object get(S struct, int pos);
+
+    protected abstract void set(S struct, int pos, Object value);
+
+    @Override
+    public S read(Decoder decoder, Object reuse) throws IOException {
+      S struct = reuseOrCreate(reuse);
+
+      for (int i = 0; i < readers.length; i += 1) {
+        if (positions[i] != null) {
+          Object reusedValue = get(struct, positions[i]);
+          set(struct, positions[i], readers[i].read(decoder, reusedValue));
+        } else {
+          // if pos is null, the value is not projected
+          readers[i].skip(decoder);
+        }
+      }
+
+      return struct;
+    }
+
+    @Override
+    public void skip(Decoder decoder) throws IOException {
+      for (int i = 0; i < readers.length; i += 1) {
+        readers[i].skip(decoder);
+      }
+    }
+  }
+
+  private static class PlannedRecordReader extends PlannedStructReader<GenericData.Record> {
+    private final Schema recordSchema;
+
+    private PlannedRecordReader(Schema recordSchema, List<Pair<Integer, ValueReader<?>>> readPlan) {
+      super(readPlan);
+      this.recordSchema = recordSchema;
+    }
+
+    @Override
+    protected GenericData.Record reuseOrCreate(Object reuse) {
+      if (reuse instanceof GenericData.Record) {
+        return (GenericData.Record) reuse;
+      } else {
+        return new GenericData.Record(recordSchema);
+      }
+    }
+
+    @Override
+    protected Object get(GenericData.Record struct, int pos) {
+      return struct.get(pos);
+    }
+
+    @Override
+    protected void set(GenericData.Record struct, int pos, Object value) {
+      struct.put(pos, value);
+    }
+  }
+
+  private static class PlannedIndexedReader<R extends IndexedRecord>
+      extends PlannedStructReader<R> {
+    private final Class<R> recordClass;
+    private final DynConstructors.Ctor<R> ctor;
+    private final Schema schema;
+
+    PlannedIndexedReader(
+        Schema recordSchema, Class<R> recordClass, List<Pair<Integer, ValueReader<?>>> readPlan) {
+      super(readPlan);
+      this.recordClass = recordClass;
+      this.ctor =
+          DynConstructors.builder(IndexedRecord.class)
+              .hiddenImpl(recordClass, Schema.class)
+              .hiddenImpl(recordClass)
+              .build();
+      this.schema = recordSchema;
+    }
+
+    @Override
+    protected R reuseOrCreate(Object reuse) {
+      if (recordClass.isInstance(reuse)) {
+        return recordClass.cast(reuse);
+      } else {
+        return ctor.newInstance(schema);
+      }
+    }
+
+    @Override
+    protected Object get(R struct, int pos) {
+      return struct.get(pos);
+    }
+
+    @Override
+    protected void set(R struct, int pos, Object value) {
+      struct.put(pos, value);
+    }
   }
 
   public abstract static class StructReader<S> implements ValueReader<S>, SupportsRowPosition {
@@ -577,10 +906,11 @@ public class ValueReaders {
       List<Schema.Field> fields = schema.getFields();
       for (int pos = 0; pos < fields.size(); pos += 1) {
         Schema.Field field = fields.get(pos);
-        if (AvroSchemaUtil.getFieldId(field) == MetadataColumns.ROW_POSITION.fieldId()) {
+        if (Objects.equals(AvroSchemaUtil.fieldId(field), MetadataColumns.ROW_POSITION.fieldId())) {
           // track where the _pos field is located for setRowPositionSupplier
           this.posField = pos;
-        } else if (AvroSchemaUtil.getFieldId(field) == MetadataColumns.IS_DELETED.fieldId()) {
+        } else if (Objects.equals(
+            AvroSchemaUtil.fieldId(field), MetadataColumns.IS_DELETED.fieldId())) {
           isDeletedColumnPos = pos;
         }
       }
@@ -622,19 +952,12 @@ public class ValueReaders {
     @Override
     public void setRowPositionSupplier(Supplier<Long> posSupplier) {
       if (posField >= 0) {
-        long startingPos = posSupplier.get();
-        this.readers[posField] = new PositionReader(startingPos);
-        for (ValueReader<?> reader : readers) {
-          if (reader instanceof SupportsRowPosition) {
-            ((SupportsRowPosition) reader).setRowPositionSupplier(() -> startingPos);
-          }
-        }
+        this.readers[posField] = new PositionReader();
+      }
 
-      } else {
-        for (ValueReader<?> reader : readers) {
-          if (reader instanceof SupportsRowPosition) {
-            ((SupportsRowPosition) reader).setRowPositionSupplier(posSupplier);
-          }
+      for (ValueReader<?> reader : readers) {
+        if (reader instanceof SupportsRowPosition) {
+          ((SupportsRowPosition) reader).setRowPositionSupplier(posSupplier);
         }
       }
     }
@@ -739,17 +1062,21 @@ public class ValueReaders {
     }
   }
 
-  static class PositionReader implements ValueReader<Long> {
-    private long currentPosition;
-
-    PositionReader(long rowPosition) {
-      this.currentPosition = rowPosition - 1;
-    }
+  static class PositionReader implements ValueReader<Long>, SupportsRowPosition {
+    private long currentPosition = 0;
 
     @Override
     public Long read(Decoder ignored, Object reuse) throws IOException {
-      currentPosition += 1;
+      this.currentPosition += 1;
       return currentPosition;
     }
+
+    @Override
+    public void skip(Decoder ignored) throws IOException {}
+
+    @Override
+    public void setRowPositionSupplier(Supplier<Long> posSupplier) {
+      this.currentPosition = posSupplier.get() - 1;
+    }
   }
 }
