@@ -27,12 +27,14 @@ import java.time.OffsetDateTime;
 import java.time.ZoneOffset;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.stream.Collectors;
 import org.apache.iceberg.BaseMetadataTable;
 import org.apache.iceberg.BaseTable;
 import org.apache.iceberg.BaseTransaction;
+import org.apache.iceberg.MetadataUpdate.UpgradeFormatVersion;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.SortOrder;
@@ -80,6 +82,7 @@ import org.apache.iceberg.view.ViewRepresentation;
 
 public class CatalogHandlers {
   private static final Schema EMPTY_SCHEMA = new Schema();
+  private static final String INTIAL_PAGE_TOKEN = "";
 
   private CatalogHandlers() {}
 
@@ -117,6 +120,29 @@ public class CatalogHandlers {
     return ListNamespacesResponse.builder().addAll(results).build();
   }
 
+  public static ListNamespacesResponse listNamespaces(
+      SupportsNamespaces catalog, Namespace parent, String pageToken, String pageSize) {
+    List<Namespace> results;
+    List<Namespace> subResults;
+
+    if (parent.isEmpty()) {
+      results = catalog.listNamespaces();
+    } else {
+      results = catalog.listNamespaces(parent);
+    }
+
+    int start = INTIAL_PAGE_TOKEN.equals(pageToken) ? 0 : Integer.parseInt(pageToken);
+    int end = start + Integer.parseInt(pageSize);
+    subResults = results.subList(start, end);
+    String nextToken = String.valueOf(end);
+
+    if (end >= results.size()) {
+      nextToken = null;
+    }
+
+    return ListNamespacesResponse.builder().addAll(subResults).nextPageToken(nextToken).build();
+  }
+
   public static CreateNamespaceResponse createNamespace(
       SupportsNamespaces catalog, CreateNamespaceRequest request) {
     Namespace namespace = request.namespace();
@@ -174,6 +200,23 @@ public class CatalogHandlers {
     return ListTablesResponse.builder().addAll(idents).build();
   }
 
+  public static ListTablesResponse listTables(
+      Catalog catalog, Namespace namespace, String pageToken, String pageSize) {
+    List<TableIdentifier> results = catalog.listTables(namespace);
+    List<TableIdentifier> subResults;
+
+    int start = INTIAL_PAGE_TOKEN.equals(pageToken) ? 0 : Integer.parseInt(pageToken);
+    int end = start + Integer.parseInt(pageSize);
+    subResults = results.subList(start, end);
+    String nextToken = String.valueOf(end);
+
+    if (end >= results.size()) {
+      nextToken = null;
+    }
+
+    return ListTablesResponse.builder().addAll(subResults).nextPageToken(nextToken).build();
+  }
+
   public static LoadTableResponse stageTableCreate(
       Catalog catalog, Namespace namespace, CreateTableRequest request) {
     request.validate();
@@ -332,10 +375,15 @@ public class CatalogHandlers {
   private static TableMetadata create(TableOperations ops, UpdateTableRequest request) {
     // the only valid requirement is that the table will be created
     request.requirements().forEach(requirement -> requirement.validate(ops.current()));
+    Optional<Integer> formatVersion =
+        request.updates().stream()
+            .filter(update -> update instanceof UpgradeFormatVersion)
+            .map(update -> ((UpgradeFormatVersion) update).formatVersion())
+            .findFirst();
 
-    TableMetadata.Builder builder = TableMetadata.buildFromEmpty();
+    TableMetadata.Builder builder =
+        formatVersion.map(TableMetadata::buildFromEmpty).orElseGet(TableMetadata::buildFromEmpty);
     request.updates().forEach(update -> update.applyTo(builder));
-
     // create transactions do not retry. if the table exists, retrying is not a solution
     ops.commit(null, builder.build());
 
@@ -397,6 +445,23 @@ public class CatalogHandlers {
     return ListTablesResponse.builder().addAll(catalog.listViews(namespace)).build();
   }
 
+  public static ListTablesResponse listViews(
+      ViewCatalog catalog, Namespace namespace, String pageToken, String pageSize) {
+    List<TableIdentifier> results = catalog.listViews(namespace);
+    List<TableIdentifier> subResults;
+
+    int start = INTIAL_PAGE_TOKEN.equals(pageToken) ? 0 : Integer.parseInt(pageToken);
+    int end = start + Integer.parseInt(pageSize);
+    subResults = results.subList(start, end);
+    String nextToken = String.valueOf(end);
+
+    if (end >= results.size()) {
+      nextToken = null;
+    }
+
+    return ListTablesResponse.builder().addAll(subResults).nextPageToken(nextToken).build();
+  }
+
   public static LoadViewResponse createView(
       ViewCatalog catalog, Namespace namespace, CreateViewRequest request) {
     request.validate();
