@@ -55,6 +55,8 @@ import org.apache.iceberg.rest.requests.ReportMetricsRequest;
 import org.apache.iceberg.rest.requests.ReportMetricsRequestParser;
 import org.apache.iceberg.rest.requests.UpdateTableRequest;
 import org.apache.iceberg.rest.requests.UpdateTableRequestParser;
+import org.apache.iceberg.rest.responses.ConfigResponse;
+import org.apache.iceberg.rest.responses.ConfigResponseParser;
 import org.apache.iceberg.rest.responses.ErrorResponse;
 import org.apache.iceberg.rest.responses.ErrorResponseParser;
 import org.apache.iceberg.rest.responses.ImmutableLoadViewResponse;
@@ -111,7 +113,9 @@ public class RESTSerializers {
         .addSerializer(LoadViewResponse.class, new LoadViewResponseSerializer<>())
         .addSerializer(ImmutableLoadViewResponse.class, new LoadViewResponseSerializer<>())
         .addDeserializer(LoadViewResponse.class, new LoadViewResponseDeserializer<>())
-        .addDeserializer(ImmutableLoadViewResponse.class, new LoadViewResponseDeserializer<>());
+        .addDeserializer(ImmutableLoadViewResponse.class, new LoadViewResponseDeserializer<>())
+        .addSerializer(ConfigResponse.class, new ConfigResponseSerializer<>())
+        .addDeserializer(ConfigResponse.class, new ConfigResponseDeserializer<>());
 
     mapper.registerModule(module);
   }
@@ -402,4 +406,20 @@ public class RESTSerializers {
       return (T) LoadViewResponseParser.fromJson(jsonNode);
     }
   }
+
+  static class ConfigResponseSerializer<T extends ConfigResponse> extends JsonSerializer<T> {
+    @Override
+    public void serialize(T request, JsonGenerator gen, SerializerProvider serializers)
+        throws IOException {
+      ConfigResponseParser.toJson(request, gen);
+    }
+  }
+
+  static class ConfigResponseDeserializer<T extends ConfigResponse> extends JsonDeserializer<T> {
+    @Override
+    public T deserialize(JsonParser p, DeserializationContext context) throws IOException {
+      JsonNode jsonNode = p.getCodec().readTree(p);
+      return (T) ConfigResponseParser.fromJson(jsonNode);
+    }
+  }
 }
