@@ -40,6 +40,7 @@ import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.base.Splitter;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.rest.ErrorHandlers;
 import org.apache.iceberg.rest.RESTClient;
@@ -129,18 +130,40 @@ public class OAuth2Util {
     return SCOPE_JOINER.join(scopes);
   }
 
+  public static Map<String, String> buildOptionalParam(Map<String, String> properties) {
+    // these are some options oauth params based on specification
+    // for any new optional oauth param, define the constant and add the constant to this list
+    Set<String> optionalParamKeys =
+        ImmutableSet.of(OAuth2Properties.AUDIENCE, OAuth2Properties.RESOURCE);
+    ImmutableMap.Builder<String, String> optionalParamBuilder = ImmutableMap.builder();
+    // add scope too,
+    optionalParamBuilder.put(
+        OAuth2Properties.SCOPE,
+        properties.getOrDefault(OAuth2Properties.SCOPE, OAuth2Properties.CATALOG_SCOPE));
+    // add all other parameters
+    for (String key : optionalParamKeys) {
+      String value = properties.get(key);
+      if (value != null) {
+        optionalParamBuilder.put(key, value);
+      }
+    }
+    return optionalParamBuilder.buildKeepingLast();
+  }
+
   private static OAuthTokenResponse refreshToken(
       RESTClient client,
       Map<String, String> headers,
       String subjectToken,
       String subjectTokenType,
       String scope,
-      String oauth2ServerUri) {
+      String oauth2ServerUri,
+      Map<String, String> optionalOAuthParams) {
     Map<String, String> request =
         tokenExchangeRequest(
             subjectToken,
             subjectTokenType,
-            scope != null ? ImmutableList.of(scope) : ImmutableList.of());
+            scope != null ? ImmutableList.of(scope) : ImmutableList.of(),
+            optionalOAuthParams);
 
     OAuthTokenResponse response =
         client.postForm(
@@ -162,14 +185,16 @@ public class OAuth2Util {
       String actorToken,
       String actorTokenType,
       String scope,
-      String oauth2ServerUri) {
+      String oauth2ServerUri,
+      Map<String, String> optionalParams) {
     Map<String, String> request =
         tokenExchangeRequest(
             subjectToken,
             subjectTokenType,
             actorToken,
             actorTokenType,
-            scope != null ? ImmutableList.of(scope) : ImmutableList.of());
+            scope != null ? ImmutableList.of(scope) : ImmutableList.of(),
+            optionalParams);
 
     OAuthTokenResponse response =
         client.postForm(
@@ -199,7 +224,29 @@ public class OAuth2Util {
         actorToken,
         actorTokenType,
         scope,
-        ResourcePaths.tokens());
+        ResourcePaths.tokens(),
+        ImmutableMap.of());
+  }
+
+  public static OAuthTokenResponse exchangeToken(
+      RESTClient client,
+      Map<String, String> headers,
+      String subjectToken,
+      String subjectTokenType,
+      String actorToken,
+      String actorTokenType,
+      String scope,
+      String oauth2ServerUri) {
+    return exchangeToken(
+        client,
+        headers,
+        subjectToken,
+        subjectTokenType,
+        actorToken,
+        actorTokenType,
+        scope,
+        oauth2ServerUri,
+        ImmutableMap.of());
   }
 
   public static OAuthTokenResponse fetchToken(
@@ -207,10 +254,13 @@ public class OAuth2Util {
       Map<String, String> headers,
       String credential,
       String scope,
-      String oauth2ServerUri) {
+      String oauth2ServerUri,
+      Map<String, String> optionalParams) {
     Map<String, String> request =
         clientCredentialsRequest(
-            credential, scope != null ? ImmutableList.of(scope) : ImmutableList.of());
+            credential,
+            scope != null ? ImmutableList.of(scope) : ImmutableList.of(),
+            optionalParams);
 
     OAuthTokenResponse response =
         client.postForm(
@@ -227,12 +277,27 @@ public class OAuth2Util {
   public static OAuthTokenResponse fetchToken(
       RESTClient client, Map<String, String> headers, String credential, String scope) {
 
-    return fetchToken(client, headers, credential, scope, ResourcePaths.tokens());
+    return fetchToken(
+        client, headers, credential, scope, ResourcePaths.tokens(), ImmutableMap.of());
+  }
+
+  public static OAuthTokenResponse fetchToken(
+      RESTClient client,
+      Map<String, String> headers,
+      String credential,
+      String scope,
+      String oauth2ServerUri) {
+
+    return fetchToken(client, headers, credential, scope, oauth2ServerUri, ImmutableMap.of());
   }
 
   private static Map<String, String> tokenExchangeRequest(
-      String subjectToken, String subjectTokenType, List<String> scopes) {
-    return tokenExchangeRequest(subjectToken, subjectTokenType, null, null, scopes);
+      String subjectToken,
+      String subjectTokenType,
+      List<String> scopes,
+      Map<String, String> optionalOAuthParams) {
+    return tokenExchangeRequest(
+        subjectToken, subjectTokenType, null, null, scopes, optionalOAuthParams);
   }
 
   private static Map<String, String> tokenExchangeRequest(
@@ -240,7 +305,8 @@ public class OAuth2Util {
       String subjectTokenType,
       String actorToken,
       String actorTokenType,
-      List<String> scopes) {
+      List<String> scopes,
+      Map<String, String> optionalParams) {
     Preconditions.checkArgument(
         VALID_TOKEN_TYPES.contains(subjectTokenType), "Invalid token type: %s", subjectTokenType);
     Preconditions.checkArgument(
@@ -257,8 +323,9 @@ public class OAuth2Util {
       formData.put(ACTOR_TOKEN, actorToken);
       formData.put(ACTOR_TOKEN_TYPE, actorTokenType);
     }
+    formData.putAll(optionalParams);
 
-    return formData.build();
+    return formData.buildKeepingLast();
   }
 
   private static Pair<String, String> parseCredential(String credential) {
@@ -278,13 +345,17 @@ public class OAuth2Util {
   }
 
   private static Map<String, String> clientCredentialsRequest(
-      String credential, List<String> scopes) {
+      String credential, List<String> scopes, Map<String, String> optionalOAuthParams) {
     Pair<String, String> credentialPair = parseCredential(credential);
-    return clientCredentialsRequest(credentialPair.first(), credentialPair.second(), scopes);
+    return clientCredentialsRequest(
+        credentialPair.first(), credentialPair.second(), scopes, optionalOAuthParams);
   }
 
   private static Map<String, String> clientCredentialsRequest(
-      String clientId, String clientSecret, List<String> scopes) {
+      String clientId,
+      String clientSecret,
+      List<String> scopes,
+      Map<String, String> optionalOAuthParams) {
     ImmutableMap.Builder<String, String> formData = ImmutableMap.builder();
     formData.put(GRANT_TYPE, CLIENT_CREDENTIALS);
     if (clientId != null) {
@@ -292,8 +363,9 @@ public class OAuth2Util {
     }
     formData.put(CLIENT_SECRET, clientSecret);
     formData.put(SCOPE, toScope(scopes));
+    formData.putAll(optionalOAuthParams);
 
-    return formData.build();
+    return formData.buildKeepingLast();
   }
 
   public static String tokenResponseToJson(OAuthTokenResponse response) {
@@ -386,14 +458,15 @@ public class OAuth2Util {
     private static final long MAX_REFRESH_WINDOW_MILLIS = 300_000; // 5 minutes
     private static final long MIN_REFRESH_WAIT_MILLIS = 10;
     private volatile Map<String, String> headers;
-    private volatile String token;
-    private volatile String tokenType;
-    private volatile Long expiresAtMillis;
-    private final String credential;
-    private final String scope;
-    private volatile boolean keepRefreshed = true;
-    private final String oauth2ServerUri;
+    private volatile AuthConfig config;
 
+    public AuthSession(Map<String, String> baseHeaders, AuthConfig config) {
+      this.headers = RESTUtil.merge(baseHeaders, authHeaders(config.token()));
+      this.config = config;
+    }
+
+    /** @deprecated since 1.6.0, will be removed in 1.7.0 */
+    @Deprecated
     public AuthSession(
         Map<String, String> baseHeaders,
         String token,
@@ -401,30 +474,15 @@ public class OAuth2Util {
         String credential,
         String scope,
         String oauth2ServerUri) {
-      this.headers = RESTUtil.merge(baseHeaders, authHeaders(token));
-      this.token = token;
-      this.tokenType = tokenType;
-      this.expiresAtMillis = OAuth2Util.expiresAtMillis(token);
-      this.credential = credential;
-      this.scope = scope;
-      this.oauth2ServerUri = oauth2ServerUri;
-    }
-
-    /** @deprecated since 1.5.0, will be removed in 1.6.0 */
-    @Deprecated
-    public AuthSession(
-        Map<String, String> baseHeaders,
-        String token,
-        String tokenType,
-        String credential,
-        String scope) {
-      this.headers = RESTUtil.merge(baseHeaders, authHeaders(token));
-      this.token = token;
-      this.tokenType = tokenType;
-      this.expiresAtMillis = OAuth2Util.expiresAtMillis(token);
-      this.credential = credential;
-      this.scope = scope;
-      this.oauth2ServerUri = ResourcePaths.tokens();
+      this(
+          baseHeaders,
+          AuthConfig.builder()
+              .token(token)
+              .tokenType(tokenType)
+              .credential(credential)
+              .scope(scope)
+              .oauth2ServerUri(oauth2ServerUri)
+              .build());
     }
 
     public Map<String, String> headers() {
@@ -432,31 +490,39 @@ public class OAuth2Util {
     }
 
     public String token() {
-      return token;
+      return config.token();
     }
 
     public String tokenType() {
-      return tokenType;
+      return config.tokenType();
     }
 
     public Long expiresAtMillis() {
-      return expiresAtMillis;
+      return config.expiresAtMillis();
     }
 
     public String scope() {
-      return scope;
+      return config.scope();
     }
 
-    public void stopRefreshing() {
-      this.keepRefreshed = false;
+    public synchronized void stopRefreshing() {
+      this.config = ImmutableAuthConfig.copyOf(config).withKeepRefreshed(false);
     }
 
     public String credential() {
-      return credential;
+      return config.credential();
     }
 
     public String oauth2ServerUri() {
-      return oauth2ServerUri;
+      return config.oauth2ServerUri();
+    }
+
+    public Map<String, String> optionalOAuthParams() {
+      return config.optionalOAuthParams();
+    }
+
+    public AuthConfig config() {
+      return config;
     }
 
     @VisibleForTesting
@@ -470,8 +536,7 @@ public class OAuth2Util {
      * @return A new {@link AuthSession} with empty headers.
      */
     public static AuthSession empty() {
-      return new AuthSession(
-          ImmutableMap.of(), null, null, null, OAuth2Properties.CATALOG_SCOPE, null);
+      return new AuthSession(ImmutableMap.of(), AuthConfig.builder().build());
     }
 
     /**
@@ -481,7 +546,7 @@ public class OAuth2Util {
      * @return interval to wait before calling refresh again, or null if no refresh is needed
      */
     public Pair<Integer, TimeUnit> refresh(RESTClient client) {
-      if (token != null && keepRefreshed) {
+      if (token() != null && config.keepRefreshed()) {
         AtomicReference<OAuthTokenResponse> ref = new AtomicReference<>(null);
         boolean isSuccessful =
             Tasks.foreach(ref)
@@ -507,10 +572,14 @@ public class OAuth2Util {
         }
 
         OAuthTokenResponse response = ref.get();
-        this.token = response.token();
-        this.tokenType = response.issuedTokenType();
-        this.expiresAtMillis = OAuth2Util.expiresAtMillis(token);
-        this.headers = RESTUtil.merge(headers, authHeaders(token));
+        this.config =
+            AuthConfig.builder()
+                .from(config())
+                .token(response.token())
+                .tokenType(response.issuedTokenType())
+                .build();
+        Map<String, String> currentHeaders = this.headers;
+        this.headers = RESTUtil.merge(currentHeaders, authHeaders(config.token()));
 
         if (response.expiresInSeconds() != null) {
           return Pair.of(response.expiresInSeconds(), TimeUnit.SECONDS);
@@ -521,19 +590,34 @@ public class OAuth2Util {
     }
 
     private OAuthTokenResponse refreshCurrentToken(RESTClient client) {
-      if (null != expiresAtMillis && expiresAtMillis <= System.currentTimeMillis()) {
+      if (null != expiresAtMillis() && expiresAtMillis() <= System.currentTimeMillis()) {
         // the token has already expired, attempt to refresh using the credential
         return refreshExpiredToken(client);
       } else {
         // attempt a normal refresh
-        return refreshToken(client, headers(), token, tokenType, scope, oauth2ServerUri);
+        return refreshToken(
+            client,
+            headers(),
+            token(),
+            tokenType(),
+            scope(),
+            oauth2ServerUri(),
+            optionalOAuthParams());
       }
     }
 
     private OAuthTokenResponse refreshExpiredToken(RESTClient client) {
-      if (credential != null) {
-        Map<String, String> basicHeaders = RESTUtil.merge(headers(), basicAuthHeaders(credential));
-        return refreshToken(client, basicHeaders, token, tokenType, scope, oauth2ServerUri);
+      if (credential() != null) {
+        Map<String, String> basicHeaders =
+            RESTUtil.merge(headers(), basicAuthHeaders(credential()));
+        return refreshToken(
+            client,
+            basicHeaders,
+            token(),
+            tokenType(),
+            scope(),
+            oauth2ServerUri(),
+            optionalOAuthParams());
       }
 
       return null;
@@ -586,11 +670,11 @@ public class OAuth2Util {
       AuthSession session =
           new AuthSession(
               parent.headers(),
-              token,
-              OAuth2Properties.ACCESS_TOKEN_TYPE,
-              parent.credential(),
-              parent.scope(),
-              parent.oauth2ServerUri());
+              AuthConfig.builder()
+                  .from(parent.config())
+                  .token(token)
+                  .tokenType(OAuth2Properties.ACCESS_TOKEN_TYPE)
+                  .build());
 
       long startTimeMillis = System.currentTimeMillis();
       Long expiresAtMillis = session.expiresAtMillis();
@@ -629,7 +713,12 @@ public class OAuth2Util {
       long startTimeMillis = System.currentTimeMillis();
       OAuthTokenResponse response =
           fetchToken(
-              client, parent.headers(), credential, parent.scope(), parent.oauth2ServerUri());
+              client,
+              parent.headers(),
+              credential,
+              parent.scope(),
+              parent.oauth2ServerUri(),
+              parent.optionalOAuthParams());
       return fromTokenResponse(client, executor, response, startTimeMillis, parent, credential);
     }
 
@@ -650,14 +739,23 @@ public class OAuth2Util {
         long startTimeMillis,
         AuthSession parent,
         String credential) {
+      // issued_token_type is required in RFC 8693 but not in RFC 6749,
+      // thus assume type is access_token for compatibility with RFC 6749.
+      // See https://datatracker.ietf.org/doc/html/rfc6749#section-4.4.3
+      // for an example of a response that does not include the issued token type.
+      String issuedTokenType = response.issuedTokenType();
+      if (issuedTokenType == null) {
+        issuedTokenType = OAuth2Properties.ACCESS_TOKEN_TYPE;
+      }
       AuthSession session =
           new AuthSession(
               parent.headers(),
-              response.token(),
-              response.issuedTokenType(),
-              credential,
-              parent.scope(),
-              parent.oauth2ServerUri());
+              AuthConfig.builder()
+                  .from(parent.config())
+                  .token(response.token())
+                  .tokenType(issuedTokenType)
+                  .credential(credential)
+                  .build());
 
       Long expiresAtMillis = session.expiresAtMillis();
       if (null == expiresAtMillis && response.expiresInSeconds() != null) {
@@ -687,7 +785,8 @@ public class OAuth2Util {
               parent.token(),
               parent.tokenType(),
               parent.scope(),
-              parent.oauth2ServerUri());
+              parent.oauth2ServerUri(),
+              parent.optionalOAuthParams());
       return fromTokenResponse(client, executor, response, startTimeMillis, parent);
     }
   }
