@@ -19,30 +19,29 @@
 package org.apache.iceberg;
 
 import static org.apache.iceberg.util.SnapshotUtil.latestSnapshot;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
 
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
+import java.util.Arrays;
 import java.util.List;
 import java.util.stream.Collectors;
 import org.apache.iceberg.ManifestEntry.Status;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.expressions.Expressions;
-import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.StructLikeWrapper;
-import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Assume;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(Parameterized.class)
-public class TestDeleteFiles extends TableTestBase {
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestDeleteFiles extends TestBase {
 
   private static final DataFile DATA_FILE_BUCKET_0_IDS_0_2 =
       DataFiles.builder(SPEC)
@@ -78,36 +77,31 @@ public class TestDeleteFiles extends TableTestBase {
                   ))
           .build();
 
-  private final String branch;
+  @Parameter(index = 1)
+  private String branch;
 
-  @Parameterized.Parameters(name = "formatVersion = {0}, branch = {1}")
-  public static Object[] parameters() {
-    return new Object[][] {
-      new Object[] {1, "main"},
-      new Object[] {1, "testBranch"},
-      new Object[] {2, "main"},
-      new Object[] {2, "testBranch"}
-    };
+  @Parameters(name = "formatVersion = {0}, branch = {1}")
+  protected static List<Object> parameters() {
+    return Arrays.asList(
+        new Object[] {1, "main"},
+        new Object[] {1, "testBranch"},
+        new Object[] {2, "main"},
+        new Object[] {2, "testBranch"});
   }
 
-  public TestDeleteFiles(int formatVersion, String branch) {
-    super(formatVersion);
-    this.branch = branch;
-  }
-
-  @Test
+  @TestTemplate
   public void testMultipleDeletes() {
     commit(
         table, table.newAppend().appendFile(FILE_A).appendFile(FILE_B).appendFile(FILE_C), branch);
     Snapshot append = latestSnapshot(readMetadata(), branch);
-    Assert.assertEquals("Metadata should be at version 1", 1L, (long) version());
+    assertThat(version()).isEqualTo(1);
     validateSnapshot(null, append, FILE_A, FILE_B, FILE_C);
 
     commit(table, table.newDelete().deleteFile(FILE_A), branch);
     Snapshot delete1 = latestSnapshot(readMetadata(), branch);
 
-    Assert.assertEquals("Metadata should be at version 2", 2L, (long) version());
-    Assert.assertEquals("Should have 1 manifest", 1, delete1.allManifests(FILE_IO).size());
+    assertThat(version()).isEqualTo(2);
+    assertThat(delete1.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         delete1.allManifests(table.io()).get(0),
         ids(delete1.snapshotId(), append.snapshotId(), append.snapshotId()),
@@ -115,8 +109,8 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.DELETED, Status.EXISTING, Status.EXISTING));
 
     Snapshot delete2 = commit(table, table.newDelete().deleteFile(FILE_B), branch);
-    Assert.assertEquals("Metadata should be at version 3", 3L, (long) version());
-    Assert.assertEquals("Should have 1 manifest", 1, delete2.allManifests(FILE_IO).size());
+    assertThat(version()).isEqualTo(3);
+    assertThat(delete2.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         delete2.allManifests(FILE_IO).get(0),
         ids(delete2.snapshotId(), append.snapshotId()),
@@ -124,7 +118,7 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.DELETED, Status.EXISTING));
   }
 
-  @Test
+  @TestTemplate
   public void testAlreadyDeletedFilesAreIgnoredDuringDeletesByRowFilter() {
     PartitionSpec spec = table.spec();
 
@@ -169,7 +163,7 @@ public class TestDeleteFiles extends TableTestBase {
             table.newFastAppend().appendFile(firstDataFile).appendFile(secondDataFile),
             branch);
 
-    Assert.assertEquals("Should have 1 manifest", 1, initialSnapshot.allManifests(FILE_IO).size());
+    assertThat(initialSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         initialSnapshot.allManifests(FILE_IO).get(0),
         ids(initialSnapshot.snapshotId(), initialSnapshot.snapshotId()),
@@ -178,7 +172,7 @@ public class TestDeleteFiles extends TableTestBase {
 
     // delete the first data file
     Snapshot deleteSnapshot = commit(table, table.newDelete().deleteFile(firstDataFile), branch);
-    Assert.assertEquals("Should have 1 manifest", 1, deleteSnapshot.allManifests(FILE_IO).size());
+    assertThat(deleteSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         deleteSnapshot.allManifests(FILE_IO).get(0),
         ids(deleteSnapshot.snapshotId(), initialSnapshot.snapshotId()),
@@ -190,7 +184,7 @@ public class TestDeleteFiles extends TableTestBase {
     Snapshot finalSnapshot =
         commit(table, table.newDelete().deleteFromRowFilter(Expressions.lessThan("id", 7)), branch);
 
-    Assert.assertEquals("Should have 1 manifest", 1, finalSnapshot.allManifests(FILE_IO).size());
+    assertThat(finalSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         finalSnapshot.allManifests(FILE_IO).get(0),
         ids(finalSnapshot.snapshotId()),
@@ -198,7 +192,7 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.DELETED));
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteSomeFilesByRowFilterWithoutPartitionPredicates() {
     // add both data files
     Snapshot initialSnapshot =
@@ -210,7 +204,7 @@ public class TestDeleteFiles extends TableTestBase {
                 .appendFile(DATA_FILE_BUCKET_0_IDS_8_10),
             branch);
 
-    Assert.assertEquals("Should have 1 manifest", 1, initialSnapshot.allManifests(FILE_IO).size());
+    assertThat(initialSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         initialSnapshot.allManifests(FILE_IO).get(0),
         ids(initialSnapshot.snapshotId(), initialSnapshot.snapshotId()),
@@ -222,7 +216,7 @@ public class TestDeleteFiles extends TableTestBase {
         commit(
             table, table.newDelete().deleteFromRowFilter(Expressions.greaterThan("id", 5)), branch);
 
-    Assert.assertEquals("Should have 1 manifest", 1, deleteSnapshot.allManifests(FILE_IO).size());
+    assertThat(deleteSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         deleteSnapshot.allManifests(FILE_IO).get(0),
         ids(initialSnapshot.snapshotId(), deleteSnapshot.snapshotId()),
@@ -230,7 +224,7 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.EXISTING, Status.DELETED));
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteSomeFilesByRowFilterWithCombinedPredicates() {
     // add both data files
     Snapshot initialSnapshot =
@@ -242,7 +236,7 @@ public class TestDeleteFiles extends TableTestBase {
                 .appendFile(DATA_FILE_BUCKET_0_IDS_8_10),
             branch);
 
-    Assert.assertEquals("Should have 1 manifest", 1, initialSnapshot.allManifests(FILE_IO).size());
+    assertThat(initialSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         initialSnapshot.allManifests(FILE_IO).get(0),
         ids(initialSnapshot.snapshotId(), initialSnapshot.snapshotId()),
@@ -255,7 +249,7 @@ public class TestDeleteFiles extends TableTestBase {
     Expression predicate = Expressions.and(partPredicate, rowPredicate);
     Snapshot deleteSnapshot =
         commit(table, table.newDelete().deleteFromRowFilter(predicate), branch);
-    Assert.assertEquals("Should have 1 manifest", 1, deleteSnapshot.allManifests(FILE_IO).size());
+    assertThat(deleteSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         deleteSnapshot.allManifests(FILE_IO).get(0),
         ids(initialSnapshot.snapshotId(), deleteSnapshot.snapshotId()),
@@ -263,9 +257,9 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.EXISTING, Status.DELETED));
   }
 
-  @Test
+  @TestTemplate
   public void testCannotDeleteFileWhereNotAllRowsMatchPartitionFilter() {
-    Assume.assumeTrue(formatVersion == 2);
+    assumeThat(formatVersion).isEqualTo(2);
 
     table
         .updateSpec()
@@ -285,7 +279,7 @@ public class TestDeleteFiles extends TableTestBase {
 
     commit(table, table.newFastAppend().appendFile(dataFile), branch);
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 commit(
                     table,
@@ -295,18 +289,18 @@ public class TestDeleteFiles extends TableTestBase {
         .hasMessageStartingWith("Cannot delete file where some, but not all, rows match filter");
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteCaseSensitivity() {
     commit(table, table.newFastAppend().appendFile(DATA_FILE_BUCKET_0_IDS_0_2), branch);
 
     Expression rowFilter = Expressions.lessThan("iD", 5);
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> commit(table, table.newDelete().deleteFromRowFilter(rowFilter), branch))
         .isInstanceOf(ValidationException.class)
         .hasMessageStartingWith("Cannot find field 'iD'");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 commit(
                     table,
@@ -319,7 +313,7 @@ public class TestDeleteFiles extends TableTestBase {
         commit(
             table, table.newDelete().deleteFromRowFilter(rowFilter).caseSensitive(false), branch);
 
-    Assert.assertEquals("Should have 1 manifest", 1, deleteSnapshot.allManifests(FILE_IO).size());
+    assertThat(deleteSnapshot.allManifests(FILE_IO)).hasSize(1);
     validateManifestEntries(
         deleteSnapshot.allManifests(FILE_IO).get(0),
         ids(deleteSnapshot.snapshotId()),
@@ -327,7 +321,7 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.DELETED));
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteFilesOnIndependentBranches() {
     String testBranch = "testBranch";
     table.newAppend().appendFile(FILE_A).appendFile(FILE_B).appendFile(FILE_C).commit();
@@ -355,7 +349,7 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.EXISTING, Status.DELETED, Status.DELETED));
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteWithCollision() {
     Schema schema = new Schema(Types.NestedField.of(0, false, "x", Types.StringType.get()));
     PartitionSpec spec = PartitionSpec.builderFor(schema).identity("x").build();
@@ -367,9 +361,8 @@ public class TestDeleteFiles extends TableTestBase {
     PartitionData partitionTwo = new PartitionData(spec.partitionType());
     partitionTwo.set(0, "BB");
 
-    Assert.assertEquals(
-        StructLikeWrapper.forType(spec.partitionType()).set(partitionOne).hashCode(),
-        StructLikeWrapper.forType(spec.partitionType()).set(partitionTwo).hashCode());
+    assertThat(StructLikeWrapper.forType(spec.partitionType()).set(partitionTwo).hashCode())
+        .isEqualTo(StructLikeWrapper.forType(spec.partitionType()).set(partitionOne).hashCode());
 
     DataFile testFileOne =
         DataFiles.builder(spec)
@@ -394,10 +387,7 @@ public class TestDeleteFiles extends TableTestBase {
             .map(s -> ((PartitionData) s.partition()).copy())
             .collect(Collectors.toList());
 
-    Assert.assertEquals(
-        "We should have both partitions",
-        ImmutableList.of(partitionOne, partitionTwo),
-        beforeDeletePartitions);
+    assertThat(beforeDeletePartitions).containsExactly(partitionOne, partitionTwo);
 
     collisionTable.newDelete().deleteFromRowFilter(Expressions.equal("x", "BB")).commit();
 
@@ -406,13 +396,10 @@ public class TestDeleteFiles extends TableTestBase {
             .map(s -> ((PartitionData) s.partition()).copy())
             .collect(Collectors.toList());
 
-    Assert.assertEquals(
-        "We should have deleted partitionTwo",
-        ImmutableList.of(partitionOne),
-        afterDeletePartitions);
+    assertThat(afterDeletePartitions).containsExactly(partitionOne);
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteValidateFileExistence() {
     commit(table, table.newFastAppend().appendFile(FILE_B), branch);
     Snapshot delete =
@@ -423,12 +410,12 @@ public class TestDeleteFiles extends TableTestBase {
         files(FILE_B),
         statuses(Status.DELETED));
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> commit(table, table.newDelete().deleteFile(FILE_B).validateFilesExist(), branch))
         .isInstanceOf(ValidationException.class);
   }
 
-  @Test
+  @TestTemplate
   public void testDeleteFilesNoValidation() {
     commit(table, table.newFastAppend().appendFile(FILE_B), branch);
     Snapshot delete1 = commit(table, table.newDelete().deleteFile(FILE_B), branch);
@@ -439,8 +426,8 @@ public class TestDeleteFiles extends TableTestBase {
         statuses(Status.DELETED));
 
     Snapshot delete2 = commit(table, table.newDelete().deleteFile(FILE_B), branch);
-    Assertions.assertThat(delete2.allManifests(FILE_IO).isEmpty()).isTrue();
-    Assertions.assertThat(delete2.removedDataFiles(FILE_IO).iterator().hasNext()).isFalse();
+    assertThat(delete2.allManifests(FILE_IO)).isEmpty();
+    assertThat(delete2.removedDataFiles(FILE_IO)).isEmpty();
   }
 
   private static ByteBuffer longToBuffer(long value) {
