@@ -18,8 +18,12 @@
  */
 package org.apache.iceberg;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.io.File;
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Set;
 import java.util.stream.Collectors;
@@ -28,31 +32,30 @@ import org.apache.iceberg.exceptions.CommitFailedException;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
-import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(Parameterized.class)
-public class TestFastAppend extends TableTestBase {
-  @Parameterized.Parameters(name = "formatVersion = {0}")
-  public static Object[] parameters() {
-    return new Object[] {1, 2};
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestFastAppend extends TestBase {
+  @Parameters(name = "formatVersion = {0}")
+  protected static List<Object> parameters() {
+    return Arrays.asList(1, 2);
   }
 
-  public TestFastAppend(int formatVersion) {
-    super(formatVersion);
+  @TestTemplate
+  public void appendNullFile() {
+    assertThatThrownBy(() -> table.newFastAppend().appendFile(null).commit())
+        .isInstanceOf(NullPointerException.class)
+        .hasMessage("Invalid data file: null");
   }
 
-  @Test
+  @TestTemplate
   public void testEmptyTableAppend() {
-    Assert.assertEquals("Table should start empty", 0, listManifestFiles().size());
+    assertThat(listManifestFiles()).isEmpty();
 
     TableMetadata base = readMetadata();
-    Assert.assertNull("Should not have a current snapshot", base.currentSnapshot());
-    Assert.assertEquals(
-        "Table should start with last-sequence-number 0", 0, base.lastSequenceNumber());
+    assertThat(base.currentSnapshot()).isNull();
+    assertThat(base.lastSequenceNumber()).isEqualTo(0);
 
     table.newFastAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
@@ -68,14 +71,13 @@ public class TestFastAppend extends TableTestBase {
         "Table should end with last-sequence-number 0", 0, base.lastSequenceNumber());
   }
 
-  @Test
+  @TestTemplate
   public void testEmptyTableAppendManifest() throws IOException {
-    Assert.assertEquals("Table should start empty", 0, listManifestFiles().size());
+    assertThat(listManifestFiles()).isEmpty();
 
     TableMetadata base = readMetadata();
-    Assert.assertNull("Should not have a current snapshot", base.currentSnapshot());
-    Assert.assertEquals(
-        "Table should start with last-sequence-number 0", 0, base.lastSequenceNumber());
+    assertThat(base.currentSnapshot()).isNull();
+    assertThat(base.lastSequenceNumber()).isEqualTo(0);
 
     ManifestFile manifest = writeManifest(FILE_A, FILE_B);
     table.newFastAppend().appendManifest(manifest).commit();
@@ -86,16 +88,13 @@ public class TestFastAppend extends TableTestBase {
 
     ManifestFile committedManifest = Iterables.getOnlyElement(snap.allManifests(FILE_IO));
     if (formatVersion == 1) {
-      Assertions.assertThat(committedManifest.path()).isNotEqualTo(manifest.path());
+      assertThat(committedManifest.path()).isNotEqualTo(manifest.path());
     } else {
-      Assertions.assertThat(committedManifest.path()).isEqualTo(manifest.path());
+      assertThat(committedManifest.path()).isEqualTo(manifest.path());
     }
 
     // validate that the metadata summary is correct when using appendManifest
-    Assert.assertEquals(
-        "Summary metadata should include 2 added files",
-        "2",
-        snap.summary().get("added-data-files"));
+    assertThat(snap.summary()).containsEntry("added-data-files", "2");
 
     V2Assert.assertEquals("Snapshot sequence number should be 1", 1, snap.sequenceNumber());
     V2Assert.assertEquals(
@@ -105,14 +104,13 @@ public class TestFastAppend extends TableTestBase {
         "Table should end with last-sequence-number 0", 0, base.lastSequenceNumber());
   }
 
-  @Test
+  @TestTemplate
   public void testEmptyTableAppendFilesAndManifest() throws IOException {
-    Assert.assertEquals("Table should start empty", 0, listManifestFiles().size());
+    assertThat(listManifestFiles()).isEmpty();
 
     TableMetadata base = readMetadata();
-    Assert.assertNull("Should not have a current snapshot", base.currentSnapshot());
-    Assert.assertEquals(
-        "Table should start with last-sequence-number 0", 0, base.lastSequenceNumber());
+    assertThat(base.currentSnapshot()).isNull();
+    assertThat(base.lastSequenceNumber()).isEqualTo(0);
 
     ManifestFile manifest = writeManifest(FILE_A, FILE_B);
     table.newFastAppend().appendFile(FILE_C).appendFile(FILE_D).appendManifest(manifest).commit();
@@ -135,9 +133,9 @@ public class TestFastAppend extends TableTestBase {
         files(FILE_A, FILE_B));
 
     if (formatVersion == 1) {
-      Assertions.assertThat(snap.allManifests(FILE_IO).get(1).path()).isNotEqualTo(manifest.path());
+      assertThat(snap.allManifests(FILE_IO).get(1).path()).isNotEqualTo(manifest.path());
     } else {
-      Assertions.assertThat(snap.allManifests(FILE_IO).get(1).path()).isEqualTo(manifest.path());
+      assertThat(snap.allManifests(FILE_IO).get(1).path()).isEqualTo(manifest.path());
     }
 
     V2Assert.assertEquals("Snapshot sequence number should be 1", 1, snap.sequenceNumber());
@@ -148,35 +146,32 @@ public class TestFastAppend extends TableTestBase {
         "Table should end with last-sequence-number 0", 0, base.lastSequenceNumber());
   }
 
-  @Test
+  @TestTemplate
   public void testNonEmptyTableAppend() {
     table.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
     TableMetadata base = readMetadata();
-    Assert.assertNotNull("Should have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNotNull();
     List<ManifestFile> v2manifests = base.currentSnapshot().allManifests(FILE_IO);
-    Assert.assertEquals("Should have one existing manifest", 1, v2manifests.size());
+    assertThat(v2manifests).hasSize(1);
 
     // prepare a new append
     Snapshot pending = table.newFastAppend().appendFile(FILE_C).appendFile(FILE_D).apply();
 
-    Assert.assertNotEquals(
-        "Snapshots should have unique IDs",
-        base.currentSnapshot().snapshotId(),
-        pending.snapshotId());
+    assertThat(pending.snapshotId()).isNotEqualTo(base.currentSnapshot().snapshotId());
     validateSnapshot(base.currentSnapshot(), pending, FILE_C, FILE_D);
   }
 
-  @Test
+  @TestTemplate
   public void testNoMerge() {
     table.newAppend().appendFile(FILE_A).commit();
 
     table.newFastAppend().appendFile(FILE_B).commit();
 
     TableMetadata base = readMetadata();
-    Assert.assertNotNull("Should have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNotNull();
     List<ManifestFile> v3manifests = base.currentSnapshot().allManifests(FILE_IO);
-    Assert.assertEquals("Should have 2 existing manifests", 2, v3manifests.size());
+    assertThat(v3manifests).hasSize(2);
 
     // prepare a new append
     Snapshot pending = table.newFastAppend().appendFile(FILE_C).appendFile(FILE_D).apply();
@@ -186,12 +181,12 @@ public class TestFastAppend extends TableTestBase {
       ids.add(snapshot.snapshotId());
     }
     ids.add(pending.snapshotId());
-    Assert.assertEquals("Snapshots should have 3 unique IDs", 3, ids.size());
+    assertThat(ids).hasSize(3);
 
     validateSnapshot(base.currentSnapshot(), pending, FILE_C, FILE_D);
   }
 
-  @Test
+  @TestTemplate
   public void testRefreshBeforeApply() {
     // load a new copy of the table that will not be refreshed by the commit
     Table stale = load();
@@ -199,9 +194,9 @@ public class TestFastAppend extends TableTestBase {
     table.newAppend().appendFile(FILE_A).commit();
 
     TableMetadata base = readMetadata();
-    Assert.assertNotNull("Should have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNotNull();
     List<ManifestFile> v2manifests = base.currentSnapshot().allManifests(FILE_IO);
-    Assert.assertEquals("Should have 1 existing manifest", 1, v2manifests.size());
+    assertThat(v2manifests).hasSize(1);
 
     // commit from the stale table
     AppendFiles append = stale.newFastAppend().appendFile(FILE_D);
@@ -211,7 +206,7 @@ public class TestFastAppend extends TableTestBase {
     validateSnapshot(base.currentSnapshot(), pending, FILE_D);
   }
 
-  @Test
+  @TestTemplate
   public void testRefreshBeforeCommit() {
     // commit from the stale table
     AppendFiles append = table.newFastAppend().appendFile(FILE_D);
@@ -222,9 +217,9 @@ public class TestFastAppend extends TableTestBase {
     table.newAppend().appendFile(FILE_A).commit();
 
     TableMetadata base = readMetadata();
-    Assert.assertNotNull("Should have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNotNull();
     List<ManifestFile> v2manifests = base.currentSnapshot().allManifests(FILE_IO);
-    Assert.assertEquals("Should have 1 existing manifest", 1, v2manifests.size());
+    assertThat(v2manifests).hasSize(1);
 
     append.commit();
 
@@ -236,13 +231,10 @@ public class TestFastAppend extends TableTestBase {
     List<ManifestFile> committedManifests =
         Lists.newArrayList(committed.currentSnapshot().allManifests(FILE_IO));
     committedManifests.removeAll(base.currentSnapshot().allManifests(FILE_IO));
-    Assert.assertEquals(
-        "Should reused manifest created by apply",
-        pending.allManifests(FILE_IO).get(0),
-        committedManifests.get(0));
+    assertThat(committedManifests.get(0)).isEqualTo(pending.allManifests(FILE_IO).get(0));
   }
 
-  @Test
+  @TestTemplate
   public void testFailure() {
     // inject 5 failures
     TestTables.TestTableOperations ops = table.ops();
@@ -251,16 +243,16 @@ public class TestFastAppend extends TableTestBase {
     AppendFiles append = table.newFastAppend().appendFile(FILE_B);
     Snapshot pending = append.apply();
     ManifestFile newManifest = pending.allManifests(FILE_IO).get(0);
-    Assert.assertTrue("Should create new manifest", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).exists();
 
-    Assertions.assertThatThrownBy(append::commit)
+    assertThatThrownBy(append::commit)
         .isInstanceOf(CommitFailedException.class)
         .hasMessage("Injected failure");
 
-    Assert.assertFalse("Should clean up new manifest", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).doesNotExist();
   }
 
-  @Test
+  @TestTemplate
   public void testAppendManifestCleanup() throws IOException {
     // inject 5 failures
     TestTables.TestTableOperations ops = table.ops();
@@ -270,25 +262,25 @@ public class TestFastAppend extends TableTestBase {
     AppendFiles append = table.newFastAppend().appendManifest(manifest);
     Snapshot pending = append.apply();
     ManifestFile newManifest = pending.allManifests(FILE_IO).get(0);
-    Assert.assertTrue("Should create new manifest", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).exists();
     if (formatVersion == 1) {
-      Assertions.assertThat(newManifest.path()).isNotEqualTo(manifest.path());
+      assertThat(newManifest.path()).isNotEqualTo(manifest.path());
     } else {
-      Assertions.assertThat(newManifest.path()).isEqualTo(manifest.path());
+      assertThat(newManifest.path()).isEqualTo(manifest.path());
     }
 
-    Assertions.assertThatThrownBy(append::commit)
+    assertThatThrownBy(append::commit)
         .isInstanceOf(CommitFailedException.class)
         .hasMessage("Injected failure");
 
     if (formatVersion == 1) {
-      Assertions.assertThat(new File(newManifest.path())).doesNotExist();
+      assertThat(new File(newManifest.path())).doesNotExist();
     } else {
-      Assertions.assertThat(new File(newManifest.path())).exists();
+      assertThat(new File(newManifest.path())).exists();
     }
   }
 
-  @Test
+  @TestTemplate
   public void testRecoveryWithManifestList() {
     table.updateProperties().set(TableProperties.MANIFEST_LISTS_ENABLED, "true").commit();
 
@@ -299,20 +291,18 @@ public class TestFastAppend extends TableTestBase {
     AppendFiles append = table.newFastAppend().appendFile(FILE_B);
     Snapshot pending = append.apply();
     ManifestFile newManifest = pending.allManifests(FILE_IO).get(0);
-    Assert.assertTrue("Should create new manifest", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).exists();
 
     append.commit();
 
     TableMetadata metadata = readMetadata();
 
     validateSnapshot(null, metadata.currentSnapshot(), FILE_B);
-    Assert.assertTrue("Should commit same new manifest", new File(newManifest.path()).exists());
-    Assert.assertTrue(
-        "Should commit the same new manifest",
-        metadata.currentSnapshot().allManifests(FILE_IO).contains(newManifest));
+    assertThat(new File(newManifest.path())).exists();
+    assertThat(metadata.currentSnapshot().allManifests(FILE_IO)).contains(newManifest);
   }
 
-  @Test
+  @TestTemplate
   public void testRecoveryWithoutManifestList() {
     table.updateProperties().set(TableProperties.MANIFEST_LISTS_ENABLED, "false").commit();
 
@@ -323,27 +313,25 @@ public class TestFastAppend extends TableTestBase {
     AppendFiles append = table.newFastAppend().appendFile(FILE_B);
     Snapshot pending = append.apply();
     ManifestFile newManifest = pending.allManifests(FILE_IO).get(0);
-    Assert.assertTrue("Should create new manifest", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).exists();
 
     append.commit();
 
     TableMetadata metadata = readMetadata();
 
     validateSnapshot(null, metadata.currentSnapshot(), FILE_B);
-    Assert.assertTrue("Should commit same new manifest", new File(newManifest.path()).exists());
-    Assert.assertTrue(
-        "Should commit the same new manifest",
-        metadata.currentSnapshot().allManifests(FILE_IO).contains(newManifest));
+    assertThat(new File(newManifest.path())).exists();
+    assertThat(metadata.currentSnapshot().allManifests(FILE_IO)).contains(newManifest);
   }
 
-  @Test
+  @TestTemplate
   public void testAppendManifestWithSnapshotIdInheritance() throws IOException {
     table.updateProperties().set(TableProperties.SNAPSHOT_ID_INHERITANCE_ENABLED, "true").commit();
 
-    Assert.assertEquals("Table should start empty", 0, listManifestFiles().size());
+    assertThat(listManifestFiles()).isEmpty();
 
     TableMetadata base = readMetadata();
-    Assert.assertNull("Should not have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNull();
 
     ManifestFile manifest = writeManifest(FILE_A, FILE_B);
     table.newFastAppend().appendManifest(manifest).commit();
@@ -351,7 +339,7 @@ public class TestFastAppend extends TableTestBase {
     Snapshot snapshot = table.currentSnapshot();
     List<ManifestFile> manifests = table.currentSnapshot().allManifests(FILE_IO);
     ManifestFile committedManifest = Iterables.getOnlyElement(manifests);
-    Assertions.assertThat(committedManifest.path()).isEqualTo(manifest.path());
+    assertThat(committedManifest.path()).isEqualTo(manifest.path());
 
     validateManifestEntries(
         manifests.get(0),
@@ -360,32 +348,21 @@ public class TestFastAppend extends TableTestBase {
         statuses(Status.ADDED, Status.ADDED));
 
     // validate that the metadata summary is correct when using appendManifest
-    Assert.assertEquals(
-        "Summary metadata should include 2 added files",
-        "2",
-        snapshot.summary().get("added-data-files"));
-    Assert.assertEquals(
-        "Summary metadata should include 2 added records",
-        "2",
-        snapshot.summary().get("added-records"));
-    Assert.assertEquals(
-        "Summary metadata should include 2 files in total",
-        "2",
-        snapshot.summary().get("total-data-files"));
-    Assert.assertEquals(
-        "Summary metadata should include 2 records in total",
-        "2",
-        snapshot.summary().get("total-records"));
+    assertThat(snapshot.summary())
+        .containsEntry("added-data-files", "2")
+        .containsEntry("added-records", "2")
+        .containsEntry("total-data-files", "2")
+        .containsEntry("total-records", "2");
   }
 
-  @Test
+  @TestTemplate
   public void testAppendManifestFailureWithSnapshotIdInheritance() throws IOException {
     table.updateProperties().set(TableProperties.SNAPSHOT_ID_INHERITANCE_ENABLED, "true").commit();
 
-    Assert.assertEquals("Table should start empty", 0, listManifestFiles().size());
+    assertThat(listManifestFiles()).isEmpty();
 
     TableMetadata base = readMetadata();
-    Assert.assertNull("Should not have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNull();
 
     table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
 
@@ -396,36 +373,36 @@ public class TestFastAppend extends TableTestBase {
     AppendFiles append = table.newAppend();
     append.appendManifest(manifest);
 
-    Assertions.assertThatThrownBy(append::commit)
+    assertThatThrownBy(append::commit)
         .isInstanceOf(CommitFailedException.class)
         .hasMessage("Injected failure");
 
-    Assert.assertTrue("Append manifest should not be deleted", new File(manifest.path()).exists());
+    assertThat(new File(manifest.path())).exists();
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidAppendManifest() throws IOException {
-    Assert.assertEquals("Table should start empty", 0, listManifestFiles().size());
+    assertThat(listManifestFiles()).isEmpty();
 
     TableMetadata base = readMetadata();
-    Assert.assertNull("Should not have a current snapshot", base.currentSnapshot());
+    assertThat(base.currentSnapshot()).isNull();
 
     ManifestFile manifestWithExistingFiles =
         writeManifest("manifest-file-1.avro", manifestEntry(Status.EXISTING, null, FILE_A));
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> table.newFastAppend().appendManifest(manifestWithExistingFiles).commit())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot append manifest with existing files");
 
     ManifestFile manifestWithDeletedFiles =
         writeManifest("manifest-file-2.avro", manifestEntry(Status.DELETED, null, FILE_A));
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> table.newFastAppend().appendManifest(manifestWithDeletedFiles).commit())
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Cannot append manifest with deleted files");
   }
 
-  @Test
+  @TestTemplate
   public void testPartitionSummariesOnUnpartitionedTable() {
     Table table =
         TestTables.create(
@@ -447,7 +424,7 @@ public class TestFastAppend extends TableTestBase {
                 .build())
         .commit();
 
-    Assertions.assertThat(
+    assertThat(
             table.currentSnapshot().summary().keySet().stream()
                 .filter(key -> key.startsWith(SnapshotSummary.CHANGED_PARTITION_PREFIX))
                 .collect(Collectors.toSet()))
@@ -455,7 +432,7 @@ public class TestFastAppend extends TableTestBase {
         .isEmpty();
   }
 
-  @Test
+  @TestTemplate
   public void testDefaultPartitionSummaries() {
     table.newFastAppend().appendFile(FILE_A).commit();
 
@@ -463,23 +440,14 @@ public class TestFastAppend extends TableTestBase {
         table.currentSnapshot().summary().keySet().stream()
             .filter(key -> key.startsWith(SnapshotSummary.CHANGED_PARTITION_PREFIX))
             .collect(Collectors.toSet());
-    Assert.assertEquals(
-        "Should include no partition summaries by default", 0, partitionSummaryKeys.size());
+    assertThat(partitionSummaryKeys).isEmpty();
 
-    String summariesIncluded =
-        table
-            .currentSnapshot()
-            .summary()
-            .getOrDefault(SnapshotSummary.PARTITION_SUMMARY_PROP, "false");
-    Assert.assertEquals(
-        "Should not set partition-summaries-included to true", "false", summariesIncluded);
-
-    String changedPartitions =
-        table.currentSnapshot().summary().get(SnapshotSummary.CHANGED_PARTITION_COUNT_PROP);
-    Assert.assertEquals("Should set changed partition count", "1", changedPartitions);
+    assertThat(table.currentSnapshot().summary())
+        .doesNotContainKey(SnapshotSummary.PARTITION_SUMMARY_PROP)
+        .containsEntry(SnapshotSummary.CHANGED_PARTITION_COUNT_PROP, "1");
   }
 
-  @Test
+  @TestTemplate
   public void testIncludedPartitionSummaries() {
     table.updateProperties().set(TableProperties.WRITE_PARTITION_SUMMARY_LIMIT, "1").commit();
 
@@ -489,32 +457,17 @@ public class TestFastAppend extends TableTestBase {
         table.currentSnapshot().summary().keySet().stream()
             .filter(key -> key.startsWith(SnapshotSummary.CHANGED_PARTITION_PREFIX))
             .collect(Collectors.toSet());
-    Assert.assertEquals("Should include a partition summary", 1, partitionSummaryKeys.size());
+    assertThat(partitionSummaryKeys).hasSize(1);
 
-    String summariesIncluded =
-        table
-            .currentSnapshot()
-            .summary()
-            .getOrDefault(SnapshotSummary.PARTITION_SUMMARY_PROP, "false");
-    Assert.assertEquals(
-        "Should set partition-summaries-included to true", "true", summariesIncluded);
-
-    String changedPartitions =
-        table.currentSnapshot().summary().get(SnapshotSummary.CHANGED_PARTITION_COUNT_PROP);
-    Assert.assertEquals("Should set changed partition count", "1", changedPartitions);
-
-    String partitionSummary =
-        table
-            .currentSnapshot()
-            .summary()
-            .get(SnapshotSummary.CHANGED_PARTITION_PREFIX + "data_bucket=0");
-    Assert.assertEquals(
-        "Summary should include 1 file with 1 record that is 10 bytes",
-        "added-data-files=1,added-records=1,added-files-size=10",
-        partitionSummary);
+    assertThat(table.currentSnapshot().summary())
+        .containsEntry(SnapshotSummary.PARTITION_SUMMARY_PROP, "true")
+        .containsEntry(SnapshotSummary.CHANGED_PARTITION_COUNT_PROP, "1")
+        .containsEntry(
+            SnapshotSummary.CHANGED_PARTITION_PREFIX + "data_bucket=0",
+            "added-data-files=1,added-records=1,added-files-size=10");
   }
 
-  @Test
+  @TestTemplate
   public void testIncludedPartitionSummaryLimit() {
     table.updateProperties().set(TableProperties.WRITE_PARTITION_SUMMARY_LIMIT, "1").commit();
 
@@ -524,69 +477,56 @@ public class TestFastAppend extends TableTestBase {
         table.currentSnapshot().summary().keySet().stream()
             .filter(key -> key.startsWith(SnapshotSummary.CHANGED_PARTITION_PREFIX))
             .collect(Collectors.toSet());
-    Assert.assertEquals(
-        "Should include no partition summaries, over limit", 0, partitionSummaryKeys.size());
+    assertThat(partitionSummaryKeys).isEmpty();
 
-    String summariesIncluded =
-        table
-            .currentSnapshot()
-            .summary()
-            .getOrDefault(SnapshotSummary.PARTITION_SUMMARY_PROP, "false");
-    Assert.assertEquals(
-        "Should not set partition-summaries-included to true", "false", summariesIncluded);
-
-    String changedPartitions =
-        table.currentSnapshot().summary().get(SnapshotSummary.CHANGED_PARTITION_COUNT_PROP);
-    Assert.assertEquals("Should set changed partition count", "2", changedPartitions);
+    assertThat(table.currentSnapshot().summary())
+        .doesNotContainKey(SnapshotSummary.PARTITION_SUMMARY_PROP)
+        .containsEntry(SnapshotSummary.CHANGED_PARTITION_COUNT_PROP, "2");
   }
 
-  @Test
+  @TestTemplate
   public void testAppendToExistingBranch() {
     table.newFastAppend().appendFile(FILE_A).commit();
     table.manageSnapshots().createBranch("branch", table.currentSnapshot().snapshotId()).commit();
     table.newFastAppend().appendFile(FILE_B).toBranch("branch").commit();
-    int branchSnapshot = 2;
 
-    Assert.assertEquals(table.currentSnapshot().snapshotId(), 1);
-    Assert.assertEquals(table.ops().current().ref("branch").snapshotId(), branchSnapshot);
+    assertThat(table.currentSnapshot().snapshotId()).isEqualTo(1);
+    assertThat(table.ops().current().ref("branch").snapshotId()).isEqualTo(2);
   }
 
-  @Test
+  @TestTemplate
   public void testAppendCreatesBranchIfNeeded() {
     table.newFastAppend().appendFile(FILE_A).commit();
     table.newFastAppend().appendFile(FILE_B).toBranch("branch").commit();
-    int branchSnapshot = 2;
 
-    Assert.assertEquals(table.currentSnapshot().snapshotId(), 1);
-    Assert.assertNotNull(table.ops().current().ref("branch"));
-    Assert.assertEquals(table.ops().current().ref("branch").snapshotId(), branchSnapshot);
+    assertThat(table.currentSnapshot().snapshotId()).isEqualTo(1);
+    assertThat(table.ops().current().ref("branch")).isNotNull();
+    assertThat(table.ops().current().ref("branch").snapshotId()).isEqualTo(2);
   }
 
-  @Test
+  @TestTemplate
   public void testAppendToBranchEmptyTable() {
     table.newFastAppend().appendFile(FILE_B).toBranch("branch").commit();
-    int branchSnapshot = 1;
 
-    Assert.assertNull(table.currentSnapshot());
-    Assert.assertNotNull(table.ops().current().ref("branch"));
-    Assert.assertEquals(table.ops().current().ref("branch").snapshotId(), branchSnapshot);
+    assertThat(table.currentSnapshot()).isNull();
+    assertThat(table.ops().current().ref("branch")).isNotNull();
+    assertThat(table.ops().current().ref("branch").snapshotId()).isEqualTo(1);
   }
 
-  @Test
+  @TestTemplate
   public void testAppendToNullBranchFails() {
-    Assertions.assertThatThrownBy(() -> table.newFastAppend().appendFile(FILE_A).toBranch(null))
+    assertThatThrownBy(() -> table.newFastAppend().appendFile(FILE_A).toBranch(null))
         .as("Invalid branch")
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Invalid branch name: null");
   }
 
-  @Test
+  @TestTemplate
   public void testAppendToTagFails() {
     table.newFastAppend().appendFile(FILE_A).commit();
     table.manageSnapshots().createTag("some-tag", table.currentSnapshot().snapshotId()).commit();
 
-    Assertions.assertThatThrownBy(
-            () -> table.newFastAppend().appendFile(FILE_A).toBranch("some-tag").commit())
+    assertThatThrownBy(() -> table.newFastAppend().appendFile(FILE_A).toBranch("some-tag").commit())
         .as("Invalid branch")
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage(
