@@ -19,9 +19,15 @@
 package org.apache.iceberg;
 
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+import java.nio.file.Path;
+import java.util.Arrays;
+import java.util.List;
 import java.util.Map;
 import org.apache.iceberg.MetricsModes.Counts;
 import org.apache.iceberg.MetricsModes.Full;
@@ -29,56 +35,48 @@ import org.apache.iceberg.MetricsModes.None;
 import org.apache.iceberg.MetricsModes.Truncate;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.types.Types;
-import org.assertj.core.api.Assertions;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestMetricsModes {
 
-  private final int formatVersion;
+  @Parameter private int formatVersion;
 
-  @Parameterized.Parameters(name = "formatVersion = {0}")
-  public static Object[] parameters() {
-    return new Object[] {1, 2};
+  @Parameters(name = "formatVersion = {0}")
+  protected static List<Object> parameters() {
+    return Arrays.asList(1, 2);
   }
 
-  public TestMetricsModes(int formatVersion) {
-    this.formatVersion = formatVersion;
-  }
+  @TempDir private Path temp;
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
-
-  @After
+  @AfterEach
   public void after() {
     TestTables.clearTables();
   }
 
-  @Test
+  @TestTemplate
   public void testMetricsModeParsing() {
-    Assert.assertEquals(None.get(), MetricsModes.fromString("none"));
-    Assert.assertEquals(None.get(), MetricsModes.fromString("nOnE"));
-    Assert.assertEquals(Counts.get(), MetricsModes.fromString("counts"));
-    Assert.assertEquals(Counts.get(), MetricsModes.fromString("coUntS"));
-    Assert.assertEquals(Truncate.withLength(1), MetricsModes.fromString("truncate(1)"));
-    Assert.assertEquals(Truncate.withLength(10), MetricsModes.fromString("truNcAte(10)"));
-    Assert.assertEquals(Full.get(), MetricsModes.fromString("full"));
-    Assert.assertEquals(Full.get(), MetricsModes.fromString("FULL"));
+    assertThat(MetricsModes.fromString("none")).isEqualTo(None.get());
+    assertThat(MetricsModes.fromString("nOnE")).isEqualTo(None.get());
+    assertThat(MetricsModes.fromString("counts")).isEqualTo(Counts.get());
+    assertThat(MetricsModes.fromString("coUntS")).isEqualTo(Counts.get());
+    assertThat(MetricsModes.fromString("truncate(1)")).isEqualTo(Truncate.withLength(1));
+    assertThat(MetricsModes.fromString("truNcAte(10)")).isEqualTo(Truncate.withLength(10));
+    assertThat(MetricsModes.fromString("full")).isEqualTo(Full.get());
+    assertThat(MetricsModes.fromString("FULL")).isEqualTo(Full.get());
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidTruncationLength() {
-    Assertions.assertThatThrownBy(() -> MetricsModes.fromString("truncate(0)"))
+    assertThatThrownBy(() -> MetricsModes.fromString("truncate(0)"))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Truncate length should be positive");
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidColumnModeValue() {
     Map<String, String> properties =
         ImmutableMap.of(
@@ -88,13 +86,12 @@ public class TestMetricsModes {
             "troncate(5)");
 
     MetricsConfig config = MetricsConfig.fromProperties(properties);
-    Assert.assertEquals(
-        "Invalid mode should be defaulted to table default (full)",
-        MetricsModes.Full.get(),
-        config.columnMode("col"));
+    assertThat(config.columnMode("col"))
+        .as("Invalid mode should be defaulted to table default (full)")
+        .isEqualTo(MetricsModes.Full.get());
   }
 
-  @Test
+  @TestTemplate
   public void testInvalidDefaultColumnModeValue() {
     Map<String, String> properties =
         ImmutableMap.of(
@@ -104,16 +101,15 @@ public class TestMetricsModes {
             "troncate(5)");
 
     MetricsConfig config = MetricsConfig.fromProperties(properties);
-    Assert.assertEquals(
-        "Invalid mode should be defaulted to library default (truncate(16))",
-        MetricsModes.Truncate.withLength(16),
-        config.columnMode("col"));
+    assertThat(config.columnMode("col"))
+        .as("Invalid mode should be defaulted to library default (truncate(16))")
+        .isEqualTo(MetricsModes.Truncate.withLength(16));
   }
 
-  @Test
+  @TestTemplate
   public void testMetricsConfigSortedColsDefault() throws Exception {
-    File tableDir = temp.newFolder();
-    tableDir.delete(); // created by table create
+    File tableDir = Files.createTempDirectory(temp, "junit").toFile();
+    assertThat(tableDir.delete()).isTrue();
 
     Schema schema =
         new Schema(
@@ -133,26 +129,24 @@ public class TestMetricsModes {
         .commit();
 
     MetricsConfig config = MetricsConfig.forTable(testTable);
-    Assert.assertEquals(
-        "Non-sorted existing column should not be overridden",
-        Counts.get(),
-        config.columnMode("col1"));
-    Assert.assertEquals(
-        "Sorted column defaults should not override user specified config",
-        None.get(),
-        config.columnMode("col2"));
-    Assert.assertEquals(
-        "Unspecified sorted column should use default",
-        Truncate.withLength(16),
-        config.columnMode("col3"));
-    Assert.assertEquals(
-        "Unspecified normal column should use default", Counts.get(), config.columnMode("col4"));
+    assertThat(config.columnMode("col1"))
+        .as("Non-sorted existing column should not be overridden")
+        .isEqualTo(Counts.get());
+    assertThat(config.columnMode("col2"))
+        .as("Sorted column defaults should not override user specified config")
+        .isEqualTo(None.get());
+    assertThat(config.columnMode("col3"))
+        .as("Unspecified sorted column should use default")
+        .isEqualTo(Truncate.withLength(16));
+    assertThat(config.columnMode("col4"))
+        .as("Unspecified normal column should use default")
+        .isEqualTo(Counts.get());
   }
 
-  @Test
+  @TestTemplate
   public void testMetricsConfigSortedColsDefaultByInvalid() throws Exception {
-    File tableDir = temp.newFolder();
-    tableDir.delete(); // created by table create
+    File tableDir = Files.createTempDirectory(temp, "junit").toFile();
+    assertThat(tableDir.delete()).isTrue();
 
     Schema schema =
         new Schema(
@@ -171,17 +165,15 @@ public class TestMetricsModes {
         .commit();
 
     MetricsConfig config = MetricsConfig.forTable(testTable);
-    Assert.assertEquals(
-        "Non-sorted existing column should not be overridden by sorted column",
-        Full.get(),
-        config.columnMode("col1"));
-    Assert.assertEquals(
-        "Original default applies as user entered invalid mode for sorted column",
-        Counts.get(),
-        config.columnMode("col2"));
+    assertThat(config.columnMode("col1"))
+        .as("Non-sorted existing column should not be overridden by sorted column")
+        .isEqualTo(Full.get());
+    assertThat(config.columnMode("col2"))
+        .as("Original default applies as user entered invalid mode for sorted column")
+        .isEqualTo(Counts.get());
   }
 
-  @Test
+  @TestTemplate
   public void testMetricsConfigInferredDefaultModeLimit() throws IOException {
     Schema schema =
         new Schema(
@@ -189,8 +181,8 @@ public class TestMetricsModes {
             required(2, "col2", Types.IntegerType.get()),
             required(3, "col3", Types.IntegerType.get()));
 
-    File tableDir = temp.newFolder();
-    Assert.assertTrue(tableDir.delete());
+    File tableDir = Files.createTempDirectory(temp, "junit").toFile();
+    assertThat(tableDir.delete()).isTrue();
 
     Table table =
         TestTables.create(
@@ -209,10 +201,8 @@ public class TestMetricsModes {
 
     MetricsConfig config = MetricsConfig.forTable(table);
 
-    Assert.assertEquals(
-        "Should use default mode for col1", Truncate.withLength(16), config.columnMode("col1"));
-    Assert.assertEquals(
-        "Should use default mode for col2", Truncate.withLength(16), config.columnMode("col2"));
-    Assert.assertEquals("Should use None for col3", None.get(), config.columnMode("col3"));
+    assertThat(config.columnMode("col1")).isEqualTo(Truncate.withLength(16));
+    assertThat(config.columnMode("col2")).isEqualTo(Truncate.withLength(16));
+    assertThat(config.columnMode("col3")).isEqualTo(None.get());
   }
 }
