@@ -19,21 +19,22 @@
 package org.apache.iceberg;
 
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.types.Types.NestedField;
 import org.apache.iceberg.types.Types.StructType;
-import org.assertj.core.api.Assertions;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 public class TestPartitioning {
 
@@ -51,15 +52,15 @@ public class TestPartitioning {
   private static final PartitionSpec BY_DATA_CATEGORY_BUCKET_SPEC =
       PartitionSpec.builderFor(SCHEMA).identity("data").bucket("category", 8).build();
 
-  @Rule public TemporaryFolder temp = new TemporaryFolder();
+  @TempDir private Path temp;
   private File tableDir = null;
 
-  @Before
+  @BeforeEach
   public void setupTableDir() throws IOException {
-    this.tableDir = temp.newFolder();
+    this.tableDir = Files.createTempDirectory(temp, "junit").toFile();
   }
 
-  @After
+  @AfterEach
   public void cleanupTables() {
     TestTables.clearTables();
   }
@@ -71,19 +72,19 @@ public class TestPartitioning {
 
     table.updateSpec().addField(Expressions.bucket("category", 8)).commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType =
         StructType.of(
             NestedField.optional(1000, "data", Types.StringType.get()),
             NestedField.optional(1001, "category_bucket_8", Types.IntegerType.get()));
     StructType actualType = Partitioning.partitionType(table);
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
 
     table.updateSpec().removeField("data").removeField("category_bucket_8").commit();
 
-    Assert.assertEquals("Should have 3 specs", 3, table.specs().size());
-    Assert.assertTrue("PartitionSpec should be unpartitioned", table.spec().isUnpartitioned());
+    assertThat(table.specs()).hasSize(3);
+    assertThat(table.spec().isUnpartitioned()).isTrue();
   }
 
   @Test
@@ -93,14 +94,14 @@ public class TestPartitioning {
 
     table.updateSpec().removeField("data").addField("category").commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType =
         StructType.of(
             NestedField.optional(1000, "data", Types.StringType.get()),
             NestedField.optional(1001, "category", Types.StringType.get()));
     StructType actualType = Partitioning.partitionType(table);
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -118,7 +119,7 @@ public class TestPartitioning {
             NestedField.optional(1000, "p2", Types.StringType.get()),
             NestedField.optional(1001, "category", Types.StringType.get()));
     StructType actualType = Partitioning.partitionType(table);
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -136,7 +137,7 @@ public class TestPartitioning {
             NestedField.optional(1000, "data_1000", Types.StringType.get()),
             NestedField.optional(1001, "data", Types.StringType.get()));
     StructType actualType = Partitioning.partitionType(table);
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -152,7 +153,7 @@ public class TestPartitioning {
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
     StructType actualType = Partitioning.partitionType(table);
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -166,9 +167,9 @@ public class TestPartitioning {
     TableMetadata current = ops.current();
     ops.commit(current, current.updatePartitionSpec(newSpec));
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
-    Assertions.assertThatThrownBy(() -> Partitioning.partitionType(table))
+    assertThatThrownBy(() -> Partitioning.partitionType(table))
         .isInstanceOf(ValidationException.class)
         .hasMessageStartingWith("Conflicting partition fields");
   }
@@ -180,12 +181,12 @@ public class TestPartitioning {
 
     table.updateSpec().addField(Expressions.bucket("category", 8)).commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -195,12 +196,12 @@ public class TestPartitioning {
 
     table.updateSpec().addField(Expressions.bucket("category", 8)).commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -211,12 +212,12 @@ public class TestPartitioning {
 
     table.updateSpec().removeField(Expressions.bucket("category", 8)).commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -227,12 +228,12 @@ public class TestPartitioning {
 
     table.updateSpec().removeField(Expressions.bucket("category", 8)).commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "data", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -248,7 +249,7 @@ public class TestPartitioning {
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "p2", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -264,7 +265,7 @@ public class TestPartitioning {
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "p2", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -274,11 +275,11 @@ public class TestPartitioning {
 
     table.updateSpec().removeField("data").commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType = StructType.of();
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -288,11 +289,11 @@ public class TestPartitioning {
 
     table.updateSpec().removeField("data").commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType = StructType.of();
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -307,7 +308,7 @@ public class TestPartitioning {
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "category", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -322,7 +323,7 @@ public class TestPartitioning {
     StructType expectedType =
         StructType.of(NestedField.optional(1000, "category", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -331,11 +332,11 @@ public class TestPartitioning {
         TestTables.create(
             tableDir, "test", SCHEMA, PartitionSpec.unpartitioned(), V1_FORMAT_VERSION);
 
-    Assert.assertEquals("Should have 1 spec", 1, table.specs().size());
+    assertThat(table.specs()).hasSize(1);
 
     StructType expectedType = StructType.of();
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -346,11 +347,11 @@ public class TestPartitioning {
 
     table.updateSpec().addField(Expressions.bucket("category", 8)).commit();
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
     StructType expectedType = StructType.of();
     StructType actualType = Partitioning.groupingKeyType(table.schema(), table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -363,7 +364,7 @@ public class TestPartitioning {
     StructType expectedType =
         StructType.of(NestedField.optional(1001, "data", Types.StringType.get()));
     StructType actualType = Partitioning.groupingKeyType(projectedSchema, table.specs().values());
-    Assert.assertEquals("Types must match", expectedType, actualType);
+    assertThat(actualType).isEqualTo(expectedType);
   }
 
   @Test
@@ -377,10 +378,9 @@ public class TestPartitioning {
     TableMetadata current = ops.current();
     ops.commit(current, current.updatePartitionSpec(newSpec));
 
-    Assert.assertEquals("Should have 2 specs", 2, table.specs().size());
+    assertThat(table.specs()).hasSize(2);
 
-    Assertions.assertThatThrownBy(
-            () -> Partitioning.groupingKeyType(table.schema(), table.specs().values()))
+    assertThatThrownBy(() -> Partitioning.groupingKeyType(table.schema(), table.specs().values()))
         .isInstanceOf(ValidationException.class)
         .hasMessageStartingWith("Conflicting partition fields");
   }
@@ -403,6 +403,6 @@ public class TestPartitioning {
             .identity("id")
             .build();
 
-    Assert.assertEquals("The spec should be there", spec, table.spec());
+    assertThat(table.spec()).isEqualTo(spec);
   }
 }
