@@ -18,8 +18,13 @@
  */
 package org.apache.iceberg;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.assertj.core.api.Assumptions.assumeThat;
+
 import java.io.File;
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.List;
 import java.util.Set;
 import java.util.UUID;
@@ -30,65 +35,54 @@ import org.apache.iceberg.io.OutputFile;
 import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Types;
-import org.assertj.core.api.Assertions;
-import org.assertj.core.api.Assumptions;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(Parameterized.class)
-public class TestTransaction extends TableTestBase {
-  @Parameterized.Parameters(name = "formatVersion = {0}")
-  public static Object[] parameters() {
-    return new Object[] {1, 2};
+@ExtendWith(ParameterizedTestExtension.class)
+public class TestTransaction extends TestBase {
+  @Parameters(name = "formatVersion = {0}")
+  protected static List<Object> parameters() {
+    return Arrays.asList(1, 2);
   }
 
-  public TestTransaction(int formatVersion) {
-    super(formatVersion);
-  }
-
-  @Test
+  @TestTemplate
   public void testEmptyTransaction() {
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(version()).isEqualTo(0);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
     txn.commitTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
   }
 
-  @Test
+  @TestTemplate
   public void testSingleOperationTransaction() {
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(version()).isEqualTo(0);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame(
-        "Base metadata should not change when an append is committed", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after append", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     txn.commitTransaction();
 
     validateSnapshot(base.currentSnapshot(), readMetadata().currentSnapshot(), FILE_A, FILE_B);
-    Assert.assertEquals("Table should be on version 1 after commit", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
   }
 
-  @Test
+  @TestTemplate
   public void testMultipleOperationTransaction() {
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(version()).isEqualTo(0);
 
     table.newAppend().appendFile(FILE_C).commit();
     List<HistoryEntry> initialHistory = table.history();
@@ -97,15 +91,13 @@ public class TestTransaction extends TableTestBase {
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     Snapshot appendSnapshot = txn.table().currentSnapshot();
 
@@ -113,55 +105,45 @@ public class TestTransaction extends TableTestBase {
 
     Snapshot deleteSnapshot = txn.table().currentSnapshot();
 
-    Assert.assertSame(
-        "Base metadata should not change when an append is committed", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 2 after commit", 2, (int) version());
-    Assert.assertEquals(
-        "Table should have two manifest after commit",
-        2,
-        readMetadata().currentSnapshot().allManifests(table.io()).size());
-    Assert.assertEquals(
-        "Table snapshot should be the delete snapshot",
-        deleteSnapshot,
-        readMetadata().currentSnapshot());
+    assertThat(version()).isEqualTo(2);
+    assertThat(readMetadata().currentSnapshot().allManifests(table.io())).hasSize(2);
+    assertThat(readMetadata().currentSnapshot()).isEqualTo(deleteSnapshot);
     validateManifestEntries(
         readMetadata().currentSnapshot().allManifests(table.io()).get(0),
         ids(deleteSnapshot.snapshotId(), appendSnapshot.snapshotId()),
         files(FILE_A, FILE_B),
         statuses(Status.DELETED, Status.EXISTING));
 
-    Assert.assertEquals(
-        "Table should have a snapshot for each operation", 3, readMetadata().snapshots().size());
+    assertThat(readMetadata().snapshots()).hasSize(3);
     validateManifestEntries(
         readMetadata().snapshots().get(1).allManifests(table.io()).get(0),
         ids(appendSnapshot.snapshotId(), appendSnapshot.snapshotId()),
         files(FILE_A, FILE_B),
         statuses(Status.ADDED, Status.ADDED));
 
-    Assertions.assertThat(table.history()).containsAll(initialHistory);
+    assertThat(table.history()).containsAll(initialHistory);
   }
 
-  @Test
+  @TestTemplate
   public void testMultipleOperationTransactionFromTable() {
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(version()).isEqualTo(0);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     Snapshot appendSnapshot = txn.table().currentSnapshot();
 
@@ -169,29 +151,21 @@ public class TestTransaction extends TableTestBase {
 
     Snapshot deleteSnapshot = txn.table().currentSnapshot();
 
-    Assert.assertSame(
-        "Base metadata should not change when an append is committed", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after append", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 1 after commit", 1, (int) version());
-    Assert.assertEquals(
-        "Table should have one manifest after commit",
-        1,
-        readMetadata().currentSnapshot().allManifests(table.io()).size());
-    Assert.assertEquals(
-        "Table snapshot should be the delete snapshot",
-        deleteSnapshot,
-        readMetadata().currentSnapshot());
+    assertThat(version()).isEqualTo(1);
+    assertThat(readMetadata().currentSnapshot().allManifests(table.io())).hasSize(1);
+    assertThat(readMetadata().currentSnapshot()).isEqualTo(deleteSnapshot);
     validateManifestEntries(
         readMetadata().currentSnapshot().allManifests(table.io()).get(0),
         ids(deleteSnapshot.snapshotId(), appendSnapshot.snapshotId()),
         files(FILE_A, FILE_B),
         statuses(Status.DELETED, Status.EXISTING));
 
-    Assert.assertEquals(
-        "Table should have a snapshot for each operation", 2, readMetadata().snapshots().size());
+    assertThat(readMetadata().snapshots()).hasSize(2);
     validateManifestEntries(
         readMetadata().snapshots().get(0).allManifests(table.io()).get(0),
         ids(appendSnapshot.snapshotId(), appendSnapshot.snapshotId()),
@@ -199,165 +173,151 @@ public class TestTransaction extends TableTestBase {
         statuses(Status.ADDED, Status.ADDED));
   }
 
-  @Test
+  @TestTemplate
   public void testDetectsUncommittedChange() {
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(version()).isEqualTo(0);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B); // not committed
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
-    Assertions.assertThatThrownBy(txn::newDelete)
+    assertThatThrownBy(txn::newDelete)
         .isInstanceOf(IllegalStateException.class)
         .hasMessage("Cannot create new DeleteFiles: last operation has not committed");
   }
 
-  @Test
+  @TestTemplate
   public void testDetectsUncommittedChangeOnCommit() {
-    Assert.assertEquals("Table should be on version 0", 0, (int) version());
+    assertThat(version()).isEqualTo(0);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B); // not committed
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 0 after txn create", 0, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(0);
 
-    Assertions.assertThatThrownBy(txn::commitTransaction)
+    assertThatThrownBy(txn::commitTransaction)
         .isInstanceOf(IllegalStateException.class)
         .hasMessage("Cannot commit transaction: last operation has not committed");
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionConflict() {
     // set retries to 0 to catch the failure
     table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "0").commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     // cause the transaction commit to fail
     table.ops().failCommits(1);
 
-    Assertions.assertThatThrownBy(txn::commitTransaction)
+    assertThatThrownBy(txn::commitTransaction)
         .isInstanceOf(CommitFailedException.class)
         .hasMessage("Injected failure");
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRetry() {
     // use only one retry
     table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
     Set<ManifestFile> appendManifests =
         Sets.newHashSet(txn.table().currentSnapshot().allManifests(table.io()));
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     // cause the transaction commit to fail
     table.ops().failCommits(1);
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 2 after commit", 2, (int) version());
+    assertThat(version()).isEqualTo(2);
 
-    Assert.assertEquals(
-        "Should reuse manifests from initial append commit",
-        appendManifests,
-        Sets.newHashSet(table.currentSnapshot().allManifests(table.io())));
+    assertThat(Sets.newHashSet(table.currentSnapshot().allManifests(table.io())))
+        .isEqualTo(appendManifests);
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRetryMergeAppend() {
     // use only one retry
     table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
     Set<ManifestFile> appendManifests =
         Sets.newHashSet(txn.table().currentSnapshot().allManifests(table.io()));
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     // cause the transaction commit to fail
     table.newAppend().appendFile(FILE_C).appendFile(FILE_D).commit();
 
-    Assert.assertEquals("Table should be on version 2 after real append", 2, (int) version());
+    assertThat(version()).isEqualTo(2);
 
     Set<ManifestFile> conflictAppendManifests =
         Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 3 after commit", 3, (int) version());
+    assertThat(version()).isEqualTo(3);
 
     Set<ManifestFile> expectedManifests = Sets.newHashSet();
     expectedManifests.addAll(appendManifests);
     expectedManifests.addAll(conflictAppendManifests);
 
-    Assert.assertEquals(
-        "Should reuse manifests from initial append commit and conflicting append",
-        expectedManifests,
-        Sets.newHashSet(table.currentSnapshot().allManifests(table.io())));
+    assertThat(Sets.newHashSet(table.currentSnapshot().allManifests(table.io())))
+        .isEqualTo(expectedManifests);
   }
 
-  @Test
+  @TestTemplate
   public void testMultipleUpdateTransactionRetryMergeCleanup() {
     // use only one retry and aggressively merge manifests
     table
@@ -366,59 +326,49 @@ public class TestTransaction extends TableTestBase {
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.updateProperties().set("test-property", "test-value").commit();
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertEquals(
-        "Append should create one manifest",
-        1,
-        txn.table().currentSnapshot().allManifests(table.io()).size());
+    assertThat(txn.table().currentSnapshot().allManifests(table.io())).hasSize(1);
     ManifestFile appendManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     // cause the transaction commit to fail
     table.newAppend().appendFile(FILE_C).appendFile(FILE_D).commit();
 
-    Assert.assertEquals("Table should be on version 2 after real append", 2, (int) version());
+    assertThat(version()).isEqualTo(2);
 
     Set<ManifestFile> conflictAppendManifests =
         Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 3 after commit", 3, (int) version());
+    assertThat(version()).isEqualTo(3);
 
     Set<ManifestFile> previousManifests = Sets.newHashSet();
     previousManifests.add(appendManifest);
     previousManifests.addAll(conflictAppendManifests);
 
-    Assert.assertEquals(
-        "Should merge both commit manifests into a single manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
-    Assert.assertFalse(
-        "Should merge both commit manifests into a new manifest",
-        previousManifests.contains(table.currentSnapshot().allManifests(table.io()).get(0)));
+    assertThat(table.currentSnapshot().allManifests(table.io()))
+        .hasSize(1)
+        .doesNotContainAnyElementsOf(previousManifests);
 
-    Assert.assertFalse(
-        "Append manifest should be deleted", new File(appendManifest.path()).exists());
+    assertThat(new File(appendManifest.path())).doesNotExist();
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRetrySchemaUpdate() {
     // use only one retry
     table.updateProperties().set(TableProperties.COMMIT_NUM_RETRIES, "1").commit();
@@ -434,18 +384,15 @@ public class TestTransaction extends TableTestBase {
     table.updateSchema().addColumn("another-column", Types.IntegerType.get()).commit();
     int conflictingSchemaId = table.schema().schemaId();
 
-    Assert.assertEquals(
-        "Both schema IDs should be the same in order to cause a conflict",
-        conflictingSchemaId,
-        schemaId);
+    assertThat(schemaId).isEqualTo(conflictingSchemaId);
 
     // commit the transaction for adding "new-column"
-    Assertions.assertThatThrownBy(txn::commitTransaction)
+    assertThatThrownBy(txn::commitTransaction)
         .isInstanceOf(CommitFailedException.class)
         .hasMessage("Table metadata refresh is required");
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRetryMergeCleanup() {
     // use only one retry and aggressively merge manifests
     table
@@ -454,61 +401,50 @@ public class TestTransaction extends TableTestBase {
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     TableMetadata base = readMetadata();
 
     Transaction txn = table.newTransaction();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after txn create", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     txn.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertEquals(
-        "Append should create one manifest",
-        1,
-        txn.table().currentSnapshot().allManifests(table.io()).size());
+    assertThat(txn.table().currentSnapshot().allManifests(table.io())).hasSize(1);
     ManifestFile appendManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 1 after append", 1, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(1);
 
     // cause the transaction commit to fail
     table.newAppend().appendFile(FILE_C).appendFile(FILE_D).commit();
 
-    Assert.assertEquals("Table should be on version 2 after real append", 2, (int) version());
+    assertThat(version()).isEqualTo(2);
 
     Set<ManifestFile> conflictAppendManifests =
         Sets.newHashSet(table.currentSnapshot().allManifests(table.io()));
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 3 after commit", 3, (int) version());
+    assertThat(version()).isEqualTo(3);
 
     Set<ManifestFile> previousManifests = Sets.newHashSet();
     previousManifests.add(appendManifest);
     previousManifests.addAll(conflictAppendManifests);
 
-    Assert.assertEquals(
-        "Should merge both commit manifests into a single manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
-    Assert.assertFalse(
-        "Should merge both commit manifests into a new manifest",
-        previousManifests.contains(table.currentSnapshot().allManifests(table.io()).get(0)));
-
-    Assert.assertFalse(
-        "Append manifest should be deleted", new File(appendManifest.path()).exists());
+    assertThat(table.currentSnapshot().allManifests(table.io()))
+        .hasSize(1)
+        .doesNotContainAnyElementsOf(previousManifests);
+    assertThat(new File(appendManifest.path())).doesNotExist();
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRetryAndAppendManifestsWithoutSnapshotIdInheritance()
       throws Exception {
     // this test assumes append manifests are rewritten, which only happens in V1 tables
-    Assumptions.assumeThat(formatVersion).isEqualTo(1);
+    assumeThat(formatVersion).isEqualTo(1);
 
     // use only one retry and aggressively merge manifests
     table
@@ -517,22 +453,18 @@ public class TestTransaction extends TableTestBase {
         .set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0")
         .commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     table.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertEquals("Table should be on version 2 after append", 2, (int) version());
-    Assert.assertEquals(
-        "Append should create one manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
+    assertThat(version()).isEqualTo(2);
+    assertThat(table.currentSnapshot().allManifests(table.io())).hasSize(1);
     ManifestFile v1manifest = table.currentSnapshot().allManifests(table.io()).get(0);
 
     TableMetadata base = readMetadata();
 
     // create a manifest append
-    OutputFile manifestLocation =
-        Files.localOutput("/tmp/" + UUID.randomUUID().toString() + ".avro");
+    OutputFile manifestLocation = Files.localOutput("/tmp/" + UUID.randomUUID() + ".avro");
     ManifestWriter<DataFile> writer = ManifestFiles.write(table.spec(), manifestLocation);
     try {
       writer.add(FILE_D);
@@ -544,14 +476,10 @@ public class TestTransaction extends TableTestBase {
 
     txn.newAppend().appendManifest(writer.toManifestFile()).commit();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 2 after txn create", 2, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(2);
 
-    Assert.assertEquals(
-        "Append should have one merged manifest",
-        1,
-        txn.table().currentSnapshot().allManifests(table.io()).size());
+    assertThat(txn.table().currentSnapshot().allManifests(table.io())).hasSize(1);
     ManifestFile mergedManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
     // find the initial copy of the appended manifest
@@ -562,40 +490,34 @@ public class TestTransaction extends TableTestBase {
                 path ->
                     !v1manifest.path().contains(path) && !mergedManifest.path().contains(path)));
 
-    Assert.assertTrue(
-        "Transaction should hijack the delete of the original copied manifest",
-        ((BaseTransaction) txn).deletedFiles().contains(copiedAppendManifest));
-    Assert.assertTrue(
-        "Copied append manifest should not be deleted yet",
-        new File(copiedAppendManifest).exists());
+    assertThat(((BaseTransaction) txn).deletedFiles())
+        .as("Transaction should hijack the delete of the original copied manifest")
+        .contains(copiedAppendManifest);
+    assertThat(new File(copiedAppendManifest)).exists();
 
     // cause the transaction commit to fail and retry
     table.newAppend().appendFile(FILE_C).commit();
 
-    Assert.assertEquals("Table should be on version 3 after real append", 3, (int) version());
+    assertThat(version()).isEqualTo(3);
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 4 after commit", 4, (int) version());
+    assertThat(version()).isEqualTo(4);
 
-    Assert.assertTrue(
-        "Transaction should hijack the delete of the original copied manifest",
-        ((BaseTransaction) txn).deletedFiles().contains(copiedAppendManifest));
-    Assert.assertFalse(
-        "Append manifest should be deleted", new File(copiedAppendManifest).exists());
-    Assert.assertTrue(
-        "Transaction should hijack the delete of the first merged manifest",
-        ((BaseTransaction) txn).deletedFiles().contains(mergedManifest.path()));
-    Assert.assertFalse(
-        "Append manifest should be deleted", new File(mergedManifest.path()).exists());
+    assertThat(((BaseTransaction) txn).deletedFiles())
+        .as("Transaction should hijack the delete of the original copied manifest")
+        .contains(copiedAppendManifest);
 
-    Assert.assertEquals(
-        "Should merge all commit manifests into a single manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
+    assertThat(new File(copiedAppendManifest)).doesNotExist();
+    assertThat(((BaseTransaction) txn).deletedFiles())
+        .as("Transaction should hijack the delete of the first merged manifest")
+        .contains(mergedManifest.path());
+    assertThat(new File(mergedManifest.path())).doesNotExist();
+
+    assertThat(table.currentSnapshot().allManifests(table.io())).hasSize(1);
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRetryAndAppendManifestsWithSnapshotIdInheritance() throws Exception {
     // use only one retry and aggressively merge manifests
     table
@@ -605,15 +527,12 @@ public class TestTransaction extends TableTestBase {
         .set(TableProperties.SNAPSHOT_ID_INHERITANCE_ENABLED, "true")
         .commit();
 
-    Assert.assertEquals("Table should be on version 1", 1, (int) version());
+    assertThat(version()).isEqualTo(1);
 
     table.newAppend().appendFile(FILE_A).appendFile(FILE_B).commit();
 
-    Assert.assertEquals("Table should be on version 2 after append", 2, (int) version());
-    Assert.assertEquals(
-        "Append should create one manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
+    assertThat(version()).isEqualTo(2);
+    assertThat(table.currentSnapshot().allManifests(table.io())).hasSize(1);
 
     TableMetadata base = readMetadata();
 
@@ -622,46 +541,37 @@ public class TestTransaction extends TableTestBase {
     ManifestFile appendManifest = writeManifestWithName("input.m0", FILE_D);
     txn.newAppend().appendManifest(appendManifest).commit();
 
-    Assert.assertSame(
-        "Base metadata should not change when commit is created", base, readMetadata());
-    Assert.assertEquals("Table should be on version 2 after txn create", 2, (int) version());
+    assertThat(readMetadata()).isSameAs(base);
+    assertThat(version()).isEqualTo(2);
 
-    Assert.assertEquals(
-        "Append should have one merged manifest",
-        1,
-        txn.table().currentSnapshot().allManifests(table.io()).size());
+    assertThat(txn.table().currentSnapshot().allManifests(table.io())).hasSize(1);
     ManifestFile mergedManifest = txn.table().currentSnapshot().allManifests(table.io()).get(0);
 
     // cause the transaction commit to fail and retry
     table.newAppend().appendFile(FILE_C).commit();
 
-    Assert.assertEquals("Table should be on version 3 after real append", 3, (int) version());
+    assertThat(version()).isEqualTo(3);
 
     txn.commitTransaction();
 
-    Assert.assertEquals("Table should be on version 4 after commit", 4, (int) version());
+    assertThat(version()).isEqualTo(4);
 
-    Assert.assertTrue(
-        "Transaction should hijack the delete of the original append manifest",
-        ((BaseTransaction) txn).deletedFiles().contains(appendManifest.path()));
-    Assert.assertFalse(
-        "Append manifest should be deleted", new File(appendManifest.path()).exists());
+    assertThat(((BaseTransaction) txn).deletedFiles())
+        .as("Transaction should hijack the delete of the original append manifest")
+        .contains(appendManifest.path());
+    assertThat(new File(appendManifest.path())).doesNotExist();
 
-    Assert.assertTrue(
-        "Transaction should hijack the delete of the first merged manifest",
-        ((BaseTransaction) txn).deletedFiles().contains(mergedManifest.path()));
-    Assert.assertFalse(
-        "Merged append manifest should be deleted", new File(mergedManifest.path()).exists());
+    assertThat(((BaseTransaction) txn).deletedFiles())
+        .as("Transaction should hijack the delete of the first merged manifest")
+        .contains(mergedManifest.path());
+    assertThat(new File(appendManifest.path())).doesNotExist();
 
-    Assert.assertEquals(
-        "Should merge all commit manifests into a single manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
+    assertThat(table.currentSnapshot().allManifests(table.io())).hasSize(1);
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionNoCustomDeleteFunc() {
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 table
                     .newTransaction()
@@ -673,7 +583,7 @@ public class TestTransaction extends TableTestBase {
         .hasMessage("Cannot set delete callback more than once");
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionFastAppends() {
     table.updateProperties().set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "0").commit();
 
@@ -686,10 +596,10 @@ public class TestTransaction extends TableTestBase {
     txn.commitTransaction();
 
     List<ManifestFile> manifests = table.currentSnapshot().allManifests(table.io());
-    Assert.assertEquals("Expected 2 manifests", 2, manifests.size());
+    assertThat(manifests).hasSize(2);
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRewriteManifestsAppendedDirectly() throws IOException {
     Table table = load();
 
@@ -706,7 +616,7 @@ public class TestTransaction extends TableTestBase {
     long secondSnapshotId = table.currentSnapshot().snapshotId();
 
     List<ManifestFile> manifests = table.currentSnapshot().allManifests(table.io());
-    Assert.assertEquals("Should have 2 manifests after 2 appends", 2, manifests.size());
+    assertThat(manifests).hasSize(2);
 
     ManifestFile newManifest =
         writeManifest(
@@ -726,11 +636,10 @@ public class TestTransaction extends TableTestBase {
     long finalSnapshotId = table.currentSnapshot().snapshotId();
     long finalSnapshotTimestamp = System.currentTimeMillis();
 
-    Assert.assertTrue(
-        "Append manifest should not be deleted", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).exists();
 
     List<ManifestFile> finalManifests = table.currentSnapshot().allManifests(table.io());
-    Assert.assertEquals("Should have 1 final manifest", 1, finalManifests.size());
+    assertThat(finalManifests).hasSize(1);
 
     validateManifestEntries(
         finalManifests.get(0),
@@ -743,30 +652,29 @@ public class TestTransaction extends TableTestBase {
 
     table.expireSnapshots().expireOlderThan(finalSnapshotTimestamp + 1).retainLast(1).commit();
 
-    Assert.assertFalse(
-        "Append manifest should be deleted on expiry", new File(newManifest.path()).exists());
+    assertThat(new File(newManifest.path())).doesNotExist();
   }
 
-  @Test
+  @TestTemplate
   public void testSimpleTransactionNotDeletingMetadataOnUnknownSate() throws IOException {
     Table table = TestTables.tableWithCommitSucceedButStateUnknown(tableDir, "test");
 
     Transaction transaction = table.newTransaction();
     transaction.newAppend().appendFile(FILE_A).commit();
 
-    Assertions.assertThatThrownBy(transaction::commitTransaction)
+    assertThatThrownBy(transaction::commitTransaction)
         .isInstanceOf(CommitStateUnknownException.class)
         .hasMessageStartingWith("datacenter on fire");
 
     // Make sure metadata files still exist
     Snapshot current = table.currentSnapshot();
     List<ManifestFile> manifests = current.allManifests(table.io());
-    Assert.assertEquals("Should have 1 manifest file", 1, manifests.size());
-    Assert.assertTrue("Manifest file should exist", new File(manifests.get(0).path()).exists());
-    Assert.assertEquals("Should have 2 files in metadata", 2, countAllMetadataFiles(tableDir));
+    assertThat(manifests).hasSize(1);
+    assertThat(new File(manifests.get(0).path())).exists();
+    assertThat(countAllMetadataFiles(tableDir)).isEqualTo(2);
   }
 
-  @Test
+  @TestTemplate
   public void testTransactionRecommit() {
     // update table settings to merge when there are 3 manifests
     table.updateProperties().set(TableProperties.MANIFEST_MIN_MERGE_COUNT, "3").commit();
@@ -781,18 +689,14 @@ public class TestTransaction extends TableTestBase {
     AppendFiles append = transaction.newAppend().appendFile(FILE_D);
     Snapshot pending = append.apply();
 
-    Assert.assertEquals(
-        "Should produce 1 pending merged manifest", 1, pending.allManifests(table.io()).size());
+    assertThat(pending.allManifests(table.io())).hasSize(1);
 
     // because a merge happened, the appended manifest is deleted the by append operation
     append.commit();
 
     // concurrently commit FILE_A without a transaction to cause the previous append to retry
     table.newAppend().appendFile(FILE_C).commit();
-    Assert.assertEquals(
-        "Should produce 1 committed merged manifest",
-        1,
-        table.currentSnapshot().allManifests(table.io()).size());
+    assertThat(table.currentSnapshot().allManifests(table.io())).hasSize(1);
 
     transaction.commitTransaction();
 
@@ -807,9 +711,7 @@ public class TestTransaction extends TableTestBase {
             FILE_C.path().toString(),
             FILE_D.path().toString());
 
-    Assert.assertEquals("Should contain all committed files", expectedPaths, paths);
-
-    Assert.assertEquals(
-        "Should produce 2 manifests", 2, table.currentSnapshot().allManifests(table.io()).size());
+    assertThat(paths).isEqualTo(expectedPaths);
+    assertThat(table.currentSnapshot().allManifests(table.io())).hasSize(2);
   }
 }
