@@ -18,6 +18,9 @@
  */
 package org.apache.iceberg.hadoop;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.io.File;
 import java.io.IOException;
 import java.io.UncheckedIOException;
@@ -37,7 +40,6 @@ import org.apache.iceberg.io.ResolvingFileIO;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Streams;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
@@ -71,29 +73,26 @@ public class HadoopFileIOTest {
               Path scalePath = new Path(parent, Integer.toString(scale));
 
               createRandomFiles(scalePath, scale);
-              Assertions.assertThat(
+              assertThat(
                       Streams.stream(hadoopFileIO.listPrefix(scalePath.toUri().toString())).count())
                   .isEqualTo((long) scale);
             });
 
     long totalFiles = scaleSizes.stream().mapToLong(Integer::longValue).sum();
-    Assertions.assertThat(
-            Streams.stream(hadoopFileIO.listPrefix(parent.toUri().toString())).count())
+    assertThat(Streams.stream(hadoopFileIO.listPrefix(parent.toUri().toString())).count())
         .isEqualTo(totalFiles);
   }
 
   @Test
   public void testFileExists() throws IOException {
     Path parent = new Path(tempDir.toURI());
-    Path randomFilePath = new Path(parent, "random-file-" + UUID.randomUUID().toString());
+    Path randomFilePath = new Path(parent, "random-file-" + UUID.randomUUID());
     fs.createNewFile(randomFilePath);
 
     // check existence of the created file
-    Assertions.assertThat(hadoopFileIO.newInputFile(randomFilePath.toUri().toString()).exists())
-        .isTrue();
+    assertThat(hadoopFileIO.newInputFile(randomFilePath.toUri().toString()).exists()).isTrue();
     fs.delete(randomFilePath, false);
-    Assertions.assertThat(hadoopFileIO.newInputFile(randomFilePath.toUri().toString()).exists())
-        .isFalse();
+    assertThat(hadoopFileIO.newInputFile(randomFilePath.toUri().toString()).exists()).isFalse();
   }
 
   @Test
@@ -112,7 +111,7 @@ public class HadoopFileIOTest {
               hadoopFileIO.deletePrefix(scalePath.toUri().toString());
 
               // Hadoop filesystem will throw if the path does not exist
-              Assertions.assertThatThrownBy(
+              assertThatThrownBy(
                       () -> hadoopFileIO.listPrefix(scalePath.toUri().toString()).iterator())
                   .isInstanceOf(UncheckedIOException.class)
                   .hasMessageContaining("java.io.FileNotFoundException");
@@ -120,8 +119,7 @@ public class HadoopFileIOTest {
 
     hadoopFileIO.deletePrefix(parent.toUri().toString());
     // Hadoop filesystem will throw if the path does not exist
-    Assertions.assertThatThrownBy(
-            () -> hadoopFileIO.listPrefix(parent.toUri().toString()).iterator())
+    assertThatThrownBy(() -> hadoopFileIO.listPrefix(parent.toUri().toString()).iterator())
         .isInstanceOf(UncheckedIOException.class)
         .hasMessageContaining("java.io.FileNotFoundException");
   }
@@ -133,15 +131,14 @@ public class HadoopFileIOTest {
     hadoopFileIO.deleteFiles(
         filesCreated.stream().map(Path::toString).collect(Collectors.toList()));
     filesCreated.forEach(
-        file ->
-            Assertions.assertThat(hadoopFileIO.newInputFile(file.toString()).exists()).isFalse());
+        file -> assertThat(hadoopFileIO.newInputFile(file.toString()).exists()).isFalse());
   }
 
   @Test
   public void testDeleteFilesErrorHandling() {
     List<String> filesCreated =
         random.ints(2).mapToObj(x -> "fakefsnotreal://file-" + x).collect(Collectors.toList());
-    Assertions.assertThatThrownBy(() -> hadoopFileIO.deleteFiles(filesCreated))
+    assertThatThrownBy(() -> hadoopFileIO.deleteFiles(filesCreated))
         .isInstanceOf(BulkDeletionFailureException.class)
         .hasMessage("Failed to delete 2 files");
   }
@@ -154,8 +151,7 @@ public class HadoopFileIOTest {
     testHadoopFileIO.initialize(ImmutableMap.of("k1", "v1"));
     FileIO roundTripSerializedFileIO = TestHelpers.KryoHelpers.roundTripSerialize(testHadoopFileIO);
 
-    Assertions.assertThat(roundTripSerializedFileIO.properties())
-        .isEqualTo(testHadoopFileIO.properties());
+    assertThat(roundTripSerializedFileIO.properties()).isEqualTo(testHadoopFileIO.properties());
   }
 
   @Test
@@ -166,8 +162,7 @@ public class HadoopFileIOTest {
     testHadoopFileIO.initialize(ImmutableMap.of("k1", "v1"));
     FileIO roundTripSerializedFileIO = TestHelpers.roundTripSerialize(testHadoopFileIO);
 
-    Assertions.assertThat(roundTripSerializedFileIO.properties())
-        .isEqualTo(testHadoopFileIO.properties());
+    assertThat(roundTripSerializedFileIO.properties()).isEqualTo(testHadoopFileIO.properties());
   }
 
   @Test
@@ -180,7 +175,7 @@ public class HadoopFileIOTest {
             .hiddenImpl(ResolvingFileIO.class, String.class)
             .build(resolvingFileIO)
             .invoke("hdfs://foo/bar");
-    Assertions.assertThat(result).isInstanceOf(HadoopFileIO.class);
+    assertThat(result).isInstanceOf(HadoopFileIO.class);
   }
 
   private List<Path> createRandomFiles(Path parent, int count) {
