@@ -21,6 +21,8 @@ package org.apache.iceberg.hadoop;
 import static org.apache.iceberg.TableProperties.COMMIT_NUM_RETRIES;
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -58,7 +60,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.Tasks;
-import org.assertj.core.api.Assertions;
 import org.awaitility.Awaitility;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.io.TempDir;
@@ -70,53 +71,53 @@ public class TestHadoopCommits extends HadoopTableTestBase {
   public void testCreateTable() throws Exception {
     PartitionSpec expectedSpec = PartitionSpec.builderFor(TABLE_SCHEMA).bucket("data", 16).build();
 
-    Assertions.assertThat(table.schema().asStruct())
+    assertThat(table.schema().asStruct())
         .as("Table schema should match schema with reassigned ids")
         .isEqualTo(TABLE_SCHEMA.asStruct());
-    Assertions.assertThat(table.spec())
+    assertThat(table.spec())
         .as("Table partition spec should match with reassigned ids")
         .isEqualTo(expectedSpec);
 
     List<FileScanTask> tasks = Lists.newArrayList(table.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should not create any scan tasks").isEmpty();
-    Assertions.assertThat(tableDir).as("Table location should exist").exists();
-    Assertions.assertThat(metadataDir).as("Should create metadata folder").exists().isDirectory();
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
-    Assertions.assertThat(versionHintFile).as("Should create version hint file").exists();
-    Assertions.assertThat(readVersionHint())
+    assertThat(tasks).as("Should not create any scan tasks").isEmpty();
+    assertThat(tableDir).as("Table location should exist").exists();
+    assertThat(metadataDir).as("Should create metadata folder").exists().isDirectory();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(versionHintFile).as("Should create version hint file").exists();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(1);
     List<File> manifests = listManifestFiles();
-    Assertions.assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
+    assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
   }
 
   @Test
   public void testSchemaUpdate() throws Exception {
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
 
     table.updateSchema().addColumn("n", Types.IntegerType.get()).commit();
 
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(2);
-    Assertions.assertThat(table.schema().asStruct())
+    assertThat(table.schema().asStruct())
         .as("Table schema should match schema with reassigned ids")
         .isEqualTo(UPDATED_SCHEMA.asStruct());
 
     List<FileScanTask> tasks = Lists.newArrayList(table.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should not create any scan tasks").isEmpty();
+    assertThat(tasks).as("Should not create any scan tasks").isEmpty();
 
     List<File> manifests = listManifestFiles();
-    Assertions.assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
+    assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
   }
 
   @Test
   public void testSchemaUpdateComplexType() throws Exception {
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
 
     Types.StructType complexColumn =
         Types.StructType.of(
@@ -146,25 +147,25 @@ public class TestHadoopCommits extends HadoopTableTestBase {
 
     table.updateSchema().addColumn("complex", complexColumn).commit();
 
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(2);
-    Assertions.assertThat(table.schema().asStruct())
+    assertThat(table.schema().asStruct())
         .as("Table schema should match schema with reassigned ids")
         .isEqualTo(updatedSchema.asStruct());
 
     List<FileScanTask> tasks = Lists.newArrayList(table.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should not create any scan tasks").isEmpty();
+    assertThat(tasks).as("Should not create any scan tasks").isEmpty();
 
     List<File> manifests = listManifestFiles();
-    Assertions.assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
+    assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
   }
 
   @Test
   public void testSchemaUpdateIdentifierFields() throws Exception {
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
 
     Schema updatedSchema =
         new Schema(
@@ -175,14 +176,14 @@ public class TestHadoopCommits extends HadoopTableTestBase {
 
     table.updateSchema().setIdentifierFields("id").commit();
 
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(2);
-    Assertions.assertThat(table.schema().asStruct())
+    assertThat(table.schema().asStruct())
         .as("Table schema should match schema with reassigned ids")
         .isEqualTo(updatedSchema.asStruct());
-    Assertions.assertThat(table.schema().identifierFieldIds())
+    assertThat(table.schema().identifierFieldIds())
         .as("Identifier fields should match schema with reassigned ids")
         .isEqualTo(updatedSchema.identifierFieldIds());
   }
@@ -193,25 +194,25 @@ public class TestHadoopCommits extends HadoopTableTestBase {
     UpdateSchema update = table.updateSchema().addColumn("n", Types.IntegerType.get());
     update.apply();
 
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
 
     version(2).createNewFile();
 
-    Assertions.assertThatThrownBy(update::commit)
+    assertThatThrownBy(update::commit)
         .isInstanceOf(CommitFailedException.class)
         .hasMessageStartingWith("Version 2 already exists");
 
     List<File> manifests = listManifestFiles();
-    Assertions.assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
+    assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
   }
 
   @Test
   public void testStaleMetadata() throws Exception {
     Table tableCopy = TABLES.load(tableLocation);
 
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
 
     // prepare changes on the copy without committing
     UpdateSchema updateCopy = tableCopy.updateSchema().addColumn("m", Types.IntegerType.get());
@@ -219,40 +220,40 @@ public class TestHadoopCommits extends HadoopTableTestBase {
 
     table.updateSchema().addColumn("n", Types.IntegerType.get()).commit();
 
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(table.schema().asStruct())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(table.schema().asStruct())
         .as("Unmodified copy should be out of date after update")
         .isNotEqualTo(tableCopy.schema().asStruct());
 
     // update the table
     tableCopy.refresh();
 
-    Assertions.assertThat(table.schema().asStruct())
+    assertThat(table.schema().asStruct())
         .as("Copy should be back in sync")
         .isEqualTo(tableCopy.schema().asStruct());
 
-    Assertions.assertThatThrownBy(updateCopy::commit)
+    assertThatThrownBy(updateCopy::commit)
         .isInstanceOf(CommitFailedException.class)
         .hasMessage("Cannot commit changes based on stale table metadata");
 
     List<File> manifests = listManifestFiles();
-    Assertions.assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
+    assertThat(manifests).as("Should contain 0 Avro manifest files").isEmpty();
   }
 
   @Test
   public void testStaleVersionHint() throws Exception {
     Table stale = TABLES.load(tableLocation);
 
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
 
     table.updateSchema().addColumn("n", Types.IntegerType.get()).commit();
 
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(2);
-    Assertions.assertThat(stale.schema().asStruct())
+    assertThat(stale.schema().asStruct())
         .as("Stable table schema should not match")
         .isNotEqualTo(UPDATED_SCHEMA.asStruct());
 
@@ -260,12 +261,12 @@ public class TestHadoopCommits extends HadoopTableTestBase {
     replaceVersionHint(1);
 
     Table reloaded = TABLES.load(tableLocation);
-    Assertions.assertThat(reloaded.schema().asStruct())
+    assertThat(reloaded.schema().asStruct())
         .as("Updated schema for newly loaded table should match")
         .isEqualTo(UPDATED_SCHEMA.asStruct());
 
     stale.refresh();
-    Assertions.assertThat(reloaded.schema().asStruct())
+    assertThat(reloaded.schema().asStruct())
         .as("Refreshed schema for stale table should match")
         .isEqualTo(UPDATED_SCHEMA.asStruct());
   }
@@ -275,33 +276,31 @@ public class TestHadoopCommits extends HadoopTableTestBase {
     // first append
     table.newFastAppend().appendFile(FILE_A).commit();
 
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(2);
 
     List<FileScanTask> tasks = Lists.newArrayList(table.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should scan 1 file").hasSize(1);
+    assertThat(tasks).as("Should scan 1 file").hasSize(1);
 
     List<File> manifests = listManifestFiles();
-    Assertions.assertThat(manifests).as("Should contain only one Avro manifest file").hasSize(1);
+    assertThat(manifests).as("Should contain only one Avro manifest file").hasSize(1);
 
     // second append
     table.newFastAppend().appendFile(FILE_B).commit();
 
-    Assertions.assertThat(version(3)).as("Should create v3 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(3)).as("Should create v3 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(3);
 
     tasks = Lists.newArrayList(table.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should scan 2 files").hasSize(2);
-    Assertions.assertThat(listManifestFiles())
-        .as("Should contain 2 Avro manifest files")
-        .hasSize(2);
+    assertThat(tasks).as("Should scan 2 files").hasSize(2);
+    assertThat(listManifestFiles()).as("Should contain 2 Avro manifest files").hasSize(2);
 
     TableMetadata metadata = readMetadataVersion(3);
-    Assertions.assertThat(metadata.currentSnapshot().allManifests(table.io()))
+    assertThat(metadata.currentSnapshot().allManifests(table.io()))
         .as("Current snapshot should contain 2 manifests")
         .hasSize(2);
   }
@@ -317,14 +316,12 @@ public class TestHadoopCommits extends HadoopTableTestBase {
     table.newAppend().appendFile(FILE_C).commit();
 
     List<FileScanTask> tasks = Lists.newArrayList(table.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should scan 3 files").hasSize(3);
+    assertThat(tasks).as("Should scan 3 files").hasSize(3);
 
-    Assertions.assertThat(listManifestFiles())
-        .as("Should contain 3 Avro manifest files")
-        .hasSize(3);
+    assertThat(listManifestFiles()).as("Should contain 3 Avro manifest files").hasSize(3);
 
     TableMetadata metadata = readMetadataVersion(5);
-    Assertions.assertThat(metadata.currentSnapshot().allManifests(table.io()))
+    assertThat(metadata.currentSnapshot().allManifests(table.io()))
         .as("Current snapshot should contain 1 merged manifest")
         .hasSize(1);
   }
@@ -350,9 +347,9 @@ public class TestHadoopCommits extends HadoopTableTestBase {
    * provided {@link FileSystem} object. The provided FileSystem will be injected for commit call.
    */
   private void testRenameWithFileSystem(FileSystem mockFs) throws Exception {
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
-    Assertions.assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
-    Assertions.assertThat(table).isInstanceOf(BaseTable.class);
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(2)).as("Should not create v2 or newer versions").doesNotExist();
+    assertThat(table).isInstanceOf(BaseTable.class);
     BaseTable baseTable = (BaseTable) table;
     // use v1 metafile as the test rename destination.
     TableMetadata meta1 = baseTable.operations().current();
@@ -361,33 +358,31 @@ public class TestHadoopCommits extends HadoopTableTestBase {
     // (so that we have 2 valid and different metadata files, which will reach the rename part
     // during commit)
     table.updateSchema().addColumn("n", Types.IntegerType.get()).commit();
-    Assertions.assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
-    Assertions.assertThat(readVersionHint())
+    assertThat(version(2)).as("Should create v2 for the update").exists().isFile();
+    assertThat(readVersionHint())
         .as("Should write the current version to the hint file")
         .isEqualTo(2);
 
     // mock / spy the classes for testing
     TableOperations tops = baseTable.operations();
-    Assertions.assertThat(tops).isInstanceOf(HadoopTableOperations.class);
+    assertThat(tops).isInstanceOf(HadoopTableOperations.class);
     HadoopTableOperations spyOps = Mockito.spy((HadoopTableOperations) tops);
 
     // inject the mockFS into the TableOperations
     doReturn(mockFs).when(spyOps).getFileSystem(any(), any());
-    Assertions.assertThatThrownBy(() -> spyOps.commit(tops.current(), meta1))
+    assertThatThrownBy(() -> spyOps.commit(tops.current(), meta1))
         .isInstanceOf(CommitFailedException.class);
 
     // Verifies that there is no temporary metadata.json files left on rename failures.
     Set<String> actual =
         listMetadataJsonFiles().stream().map(File::getName).collect(Collectors.toSet());
     Set<String> expected = Sets.newHashSet("v1.metadata.json", "v2.metadata.json");
-    Assertions.assertThat(actual)
-        .as("only v1 and v2 metadata.json should exist.")
-        .isEqualTo(expected);
+    assertThat(actual).as("only v1 and v2 metadata.json should exist.").isEqualTo(expected);
   }
 
   @Test
   public void testCanReadOldCompressedManifestFiles() throws Exception {
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
 
     // do a file append
     table.newAppend().appendFile(FILE_A).commit();
@@ -399,20 +394,20 @@ public class TestHadoopCommits extends HadoopTableTestBase {
 
     List<File> metadataFiles = listMetadataJsonFiles();
 
-    Assertions.assertThat(metadataFiles).as("Should have two versions").hasSize(2);
-    Assertions.assertThat(metadataFiles.stream().map(File::getName))
+    assertThat(metadataFiles).as("Should have two versions").hasSize(2);
+    assertThat(metadataFiles.stream().map(File::getName))
         .as("Metadata should be compressed with old format.")
         .allMatch(f -> f.endsWith(".metadata.json.gz"));
 
     Table reloaded = TABLES.load(tableLocation);
 
     List<FileScanTask> tasks = Lists.newArrayList(reloaded.newScan().planFiles());
-    Assertions.assertThat(tasks).as("Should scan 1 files").hasSize(1);
+    assertThat(tasks).as("Should scan 1 files").hasSize(1);
   }
 
   @Test
   public void testConcurrentFastAppends(@TempDir File dir) throws Exception {
-    Assertions.assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
+    assertThat(version(1)).as("Should create v1 metadata").exists().isFile();
     int threadsCount = 5;
     int numberOfCommitedFilesPerThread = 10;
     Table tableWithHighRetries =
@@ -452,7 +447,7 @@ public class TestHadoopCommits extends HadoopTableTestBase {
             });
 
     tableWithHighRetries.refresh();
-    Assertions.assertThat(Lists.newArrayList(tableWithHighRetries.snapshots()))
+    assertThat(Lists.newArrayList(tableWithHighRetries.snapshots()))
         .hasSize(threadsCount * numberOfCommitedFilesPerThread);
   }
 
@@ -467,7 +462,7 @@ public class TestHadoopCommits extends HadoopTableTestBase {
     tableOperations.refresh();
     BaseTable baseTable = (BaseTable) table;
     TableMetadata meta2 = baseTable.operations().current();
-    Assertions.assertThatThrownBy(() -> tableOperations.commit(tableOperations.current(), meta2))
+    assertThatThrownBy(() -> tableOperations.commit(tableOperations.current(), meta2))
         .isInstanceOf(CommitFailedException.class)
         .hasMessageStartingWith("Failed to acquire lock on file");
   }
