@@ -18,45 +18,45 @@
  */
 package org.apache.iceberg.io;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+import java.util.Arrays;
 import java.util.List;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DeleteFile;
 import org.apache.iceberg.FileFormat;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.RowDelta;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.util.StructLikeSet;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
 
-  @Parameterized.Parameters(name = "FileFormat={0}")
-  public static Object[] parameters() {
-    return new Object[][] {
-      new Object[] {FileFormat.AVRO},
-      new Object[] {FileFormat.ORC},
-      new Object[] {FileFormat.PARQUET}
-    };
+  @Parameters(name = "formatVersion = {0}, fileFormat = {1}")
+  protected static List<Object> parameters() {
+    return Arrays.asList(
+        new Object[] {2, FileFormat.AVRO},
+        new Object[] {2, FileFormat.ORC},
+        new Object[] {2, FileFormat.PARQUET});
   }
 
-  private static final int TABLE_FORMAT_VERSION = 2;
   private static final long TARGET_FILE_SIZE = 128L * 1024 * 1024;
 
-  private final FileFormat fileFormat;
-  private OutputFileFactory fileFactory = null;
+  @Parameter(index = 1)
+  private FileFormat fileFormat;
 
-  public TestPositionDeltaWriters(FileFormat fileFormat) {
-    super(TABLE_FORMAT_VERSION);
-    this.fileFormat = fileFormat;
-  }
+  private OutputFileFactory fileFactory = null;
 
   protected abstract StructLikeSet toSet(Iterable<T> records);
 
@@ -65,17 +65,17 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
   }
 
   @Override
-  @Before
+  @BeforeEach
   public void setupTable() throws Exception {
-    this.tableDir = temp.newFolder();
-    Assert.assertTrue(tableDir.delete()); // created during table creation
+    this.tableDir = Files.createTempDirectory(temp, "junit").toFile();
+    assertThat(tableDir.delete()).isTrue(); // created during table creation
 
     this.metadataDir = new File(tableDir, "metadata");
     this.table = create(SCHEMA, PartitionSpec.unpartitioned());
     this.fileFactory = OutputFileFactory.builderFor(table, 1, 1).format(fileFormat).build();
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeltaWithOneDataWriter() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -95,12 +95,12 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
     DeleteFile[] deleteFiles = result.deleteFiles();
     CharSequence[] referencedDataFiles = result.referencedDataFiles();
 
-    Assert.assertEquals("Must be 1 data files", 1, dataFiles.length);
-    Assert.assertEquals("Must be no delete files", 0, deleteFiles.length);
-    Assert.assertEquals("Must not reference data files", 0, referencedDataFiles.length);
+    assertThat(dataFiles).hasSize(1);
+    assertThat(deleteFiles).isEmpty();
+    assertThat(referencedDataFiles).isEmpty();
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeltaInsertOnly() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -122,9 +122,9 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
     DeleteFile[] deleteFiles = result.deleteFiles();
     CharSequence[] referencedDataFiles = result.referencedDataFiles();
 
-    Assert.assertEquals("Must be 1 data files", 1, dataFiles.length);
-    Assert.assertEquals("Must be no delete files", 0, deleteFiles.length);
-    Assert.assertEquals("Must not reference data files", 0, referencedDataFiles.length);
+    assertThat(dataFiles).hasSize(1);
+    assertThat(deleteFiles).isEmpty();
+    assertThat(referencedDataFiles).isEmpty();
 
     RowDelta rowDelta = table.newRowDelta();
     for (DataFile dataFile : dataFiles) {
@@ -133,10 +133,10 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
     rowDelta.commit();
 
     List<T> expectedRows = ImmutableList.of(toRow(1, "aaa"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeltaDeleteOnly() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -178,10 +178,9 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
     DeleteFile[] deleteFiles = result.deleteFiles();
     CharSequence[] referencedDataFiles = result.referencedDataFiles();
 
-    Assert.assertEquals("Must be 0 data files", 0, dataFiles.length);
-    Assert.assertEquals("Must be 2 delete files", 2, deleteFiles.length);
-    Assert.assertEquals("Must reference 2 data files", 2, referencedDataFiles.length);
-
+    assertThat(dataFiles).isEmpty();
+    assertThat(deleteFiles).hasSize(2);
+    assertThat(referencedDataFiles).hasSize(2);
     RowDelta rowDelta = table.newRowDelta();
     for (DeleteFile deleteFile : deleteFiles) {
       rowDelta.addDeletes(deleteFile);
@@ -189,10 +188,10 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
     rowDelta.commit();
 
     List<T> expectedRows = ImmutableList.of(toRow(1, "aaa"), toRow(2, "aaa"), toRow(3, "bbb"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 
-  @Test
+  @TestTemplate
   public void testPositionDeltaMultipleSpecs() throws IOException {
     FileWriterFactory<T> writerFactory = newWriterFactory(table.schema());
 
@@ -235,9 +234,9 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
     DeleteFile[] deleteFiles = result.deleteFiles();
     CharSequence[] referencedDataFiles = result.referencedDataFiles();
 
-    Assert.assertEquals("Must be 1 data files", 1, dataFiles.length);
-    Assert.assertEquals("Must be 2 delete files", 2, deleteFiles.length);
-    Assert.assertEquals("Must reference 2 data files", 2, referencedDataFiles.length);
+    assertThat(dataFiles).hasSize(1);
+    assertThat(deleteFiles).hasSize(2);
+    assertThat(referencedDataFiles).hasSize(2);
 
     RowDelta rowDelta = table.newRowDelta();
     for (DataFile dataFile : dataFiles) {
@@ -250,6 +249,6 @@ public abstract class TestPositionDeltaWriters<T> extends WriterTestBase<T> {
 
     List<T> expectedRows =
         ImmutableList.of(toRow(1, "aaa"), toRow(2, "aaa"), toRow(3, "bbb"), toRow(10, "ccc"));
-    Assert.assertEquals("Records should match", toSet(expectedRows), actualRowSet("*"));
+    assertThat(actualRowSet("*")).isEqualTo(toSet(expectedRows));
   }
 }
