@@ -18,6 +18,10 @@
  */
 package org.apache.iceberg.flink.sink;
 
+import static org.apache.iceberg.flink.TestFixtures.DATABASE;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.io.IOException;
 import java.util.Collections;
 import java.util.List;
@@ -27,17 +31,21 @@ import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.data.RowData;
-import org.apache.flink.test.util.MiniClusterWithClientResource;
+import org.apache.flink.test.junit5.MiniClusterExtension;
 import org.apache.flink.types.Row;
 import org.apache.iceberg.DistributionMode;
 import org.apache.iceberg.FileFormat;
+import org.apache.iceberg.Parameter;
+import org.apache.iceberg.ParameterizedTestExtension;
+import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.flink.FlinkWriteOptions;
-import org.apache.iceberg.flink.HadoopCatalogResource;
+import org.apache.iceberg.flink.HadoopCatalogExtension;
 import org.apache.iceberg.flink.MiniClusterResource;
+import org.apache.iceberg.flink.MiniFlinkClusterExtension;
 import org.apache.iceberg.flink.SimpleDataUtil;
 import org.apache.iceberg.flink.TableLoader;
 import org.apache.iceberg.flink.TestFixtures;
@@ -45,63 +53,55 @@ import org.apache.iceberg.flink.util.FlinkCompatibilityUtil;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
-import org.assertj.core.api.Assertions;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.extension.RegisterExtension;
 
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
 
-  @ClassRule
-  public static final MiniClusterWithClientResource MINI_CLUSTER_RESOURCE =
-      MiniClusterResource.createWithClassloaderCheckDisabled();
+  @RegisterExtension
+  public static MiniClusterExtension miniClusterResource =
+      MiniFlinkClusterExtension.createWithClassloaderCheckDisabled();
 
-  @ClassRule public static final TemporaryFolder TEMPORARY_FOLDER = new TemporaryFolder();
-
-  @Rule
-  public final HadoopCatalogResource catalogResource =
-      new HadoopCatalogResource(TEMPORARY_FOLDER, TestFixtures.DATABASE, TestFixtures.TABLE);
+  @RegisterExtension
+  private static final HadoopCatalogExtension CATALOG_EXTENSION =
+      new HadoopCatalogExtension(DATABASE, TestFixtures.TABLE);
 
   private TableLoader tableLoader;
 
-  private final FileFormat format;
-  private final int parallelism;
-  private final boolean partitioned;
+  @Parameter(index = 0)
+  private FileFormat format;
 
-  @Parameterized.Parameters(name = "format={0}, parallelism = {1}, partitioned = {2}")
+  @Parameter(index = 1)
+  private int parallelism;
+
+  @Parameter(index = 2)
+  private boolean partitioned;
+
+  @Parameters(name = "format={0}, parallelism = {1}, partitioned = {2}")
   public static Object[][] parameters() {
     return new Object[][] {
-      {"avro", 1, true},
-      {"avro", 1, false},
-      {"avro", 2, true},
-      {"avro", 2, false},
-      {"orc", 1, true},
-      {"orc", 1, false},
-      {"orc", 2, true},
-      {"orc", 2, false},
-      {"parquet", 1, true},
-      {"parquet", 1, false},
-      {"parquet", 2, true},
-      {"parquet", 2, false}
+      {FileFormat.AVRO, 1, true},
+      {FileFormat.AVRO, 1, false},
+      {FileFormat.AVRO, 2, true},
+      {FileFormat.AVRO, 2, false},
+      {FileFormat.ORC, 1, true},
+      {FileFormat.ORC, 1, false},
+      {FileFormat.ORC, 2, true},
+      {FileFormat.ORC, 2, false},
+      {FileFormat.PARQUET, 1, true},
+      {FileFormat.PARQUET, 1, false},
+      {FileFormat.PARQUET, 2, true},
+      {FileFormat.PARQUET, 2, false}
     };
   }
 
-  public TestFlinkIcebergSink(String format, int parallelism, boolean partitioned) {
-    this.format = FileFormat.fromString(format);
-    this.parallelism = parallelism;
-    this.partitioned = partitioned;
-  }
-
-  @Before
+  @BeforeEach
   public void before() throws IOException {
     table =
-        catalogResource
+        CATALOG_EXTENSION
             .catalog()
             .createTable(
                 TestFixtures.TABLE_IDENTIFIER,
@@ -118,10 +118,10 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
             .setParallelism(parallelism)
             .setMaxParallelism(parallelism);
 
-    tableLoader = catalogResource.tableLoader();
+    tableLoader = CATALOG_EXTENSION.tableLoader();
   }
 
-  @Test
+  @TestTemplate
   public void testWriteRowData() throws Exception {
     List<Row> rows = Lists.newArrayList(Row.of(1, "hello"), Row.of(2, "world"), Row.of(3, "foo"));
     DataStream<RowData> dataStream =
@@ -164,17 +164,17 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
     return SimpleDataUtil.partitionDataFiles(table, ImmutableMap.of("data", partition)).size();
   }
 
-  @Test
+  @TestTemplate
   public void testWriteRow() throws Exception {
     testWriteRow(null, DistributionMode.NONE);
   }
 
-  @Test
+  @TestTemplate
   public void testWriteRowWithTableSchema() throws Exception {
     testWriteRow(SimpleDataUtil.FLINK_SCHEMA, DistributionMode.NONE);
   }
 
-  @Test
+  @TestTemplate
   public void testJobNoneDistributeMode() throws Exception {
     table
         .updateProperties()
@@ -186,24 +186,24 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
     if (parallelism > 1) {
       if (partitioned) {
         int files = partitionFiles("aaa") + partitionFiles("bbb") + partitionFiles("ccc");
-        Assert.assertTrue("Should have more than 3 files in iceberg table.", files > 3);
+        assertThat(files).isGreaterThan(3);
       }
     }
   }
 
-  @Test
+  @TestTemplate
   public void testJobHashDistributionMode() {
     table
         .updateProperties()
         .set(TableProperties.WRITE_DISTRIBUTION_MODE, DistributionMode.HASH.modeName())
         .commit();
 
-    Assertions.assertThatThrownBy(() -> testWriteRow(null, DistributionMode.RANGE))
+    assertThatThrownBy(() -> testWriteRow(null, DistributionMode.RANGE))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Flink does not support 'range' write distribution mode now.");
   }
 
-  @Test
+  @TestTemplate
   public void testJobNullDistributionMode() throws Exception {
     table
         .updateProperties()
@@ -213,47 +213,38 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
     testWriteRow(null, null);
 
     if (partitioned) {
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'aaa'", 1, partitionFiles("aaa"));
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'bbb'", 1, partitionFiles("bbb"));
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'ccc'", 1, partitionFiles("ccc"));
+      assertThat(partitionFiles("aaa")).isEqualTo(1);
+      assertThat(partitionFiles("bbb")).isEqualTo(1);
+      assertThat(partitionFiles("ccc")).isEqualTo(1);
     }
   }
 
-  @Test
+  @TestTemplate
   public void testPartitionWriteMode() throws Exception {
     testWriteRow(null, DistributionMode.HASH);
     if (partitioned) {
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'aaa'", 1, partitionFiles("aaa"));
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'bbb'", 1, partitionFiles("bbb"));
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'ccc'", 1, partitionFiles("ccc"));
+      assertThat(partitionFiles("aaa")).isEqualTo(1);
+      assertThat(partitionFiles("bbb")).isEqualTo(1);
+      assertThat(partitionFiles("ccc")).isEqualTo(1);
     }
   }
 
-  @Test
+  @TestTemplate
   public void testShuffleByPartitionWithSchema() throws Exception {
     testWriteRow(SimpleDataUtil.FLINK_SCHEMA, DistributionMode.HASH);
     if (partitioned) {
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'aaa'", 1, partitionFiles("aaa"));
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'bbb'", 1, partitionFiles("bbb"));
-      Assert.assertEquals(
-          "There should be only 1 data file in partition 'ccc'", 1, partitionFiles("ccc"));
+      assertThat(partitionFiles("aaa")).isEqualTo(1);
+      assertThat(partitionFiles("bbb")).isEqualTo(1);
+      assertThat(partitionFiles("ccc")).isEqualTo(1);
     }
   }
 
-  @Test
+  @TestTemplate
   public void testTwoSinksInDisjointedDAG() throws Exception {
     Map<String, String> props = ImmutableMap.of(TableProperties.DEFAULT_FILE_FORMAT, format.name());
 
     Table leftTable =
-        catalogResource
+        CATALOG_EXTENSION
             .catalog()
             .createTable(
                 TableIdentifier.of("left"),
@@ -263,10 +254,10 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
                     : PartitionSpec.unpartitioned(),
                 props);
     TableLoader leftTableLoader =
-        TableLoader.fromCatalog(catalogResource.catalogLoader(), TableIdentifier.of("left"));
+        TableLoader.fromCatalog(CATALOG_EXTENSION.catalogLoader(), TableIdentifier.of("left"));
 
     Table rightTable =
-        catalogResource
+        CATALOG_EXTENSION
             .catalog()
             .createTable(
                 TableIdentifier.of("right"),
@@ -276,7 +267,7 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
                     : PartitionSpec.unpartitioned(),
                 props);
     TableLoader rightTableLoader =
-        TableLoader.fromCatalog(catalogResource.catalogLoader(), TableIdentifier.of("right"));
+        TableLoader.fromCatalog(CATALOG_EXTENSION.catalogLoader(), TableIdentifier.of("right"));
 
     env =
         StreamExecutionEnvironment.getExecutionEnvironment(
@@ -322,16 +313,14 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
     SimpleDataUtil.assertTableRows(rightTable, convertToRowData(rightRows));
 
     leftTable.refresh();
-    Assert.assertNull(leftTable.currentSnapshot().summary().get("flink.test"));
-    Assert.assertNull(leftTable.currentSnapshot().summary().get("direction"));
+    assertThat(leftTable.currentSnapshot().summary()).doesNotContainKeys("flink.test", "direction");
     rightTable.refresh();
-    Assert.assertEquals(
-        TestFlinkIcebergSink.class.getName(),
-        rightTable.currentSnapshot().summary().get("flink.test"));
-    Assert.assertEquals("rightTable", rightTable.currentSnapshot().summary().get("direction"));
+    assertThat(rightTable.currentSnapshot().summary())
+        .containsEntry("flink.test", TestFlinkIcebergSink.class.getName())
+        .containsEntry("direction", "rightTable");
   }
 
-  @Test
+  @TestTemplate
   public void testOverrideWriteConfigWithUnknownDistributionMode() {
     Map<String, String> newProps = Maps.newHashMap();
     newProps.put(FlinkWriteOptions.DISTRIBUTION_MODE.key(), "UNRECOGNIZED");
@@ -346,12 +335,12 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
             .writeParallelism(parallelism)
             .setAll(newProps);
 
-    Assertions.assertThatThrownBy(builder::append)
+    assertThatThrownBy(builder::append)
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Invalid distribution mode: UNRECOGNIZED");
   }
 
-  @Test
+  @TestTemplate
   public void testOverrideWriteConfigWithUnknownFileFormat() {
     Map<String, String> newProps = Maps.newHashMap();
     newProps.put(FlinkWriteOptions.WRITE_FORMAT.key(), "UNRECOGNIZED");
@@ -366,12 +355,12 @@ public class TestFlinkIcebergSink extends TestFlinkIcebergSinkBase {
             .writeParallelism(parallelism)
             .setAll(newProps);
 
-    Assertions.assertThatThrownBy(builder::append)
+    assertThatThrownBy(builder::append)
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessage("Invalid file format: UNRECOGNIZED");
   }
 
-  @Test
+  @TestTemplate
   public void testWriteRowWithTableRefreshInterval() throws Exception {
     List<Row> rows = Lists.newArrayList(Row.of(1, "hello"), Row.of(2, "world"), Row.of(3, "foo"));
     DataStream<RowData> dataStream =
