@@ -18,6 +18,9 @@
  */
 package org.apache.iceberg.flink.source;
 
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.io.File;
 import java.io.IOException;
 import java.util.List;
@@ -29,52 +32,42 @@ import org.apache.iceberg.FileFormat;
 import org.apache.iceberg.events.Listeners;
 import org.apache.iceberg.events.ScanEvent;
 import org.apache.iceberg.expressions.Expressions;
-import org.apache.iceberg.flink.FlinkTestBase;
+import org.apache.iceberg.flink.TestBase;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.assertj.core.api.Assertions;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-public class TestFlinkTableSource extends FlinkTestBase {
+public class TestFlinkTableSource extends TestBase {
 
   private static final String CATALOG_NAME = "test_catalog";
   private static final String DATABASE_NAME = "test_db";
   private static final String TABLE_NAME = "test_table";
   private final FileFormat format = FileFormat.AVRO;
-  private static String warehouse;
 
   private int scanEventCount = 0;
   private ScanEvent lastScanEvent = null;
 
-  public TestFlinkTableSource() {
-    // register a scan event listener to validate pushdown
-    Listeners.register(
-        event -> {
-          scanEventCount += 1;
-          lastScanEvent = event;
-        },
-        ScanEvent.class);
-  }
-
   @Override
   protected TableEnvironment getTableEnv() {
     super.getTableEnv().getConfig().getConfiguration().set(CoreOptions.DEFAULT_PARALLELISM, 1);
     return super.getTableEnv();
   }
 
-  @BeforeClass
-  public static void createWarehouse() throws IOException {
-    File warehouseFile = TEMPORARY_FOLDER.newFolder();
-    Assert.assertTrue("The warehouse should be deleted", warehouseFile.delete());
-    // before variables
-    warehouse = "file:" + warehouseFile;
-  }
+  @BeforeEach
+  public void before() throws IOException {
+    // register a scan event listener to validate pushdown
+    Listeners.register(
+        event -> {
+          scanEventCount += 1;
+          lastScanEvent = event;
+        },
+        ScanEvent.class);
+
+    File warehouseFile = File.createTempFile("junit", null, temporaryDirectory.toFile());
+    assertThat(warehouseFile.delete()).isTrue();
+    String warehouse = String.format("file:%s", warehouseFile);
 
-  @Before
-  public void before() {
     sql(
         "CREATE CATALOG %s WITH ('type'='iceberg', 'catalog-type'='hadoop', 'warehouse'='%s')",
         CATALOG_NAME, warehouse);
@@ -92,26 +85,25 @@ public class TestFlinkTableSource extends FlinkTestBase {
     this.lastScanEvent = null;
   }
 
-  @After
+  @AfterEach
   public void clean() {
     sql("DROP TABLE IF EXISTS %s.%s", DATABASE_NAME, TABLE_NAME);
-    sql("DROP DATABASE IF EXISTS %s", DATABASE_NAME);
+    dropDatabase(DATABASE_NAME, true);
     dropCatalog(CATALOG_NAME, true);
   }
 
   @Test
   public void testLimitPushDown() {
 
-    Assertions.assertThatThrownBy(() -> sql("SELECT * FROM %s LIMIT -1", TABLE_NAME))
+    assertThatThrownBy(() -> sql("SELECT * FROM %s LIMIT -1", TABLE_NAME))
         .isInstanceOf(SqlParserException.class)
         .hasMessageStartingWith("SQL parse failed.");
 
-    Assert.assertEquals(
-        "Should have 0 record", 0, sql("SELECT * FROM %s LIMIT 0", TABLE_NAME).size());
+    assertThat(sql("SELECT * FROM %s LIMIT 0", TABLE_NAME)).isEmpty();
 
     String sqlLimitExceed = String.format("SELECT * FROM %s LIMIT 4", TABLE_NAME);
     List<Row> resultExceed = sql(sqlLimitExceed);
-    Assert.assertEquals("Should have 3 records", 3, resultExceed.size());
+    assertThat(resultExceed).hasSize(3);
     List<Row> expectedList =
         Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0), Row.of(3, null, 30.0));
     assertSameElements(expectedList, resultExceed);
@@ -119,16 +111,14 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String querySql = String.format("SELECT * FROM %s LIMIT 1", TABLE_NAME);
     String explain = getTableEnv().explainSql(querySql);
     String expectedExplain = "limit=[1]";
-    Assert.assertTrue("Explain should contain LimitPushDown", explain.contains(expectedExplain));
+    assertThat(explain).as("Explain should contain LimitPushDown").contains(expectedExplain);
     List<Row> result = sql(querySql);
-    Assert.assertEquals("Should have 1 record", 1, result.size());
-    Assertions.assertThat(result).containsAnyElementsOf(expectedList);
+    assertThat(result).hasSize(1);
+    assertThat(result).containsAnyElementsOf(expectedList);
 
     String sqlMixed = String.format("SELECT * FROM %s WHERE id = 1 LIMIT 2", TABLE_NAME);
     List<Row> mixedResult = sql(sqlMixed);
-    Assert.assertEquals("Should have 1 record", 1, mixedResult.size());
-    Assert.assertEquals(
-        "Should produce the expected records", Row.of(1, "iceberg", 10.0), mixedResult.get(0));
+    assertThat(mixedResult).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
   }
 
   @Test
@@ -138,8 +128,9 @@ public class TestFlinkTableSource extends FlinkTestBase {
     List<Row> expectedRecords =
         Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0), Row.of(3, null, 30.0));
     assertSameElements(expectedRecords, result);
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
   }
 
   @Test
@@ -148,13 +139,12 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") == 1";
 
     List<Row> result = sql(sqlLiteralRight);
-    Assert.assertEquals("Should have 1 record", 1, result.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), result.get(0));
-
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(result).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -162,8 +152,8 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlEqualNull = String.format("SELECT * FROM %s WHERE data = NULL ", TABLE_NAME);
 
     List<Row> result = sql(sqlEqualNull);
-    Assert.assertEquals("Should have 0 record", 0, result.size());
-    Assert.assertNull("Should not push down a filter", lastScanEvent);
+    assertThat(result).isEmpty();
+    assertThat(lastScanEvent).as("Should not push down a filter").isNull();
   }
 
   @Test
@@ -172,13 +162,12 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") == 1";
 
     List<Row> resultLeft = sql(sqlLiteralLeft);
-    Assert.assertEquals("Should have 1 record", 1, resultLeft.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), resultLeft.get(0));
-
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(resultLeft).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -187,13 +176,15 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") != 1";
 
     List<Row> resultNE = sql(sqlNE);
-    Assert.assertEquals("Should have 2 records", 2, resultNE.size());
+    assertThat(resultNE).hasSize(2);
 
     List<Row> expectedNE = Lists.newArrayList(Row.of(2, "b", 20.0), Row.of(3, null, 30.0));
     assertSameElements(expectedNE, resultNE);
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -201,8 +192,8 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlNotEqualNull = String.format("SELECT * FROM %s WHERE data <> NULL ", TABLE_NAME);
 
     List<Row> resultNE = sql(sqlNotEqualNull);
-    Assert.assertEquals("Should have 0 records", 0, resultNE.size());
-    Assert.assertNull("Should not push down a filter", lastScanEvent);
+    assertThat(resultNE).isEmpty();
+    assertThat(lastScanEvent).as("Should not push down a filter").isNull();
   }
 
   @Test
@@ -211,14 +202,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
         String.format("SELECT * FROM %s WHERE id = 1 AND data = 'iceberg' ", TABLE_NAME);
 
     List<Row> resultAnd = sql(sqlAnd);
-    Assert.assertEquals("Should have 1 record", 1, resultAnd.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), resultAnd.get(0));
-
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    assertThat(resultAnd).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
+    assertThat(scanEventCount).isEqualTo(1);
     String expected = "(ref(name=\"id\") == 1 and ref(name=\"data\") == \"iceberg\")";
-    Assert.assertEquals(
-        "Should contain the push down filter", expected, lastScanEvent.filter().toString());
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expected);
   }
 
   @Test
@@ -227,14 +217,16 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "(ref(name=\"id\") == 1 or ref(name=\"data\") == \"b\")";
 
     List<Row> resultOr = sql(sqlOr);
-    Assert.assertEquals("Should have 2 record", 2, resultOr.size());
+    assertThat(resultOr).hasSize(2);
 
     List<Row> expectedOR = Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expectedOR, resultOr);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -243,14 +235,16 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") > 1";
 
     List<Row> resultGT = sql(sqlGT);
-    Assert.assertEquals("Should have 2 record", 2, resultGT.size());
+    assertThat(resultGT).hasSize(2);
 
     List<Row> expectedGT = Lists.newArrayList(Row.of(2, "b", 20.0), Row.of(3, null, 30.0));
     assertSameElements(expectedGT, resultGT);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -258,8 +252,8 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlGT = String.format("SELECT * FROM %s WHERE data > null ", TABLE_NAME);
 
     List<Row> resultGT = sql(sqlGT);
-    Assert.assertEquals("Should have 0 record", 0, resultGT.size());
-    Assert.assertNull("Should not push down a filter", lastScanEvent);
+    assertThat(resultGT).isEmpty();
+    assertThat(lastScanEvent).as("Should not push down a filter").isNull();
   }
 
   @Test
@@ -268,14 +262,16 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") < 3";
 
     List<Row> resultGT = sql(sqlGT);
-    Assert.assertEquals("Should have 2 records", 2, resultGT.size());
+    assertThat(resultGT).hasSize(2);
 
     List<Row> expectedGT = Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expectedGT, resultGT);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -284,14 +280,16 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") >= 2";
 
     List<Row> resultGTE = sql(sqlGTE);
-    Assert.assertEquals("Should have 2 records", 2, resultGTE.size());
+    assertThat(resultGTE).hasSize(2);
 
     List<Row> expectedGTE = Lists.newArrayList(Row.of(2, "b", 20.0), Row.of(3, null, 30.0));
     assertSameElements(expectedGTE, resultGTE);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -299,8 +297,8 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlGTE = String.format("SELECT * FROM %s WHERE data >= null ", TABLE_NAME);
 
     List<Row> resultGT = sql(sqlGTE);
-    Assert.assertEquals("Should have 0 record", 0, resultGT.size());
-    Assert.assertNull("Should not push down a filter", lastScanEvent);
+    assertThat(resultGT).isEmpty();
+    assertThat(lastScanEvent).as("Should not push down a filter").isNull();
   }
 
   @Test
@@ -309,14 +307,16 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") <= 2";
 
     List<Row> resultGTE = sql(sqlGTE);
-    Assert.assertEquals("Should have 2 records", 2, resultGTE.size());
+    assertThat(resultGTE).hasSize(2);
 
     List<Row> expectedGTE = Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expectedGTE, resultGTE);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -325,13 +325,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") < 2";
 
     List<Row> resultLT = sql(sqlLT);
-    Assert.assertEquals("Should have 1 record", 1, resultLT.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), resultLT.get(0));
+    assertThat(resultLT).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -339,8 +339,8 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlLT = String.format("SELECT * FROM %s WHERE data < null ", TABLE_NAME);
 
     List<Row> resultGT = sql(sqlLT);
-    Assert.assertEquals("Should have 0 record", 0, resultGT.size());
-    Assert.assertNull("Should not push down a filter", lastScanEvent);
+    assertThat(resultGT).isEmpty();
+    assertThat(lastScanEvent).as("Should not push down a filter").isNull();
   }
 
   @Test
@@ -349,13 +349,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") > 2";
 
     List<Row> resultLT = sql(sqlLT);
-    Assert.assertEquals("Should have 1 record", 1, resultLT.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(3, null, 30.0), resultLT.get(0));
+    assertThat(resultLT).hasSize(1).first().isEqualTo(Row.of(3, null, 30.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -364,13 +364,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") <= 1";
 
     List<Row> resultLTE = sql(sqlLTE);
-    Assert.assertEquals("Should have 1 record", 1, resultLTE.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), resultLTE.get(0));
+    assertThat(resultLTE).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -378,8 +378,8 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlLTE = String.format("SELECT * FROM %s WHERE data <= null ", TABLE_NAME);
 
     List<Row> resultGT = sql(sqlLTE);
-    Assert.assertEquals("Should have 0 record", 0, resultGT.size());
-    Assert.assertNull("Should not push down a filter", lastScanEvent);
+    assertThat(resultGT).isEmpty();
+    assertThat(lastScanEvent).as("Should not push down a filter").isNull();
   }
 
   @Test
@@ -388,13 +388,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "ref(name=\"id\") >= 3";
 
     List<Row> resultLTE = sql(sqlLTE);
-    Assert.assertEquals("Should have 1 record", 1, resultLTE.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(3, null, 30.0), resultLTE.get(0));
+    assertThat(resultLTE).hasSize(1).first().isEqualTo(Row.of(3, null, 30.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -402,13 +402,15 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlIN = String.format("SELECT * FROM %s WHERE id IN (1,2) ", TABLE_NAME);
     String expectedFilter = "(ref(name=\"id\") == 1 or ref(name=\"id\") == 2)";
     List<Row> resultIN = sql(sqlIN);
-    Assert.assertEquals("Should have 2 records", 2, resultIN.size());
+    assertThat(resultIN).hasSize(2);
 
     List<Row> expectedIN = Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expectedIN, resultIN);
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -417,15 +419,15 @@ public class TestFlinkTableSource extends FlinkTestBase {
         String.format("SELECT * FROM %s WHERE data IN ('iceberg',NULL) ", TABLE_NAME);
 
     List<Row> result = sql(sqlInNull);
-    Assert.assertEquals("Should have 1 record", 1, result.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), result.get(0));
+    assertThat(result).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
 
     // In SQL, null check can only be done as IS NULL or IS NOT NULL, so it's correct to ignore it
     // and push the rest down.
     String expectedScan = "ref(name=\"data\") == \"iceberg\"";
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedScan, lastScanEvent.filter().toString());
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedScan);
   }
 
   @Test
@@ -433,23 +435,24 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlNotIn = String.format("SELECT * FROM %s WHERE id NOT IN (3,2) ", TABLE_NAME);
 
     List<Row> resultNotIn = sql(sqlNotIn);
-    Assert.assertEquals("Should have 1 record", 1, resultNotIn.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), resultNotIn.get(0));
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    assertThat(resultNotIn).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
+    assertThat(scanEventCount).isEqualTo(1);
     String expectedScan = "(ref(name=\"id\") != 2 and ref(name=\"id\") != 3)";
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedScan, lastScanEvent.filter().toString());
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedScan);
   }
 
   @Test
   public void testFilterPushDownNotInNull() {
     String sqlNotInNull = String.format("SELECT * FROM %s WHERE id NOT IN (1,2,NULL) ", TABLE_NAME);
     List<Row> resultGT = sql(sqlNotInNull);
-    Assert.assertEquals("Should have 0 record", 0, resultGT.size());
-    Assert.assertNull(
-        "As the predicate pushdown filter out all rows, Flink did not create scan plan, so it doesn't publish any ScanEvent.",
-        lastScanEvent);
+    assertThat(resultGT).isEmpty();
+    assertThat(lastScanEvent)
+        .as(
+            "As the predicate pushdown filter out all rows, Flink did not create scan plan, so it doesn't publish any ScanEvent.")
+        .isNull();
   }
 
   @Test
@@ -458,14 +461,16 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "not_null(ref(name=\"data\"))";
 
     List<Row> resultNotNull = sql(sqlNotNull);
-    Assert.assertEquals("Should have 2 record", 2, resultNotNull.size());
+    assertThat(resultNotNull).hasSize(2);
 
     List<Row> expected = Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expected, resultNotNull);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -474,13 +479,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "is_null(ref(name=\"data\"))";
 
     List<Row> resultNull = sql(sqlNull);
-    Assert.assertEquals("Should have 1 record", 1, resultNull.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(3, null, 30.0), resultNull.get(0));
+    assertThat(resultNull).hasSize(1).first().isEqualTo(Row.of(3, null, 30.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -488,14 +493,14 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlNot = String.format("SELECT * FROM %s WHERE NOT (id = 1 OR id = 2 ) ", TABLE_NAME);
 
     List<Row> resultNot = sql(sqlNot);
-    Assert.assertEquals("Should have 1 record", 1, resultNot.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(3, null, 30.0), resultNot.get(0));
+    assertThat(resultNot).hasSize(1).first().isEqualTo(Row.of(3, null, 30.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    assertThat(scanEventCount).isEqualTo(1);
     String expectedFilter = "(ref(name=\"id\") != 1 and ref(name=\"id\") != 2)";
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -503,16 +508,18 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String sqlBetween = String.format("SELECT * FROM %s WHERE id BETWEEN 1 AND 2 ", TABLE_NAME);
 
     List<Row> resultBetween = sql(sqlBetween);
-    Assert.assertEquals("Should have 2 record", 2, resultBetween.size());
+    assertThat(resultBetween).hasSize(2);
 
     List<Row> expectedBetween =
         Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expectedBetween, resultBetween);
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
+    assertThat(scanEventCount).isEqualTo(1);
     String expected = "(ref(name=\"id\") >= 1 and ref(name=\"id\") <= 2)";
-    Assert.assertEquals(
-        "Should contain the push down filter", expected, lastScanEvent.filter().toString());
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expected);
   }
 
   @Test
@@ -522,13 +529,13 @@ public class TestFlinkTableSource extends FlinkTestBase {
     String expectedFilter = "(ref(name=\"id\") < 2 or ref(name=\"id\") > 3)";
 
     List<Row> resultNotBetween = sql(sqlNotBetween);
-    Assert.assertEquals("Should have 1 record", 1, resultNotBetween.size());
-    Assert.assertEquals(
-        "Should produce the expected record", Row.of(1, "iceberg", 10.0), resultNotBetween.get(0));
+    assertThat(resultNotBetween).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
 
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
   }
 
   @Test
@@ -537,25 +544,25 @@ public class TestFlinkTableSource extends FlinkTestBase {
 
     String sqlLike = "SELECT * FROM " + TABLE_NAME + " WHERE data LIKE 'ice%%' ";
     List<Row> resultLike = sql(sqlLike);
-    Assert.assertEquals("Should have 1 record", 1, resultLike.size());
-    Assert.assertEquals(
-        "The like result should produce the expected record",
-        Row.of(1, "iceberg", 10.0),
-        resultLike.get(0));
-    Assert.assertEquals("Should create only one scan", 1, scanEventCount);
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedFilter, lastScanEvent.filter().toString());
+    assertThat(resultLike).hasSize(1).first().isEqualTo(Row.of(1, "iceberg", 10.0));
+    assertThat(scanEventCount).isEqualTo(1);
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedFilter);
 
     // %% won't match the row with null value
     sqlLike = "SELECT * FROM  " + TABLE_NAME + "  WHERE data LIKE '%%' ";
     resultLike = sql(sqlLike);
-    Assert.assertEquals("Should have 2 records", 2, resultLike.size());
+    assertThat(resultLike).hasSize(2);
     List<Row> expectedRecords =
         Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0));
     assertSameElements(expectedRecords, resultLike);
     String expectedScan = "not_null(ref(name=\"data\"))";
-    Assert.assertEquals(
-        "Should contain the push down filter", expectedScan, lastScanEvent.filter().toString());
+    assertThat(lastScanEvent.filter())
+        .as("Should contain the push down filter")
+        .asString()
+        .isEqualTo(expectedScan);
   }
 
   @Test
@@ -563,37 +570,38 @@ public class TestFlinkTableSource extends FlinkTestBase {
     Row expectRecord = Row.of(1, "iceberg", 10.0);
     String sqlNoPushDown = "SELECT * FROM " + TABLE_NAME + " WHERE data LIKE '%%i' ";
     List<Row> resultLike = sql(sqlNoPushDown);
-    Assert.assertEquals("Should have 0 record", 0, resultLike.size());
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(resultLike).isEmpty();
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
 
     sqlNoPushDown = "SELECT * FROM " + TABLE_NAME + " WHERE data LIKE '%%i%%' ";
     resultLike = sql(sqlNoPushDown);
-    Assert.assertEquals("Should have 1 record", 1, resultLike.size());
-    Assert.assertEquals("Should produce the expected record", expectRecord, resultLike.get(0));
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(resultLike).hasSize(1).first().isEqualTo(expectRecord);
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
 
     sqlNoPushDown = "SELECT * FROM  " + TABLE_NAME + "  WHERE data LIKE '%%ice%%g' ";
     resultLike = sql(sqlNoPushDown);
-    Assert.assertEquals("Should have 1 record", 1, resultLike.size());
-    Assert.assertEquals("Should produce the expected record", expectRecord, resultLike.get(0));
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(resultLike).hasSize(1).first().isEqualTo(expectRecord);
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
 
     sqlNoPushDown = "SELECT * FROM  " + TABLE_NAME + "  WHERE data LIKE 'iceber_' ";
     resultLike = sql(sqlNoPushDown);
-    Assert.assertEquals("Should have 1 record", 1, resultLike.size());
-    Assert.assertEquals("Should produce the expected record", expectRecord, resultLike.get(0));
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(resultLike).hasSize(1).first().isEqualTo(expectRecord);
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
 
     sqlNoPushDown = "SELECT * FROM  " + TABLE_NAME + "  WHERE data LIKE 'i%%g' ";
     resultLike = sql(sqlNoPushDown);
-    Assert.assertEquals("Should have 1 record", 1, resultLike.size());
-    Assert.assertEquals("Should produce the expected record", expectRecord, resultLike.get(0));
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(resultLike).hasSize(1).first().isEqualTo(expectRecord);
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
   }
 
   @Test
@@ -603,8 +611,9 @@ public class TestFlinkTableSource extends FlinkTestBase {
     List<Row> expectedRecords =
         Lists.newArrayList(Row.of(1, "iceberg", 10.0), Row.of(2, "b", 20.0), Row.of(3, null, 30.0));
     assertSameElements(expectedRecords, result);
-    Assert.assertEquals(
-        "Should not push down a filter", Expressions.alwaysTrue(), lastScanEvent.filter());
+    assertThat(lastScanEvent.filter())
+        .as("Should not push down a filter")
+        .isEqualTo(Expressions.alwaysTrue());
   }
 
   @Test
