@@ -19,6 +19,7 @@
 package org.apache.iceberg.flink.source;
 
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.IOException;
 import java.util.Iterator;
@@ -44,38 +45,41 @@ import org.apache.iceberg.flink.CatalogTestBase;
 import org.apache.iceberg.flink.MiniClusterResource;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.assertj.core.api.Assertions;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.Timeout;
 
+@Timeout(60)
 public class TestStreamScanSql extends CatalogTestBase {
   private static final String TABLE = "test_table";
   private static final FileFormat FORMAT = FileFormat.PARQUET;
 
-  private TableEnvironment tEnv;
+  private volatile TableEnvironment tEnv;
 
   @Override
   protected TableEnvironment getTableEnv() {
-    if (tEnv == null) {
-      synchronized (this) {
-        if (tEnv == null) {
-          EnvironmentSettings.Builder settingsBuilder =
-              EnvironmentSettings.newInstance().inStreamingMode();
+    TableEnvironment tableEnv = tEnv;
+    if (tableEnv != null) {
+      return tableEnv;
+    }
+    synchronized (this) {
+      if (tEnv == null) {
+        EnvironmentSettings.Builder settingsBuilder =
+            EnvironmentSettings.newInstance().inStreamingMode();
 
-          StreamExecutionEnvironment env =
-              StreamExecutionEnvironment.getExecutionEnvironment(
-                  MiniClusterResource.DISABLE_CLASSLOADER_CHECK_CONFIG);
-          env.enableCheckpointing(400);
+        StreamExecutionEnvironment env =
+            StreamExecutionEnvironment.getExecutionEnvironment(
+                MiniClusterResource.DISABLE_CLASSLOADER_CHECK_CONFIG);
+        env.enableCheckpointing(400);
 
-          StreamTableEnvironment streamTableEnv =
-              StreamTableEnvironment.create(env, settingsBuilder.build());
-          streamTableEnv
-              .getConfig()
-              .getConfiguration()
-              .set(TableConfigOptions.TABLE_DYNAMIC_TABLE_OPTIONS_ENABLED, true);
-          tEnv = streamTableEnv;
-        }
+        StreamTableEnvironment streamTableEnv =
+            StreamTableEnvironment.create(env, settingsBuilder.build());
+        streamTableEnv
+            .getConfig()
+            .getConfiguration()
+            .set(TableConfigOptions.TABLE_DYNAMIC_TABLE_OPTIONS_ENABLED, true);
+        tEnv = streamTableEnv;
       }
     }
     return tEnv;
@@ -94,7 +98,7 @@ public class TestStreamScanSql extends CatalogTestBase {
   @AfterEach
   public void clean() {
     sql("DROP TABLE IF EXISTS %s.%s", flinkDatabase, TABLE);
-    sql("DROP DATABASE IF EXISTS %s", flinkDatabase);
+    dropDatabase(flinkDatabase, true);
     super.clean();
   }
 
@@ -418,7 +422,7 @@ public class TestStreamScanSql extends CatalogTestBase {
     }
     result.getJobClient().ifPresent(JobClient::cancel);
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 exec(
                     "SELECT * FROM %s /*+ OPTIONS('streaming'='true', 'monitor-interval'='1s', 'start-tag'='%s', "
