@@ -93,7 +93,7 @@ import org.junit.jupiter.params.provider.ValueSource;
  * Run all the tests from abstract of {@link CatalogTests} with few specific tests related to HIVE.
  */
 public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
-  private static ImmutableMap meta =
+  private static final ImmutableMap META =
       ImmutableMap.of(
           "owner", "apache",
           "group", "iceberg",
@@ -411,7 +411,7 @@ public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
   @Test
   public void testDatabaseAndNamespaceWithLocation() throws Exception {
     Namespace namespace1 = Namespace.of("noLocation");
-    catalog.createNamespace(namespace1, meta);
+    catalog.createNamespace(namespace1, META);
     Database database1 =
         HIVE_METASTORE_EXTENSION.metastoreClient().getDatabase(namespace1.toString());
 
@@ -430,7 +430,7 @@ public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
     hiveLocalDir = hiveLocalDir.substring(0, hiveLocalDir.length() - 1);
     ImmutableMap newMeta =
         ImmutableMap.<String, String>builder()
-            .putAll(meta)
+            .putAll(META)
             .put("location", hiveLocalDir)
             .buildOrThrow();
     Namespace namespace2 = Namespace.of("haveLocation");
@@ -527,12 +527,12 @@ public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
   public void testLoadNamespaceMeta() throws TException {
     Namespace namespace = Namespace.of("dbname_load");
 
-    catalog.createNamespace(namespace, meta);
+    catalog.createNamespace(namespace, META);
 
     Map<String, String> nameMata = catalog.loadNamespaceMetadata(namespace);
     assertThat(nameMata).containsEntry("owner", "apache");
     assertThat(nameMata).containsEntry("group", "iceberg");
-    assertThat(catalog.convertToDatabase(namespace, meta).getLocationUri())
+    assertThat(catalog.convertToDatabase(namespace, META).getLocationUri())
         .as("There no same location for db and namespace")
         .isEqualTo(nameMata.get("location"));
   }
@@ -541,7 +541,7 @@ public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
   public void testNamespaceExists() throws TException {
     Namespace namespace = Namespace.of("dbname_exists");
 
-    catalog.createNamespace(namespace, meta);
+    catalog.createNamespace(namespace, META);
 
     assertThat(catalog.namespaceExists(namespace)).as("Should true to namespace exist").isTrue();
     assertThat(catalog.namespaceExists(Namespace.of("db2", "db2", "ns2")))
@@ -861,7 +861,7 @@ public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
     TableIdentifier identifier = TableIdentifier.of(namespace, "table");
     Schema schema = getTestSchema();
 
-    catalog.createNamespace(namespace, meta);
+    catalog.createNamespace(namespace, META);
     catalog.createTable(identifier, schema);
     Map<String, String> nameMata = catalog.loadNamespaceMetadata(namespace);
     assertThat(nameMata).containsEntry("owner", "apache");
@@ -1041,7 +1041,7 @@ public class TestHiveCatalog extends CatalogTests<HiveCatalog> {
         .doesNotContainKey(CURRENT_SNAPSHOT_ID)
         .doesNotContainKey(CURRENT_SNAPSHOT_TIMESTAMP);
 
-    ops.setSchema(metadata, parameters);
+    ops.setSchema(metadata.schema(), parameters);
     assertThat(parameters).doesNotContainKey(CURRENT_SCHEMA);
 
     ops.setPartitionSpec(metadata, parameters);
