@@ -19,6 +19,7 @@
 package org.apache.iceberg.spark.extensions;
 
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.Arrays;
 import java.util.List;
@@ -35,18 +36,14 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.ExtendedParser;
 import org.apache.iceberg.spark.SparkCatalogConfig;
 import org.apache.iceberg.spark.SparkTableCache;
-import org.apache.iceberg.spark.SystemFunctionPushDownHelper;
 import org.apache.iceberg.spark.source.ThreeColumnRecord;
 import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchProcedureException;
-import org.apache.spark.sql.internal.SQLConf;
-import org.assertj.core.api.Assertions;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Assume;
-import org.junit.BeforeClass;
 import org.junit.Test;
 
 public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
@@ -58,12 +55,6 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     super(catalogName, implementation, config);
   }
 
-  @BeforeClass
-  public static void setupSpark() {
-    // disable AQE as tests assume that writes generate a particular number of files
-    spark.conf().set(SQLConf.ADAPTIVE_EXECUTION_ENABLED().key(), "false");
-  }
-
   @After
   public void removeTable() {
     sql("DROP TABLE IF EXISTS %s", tableName);
@@ -84,7 +75,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
   public void testRewriteDataFilesInEmptyTable() {
     createTable();
     List<Object[]> output = sql("CALL %s.system.rewrite_data_files('%s')", catalogName, tableIdent);
-    assertEquals("Procedure output must match", ImmutableList.of(row(0, 0, 0L, 0)), output);
+    assertEquals("Procedure output must match", ImmutableList.of(row(0, 0, 0L)), output);
   }
 
   @Test
@@ -102,7 +93,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 2),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -126,7 +117,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -150,7 +141,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
 
     assertEquals(
         "Action should rewrite 0 data files and add 0 data files",
-        ImmutableList.of(row(0, 0, 0L, 0)),
+        ImmutableList.of(row(0, 0, 0L)),
         output);
 
     List<Object[]> actualRecords = currentData();
@@ -176,7 +167,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -185,41 +176,6 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
   }
 
-  @Test
-  public void testRewriteDataFilesWithSortStrategyAndMultipleShufflePartitionsPerFile() {
-    createTable();
-    insertData(10 /* file count */);
-
-    List<Object[]> output =
-        sql(
-            "CALL %s.system.rewrite_data_files("
-                + " table => '%s', "
-                + " strategy => 'sort', "
-                + " sort_order => 'c1', "
-                + " options => map('shuffle-partitions-per-file', '2'))",
-            catalogName, tableIdent);
-
-    assertEquals(
-        "Action should rewrite 10 data files and add 1 data files",
-        row(10, 1),
-        Arrays.copyOf(output.get(0), 2));
-
-    // as there is only one small output file, validate the query ordering (it will not change)
-    ImmutableList<Object[]> expectedRows =
-        ImmutableList.of(
-            row(1, "foo", null),
-            row(1, "foo", null),
-            row(1, "foo", null),
-            row(1, "foo", null),
-            row(1, "foo", null),
-            row(2, "bar", null),
-            row(2, "bar", null),
-            row(2, "bar", null),
-            row(2, "bar", null),
-            row(2, "bar", null));
-    assertEquals("Should have expected rows", expectedRows, sql("SELECT * FROM %s", tableName));
-  }
-
   @Test
   public void testRewriteDataFilesWithZOrder() {
     createTable();
@@ -238,7 +194,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -262,28 +218,28 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
   }
 
   @Test
-  public void testRewriteDataFilesWithZOrderAndMultipleShufflePartitionsPerFile() {
-    createTable();
-    insertData(10 /* file count */);
+  public void testRewriteDataFilesWithZOrderNullBinaryColumn() {
+    sql("CREATE TABLE %s (c1 int, c2 string, c3 binary) USING iceberg", tableName);
+
+    for (int i = 0; i < 5; i++) {
+      sql("INSERT INTO %s values (1, 'foo', null), (2, 'bar', null)", tableName);
+    }
 
     List<Object[]> output =
         sql(
-            "CALL %s.system.rewrite_data_files("
-                + " table => '%s', "
-                + "strategy => 'sort', "
-                + " sort_order => 'zorder(c1, c2)', "
-                + " options => map('shuffle-partitions-per-file', '2'))",
+            "CALL %s.system.rewrite_data_files(table => '%s', "
+                + "strategy => 'sort', sort_order => 'zorder(c2,c3)')",
             catalogName, tableIdent);
 
     assertEquals(
         "Action should rewrite 10 data files and add 1 data files",
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
-
-    // due to z-ordering, the data will be written in the below order
-    // as there is only one small output file, validate the query ordering (it will not change)
-    ImmutableList<Object[]> expectedRows =
-        ImmutableList.of(
+    assertThat(output.get(0)).hasSize(3);
+    assertThat(snapshotSummary())
+        .containsEntry(SnapshotSummary.REMOVED_FILE_SIZE_PROP, String.valueOf(output.get(0)[2]));
+    assertThat(sql("SELECT * FROM %s", tableName))
+        .containsExactly(
             row(2, "bar", null),
             row(2, "bar", null),
             row(2, "bar", null),
@@ -294,7 +250,6 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
             row(1, "foo", null),
             row(1, "foo", null),
             row(1, "foo", null));
-    assertEquals("Should have expected rows", expectedRows, sql("SELECT * FROM %s", tableName));
   }
 
   @Test
@@ -316,7 +271,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(5, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -341,7 +296,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -387,39 +342,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(5, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
-    assertThat(output.get(0)[2])
-        .isInstanceOf(Long.class)
-        .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
-
-    List<Object[]> actualRecords = currentData();
-    assertEquals("Data after compaction should not change", expectedRecords, actualRecords);
-  }
-
-  @Test
-  public void testRewriteDataFilesWithFilterOnOnBucketExpression() {
-    // currently spark session catalog only resolve to v1 functions instead of desired v2 functions
-    // https://github.com/apache/spark/blob/branch-3.4/sql/catalyst/src/main/scala/org/apache/spark/sql/catalyst/analysis/Analyzer.scala#L2070-L2083
-    Assume.assumeFalse(catalogName.equals(SparkCatalogConfig.SPARK.catalogName()));
-    createBucketPartitionTable();
-    // create 5 files for each partition (c2 = 'foo' and c2 = 'bar')
-    insertData(10);
-    List<Object[]> expectedRecords = currentData();
-
-    // select only 5 files for compaction (files in the partition c2 = 'bar')
-    List<Object[]> output =
-        sql(
-            "CALL %s.system.rewrite_data_files(table => '%s',"
-                + " where => '%s.system.bucket(2, c2) = 0')",
-            catalogName, tableIdent, catalogName);
-
-    assertEquals(
-        "Action should rewrite 5 data files from single matching partition"
-            + "(containing bucket(c2) = 0) and add 1 data files",
-        row(5, 1),
-        row(output.get(0)[0], output.get(0)[1]));
-    // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -447,7 +370,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(5, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -513,6 +436,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     sql(
         "CALL %s.system.rewrite_data_files(table => '%s'," + " where => 'c2 like \"%s\"')",
         catalogName, tableIdent, "car%");
+
     // TODO: Enable when org.apache.iceberg.spark.SparkFilters have implementations for
     // StringEndsWith & StringContains
     // StringEndsWith
@@ -523,39 +447,6 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     //     " where => 'c2 like \"%s\"')", catalogName, tableIdent, "%car%");
   }
 
-  @Test
-  public void testRewriteDataFilesWithPossibleV2Filters() {
-    // currently spark session catalog only resolve to v1 functions instead of desired v2 functions
-    // https://github.com/apache/spark/blob/branch-3.4/sql/catalyst/src/main/scala/org/apache/spark/sql/catalyst/analysis/Analyzer.scala#L2070-L2083
-    Assume.assumeFalse(catalogName.equals(SparkCatalogConfig.SPARK.catalogName()));
-
-    SystemFunctionPushDownHelper.createPartitionedTable(spark, tableName, "id");
-    sql(
-        "CALL %s.system.rewrite_data_files(table => '%s',"
-            + " where => '%s.system.bucket(2, data) >= 0')",
-        catalogName, tableIdent, catalogName);
-    sql(
-        "CALL %s.system.rewrite_data_files(table => '%s',"
-            + " where => '%s.system.truncate(4, id) >= 1')",
-        catalogName, tableIdent, catalogName);
-    sql(
-        "CALL %s.system.rewrite_data_files(table => '%s',"
-            + " where => '%s.system.years(ts) >= 1')",
-        catalogName, tableIdent, catalogName);
-    sql(
-        "CALL %s.system.rewrite_data_files(table => '%s',"
-            + " where => '%s.system.months(ts) >= 1')",
-        catalogName, tableIdent, catalogName);
-    sql(
-        "CALL %s.system.rewrite_data_files(table => '%s',"
-            + " where => '%s.system.days(ts) >= date(\"2023-01-01\")')",
-        catalogName, tableIdent, catalogName);
-    sql(
-        "CALL %s.system.rewrite_data_files(table => '%s',"
-            + " where => '%s.system.hours(ts) >= 1')",
-        catalogName, tableIdent, catalogName);
-  }
-
   @Test
   public void testRewriteDataFilesWithInvalidInputs() {
     createTable();
@@ -563,121 +454,136 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
     insertData(2);
 
     // Test for invalid strategy
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', options => map('min-input-files','2'), "
                         + "strategy => 'temp')",
                     catalogName, tableIdent))
+        .as("Should reject calls with unsupported strategy error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("unsupported strategy: temp. Only binpack or sort is supported");
+        .hasMessageContaining("unsupported strategy: temp. Only binpack or sort is supported");
 
     // Test for sort_order with binpack strategy
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'binpack', "
                         + "sort_order => 'c1 ASC NULLS FIRST')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Must use only one rewriter type (bin-pack, sort, zorder)");
+        .hasMessageContaining("Must use only one rewriter type (bin-pack, sort, zorder)");
 
     // Test for sort strategy without any (default/user defined) sort_order
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageStartingWith("Cannot sort data without a valid sort order");
+        .hasMessageContaining("Cannot sort data without a valid sort order");
 
     // Test for sort_order with invalid null order
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'c1 ASC none')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Unable to parse sortOrder: c1 ASC none");
+        .hasMessageContaining("Unable to parse sortOrder:");
 
     // Test for sort_order with invalid sort direction
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'c1 none NULLS FIRST')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Unable to parse sortOrder: c1 none NULLS FIRST");
+        .hasMessageContaining("Unable to parse sortOrder:");
 
     // Test for sort_order with invalid column name
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'col1 DESC NULLS FIRST')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(ValidationException.class)
-        .hasMessageStartingWith("Cannot find field 'col1' in struct:");
+        .hasMessageContaining(
+            "Cannot find field 'col1' in struct:"
+                + " struct<1: c1: optional int, 2: c2: optional string, 3: c3: optional string>");
 
     // Test with invalid filter column col1
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', " + "where => 'col1 = 3')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Cannot parse predicates in where option: col1 = 3");
+        .hasMessageContaining("Cannot parse predicates in where option: col1 = 3");
 
     // Test for z_order with invalid column name
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'zorder(col1)')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage(
+        .hasMessageContaining(
             "Cannot find column 'col1' in table schema (case sensitive = false): "
                 + "struct<1: c1: optional int, 2: c2: optional string, 3: c3: optional string>");
 
     // Test for z_order with sort_order
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rewrite_data_files(table => '%s', strategy => 'sort', "
                         + "sort_order => 'c1,zorder(c2,c3)')",
                     catalogName, tableIdent))
+        .as("Should reject calls with error message")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage(
+        .hasMessageContaining(
             "Cannot mix identity sort columns and a Zorder sort expression:" + " c1,zorder(c2,c3)");
   }
 
   @Test
   public void testInvalidCasesForRewriteDataFiles() {
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> sql("CALL %s.system.rewrite_data_files('n', table => 't')", catalogName))
+        .as("Should not allow mixed args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessage("Named and positional arguments cannot be mixed");
+        .hasMessageContaining("Named and positional arguments cannot be mixed");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.custom.rewrite_data_files('n', 't')", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.custom.rewrite_data_files('n', 't')", catalogName))
+        .as("Should not resolve procedures in arbitrary namespaces")
         .isInstanceOf(NoSuchProcedureException.class)
-        .hasMessage("Procedure custom.rewrite_data_files not found");
+        .hasMessageContaining("not found");
 
-    Assertions.assertThatThrownBy(() -> sql("CALL %s.system.rewrite_data_files()", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.rewrite_data_files()", catalogName))
+        .as("Should reject calls without all required args")
         .isInstanceOf(AnalysisException.class)
-        .hasMessage("Missing required parameters: [table]");
+        .hasMessageContaining("Missing required parameters");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> sql("CALL %s.system.rewrite_data_files(table => 't', table => 't')", catalogName))
+        .as("Should reject duplicate arg names name")
         .isInstanceOf(AnalysisException.class)
-        .hasMessageEndingWith("Duplicate procedure argument: table");
+        .hasMessageContaining("Duplicate procedure argument: table");
 
-    Assertions.assertThatThrownBy(() -> sql("CALL %s.system.rewrite_data_files('')", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.rewrite_data_files('')", catalogName))
+        .as("Should reject calls with empty table identifier")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Cannot handle an empty identifier for parameter 'table'");
+        .hasMessageContaining("Cannot handle an empty identifier");
   }
 
   @Test
@@ -704,7 +610,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isEqualTo(
             Long.valueOf(snapshotSummary(identifier).get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -743,7 +649,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(
@@ -783,7 +689,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(10, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(
@@ -819,7 +725,7 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         row(2, 1),
         Arrays.copyOf(output.get(0), 2));
     // verify rewritten bytes separately
-    assertThat(output.get(0)).hasSize(4);
+    assertThat(output.get(0)).hasSize(3);
     assertThat(output.get(0)[2])
         .isInstanceOf(Long.class)
         .isEqualTo(Long.valueOf(snapshotSummary().get(SnapshotSummary.REMOVED_FILE_SIZE_PROP)));
@@ -831,18 +737,18 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
   @Test
   public void testRewriteWithUntranslatedOrUnconvertedFilter() {
     createTable();
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
-                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'substr(encode(c2, \"utf-8\"), 2) = \"fo\"')",
+                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'lower(c2) = \"fo\"')",
                     catalogName, tableIdent))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageContaining("Cannot translate Spark expression");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
-                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'substr(c2, 2) = \"fo\"')",
+                    "CALL %s.system.rewrite_data_files(table => '%s', where => 'c2 like \"%%fo\"')",
                     catalogName, tableIdent))
         .isInstanceOf(IllegalArgumentException.class)
         .hasMessageContaining("Cannot convert Spark filter");
@@ -863,17 +769,6 @@ public class TestRewriteDataFilesProcedure extends SparkExtensionsTestBase {
         TableProperties.WRITE_DISTRIBUTION_MODE_NONE);
   }
 
-  private void createBucketPartitionTable() {
-    sql(
-        "CREATE TABLE %s (c1 int, c2 string, c3 string) "
-            + "USING iceberg "
-            + "PARTITIONED BY (bucket(2, c2)) "
-            + "TBLPROPERTIES ('%s' '%s')",
-        tableName,
-        TableProperties.WRITE_DISTRIBUTION_MODE,
-        TableProperties.WRITE_DISTRIBUTION_MODE_NONE);
-  }
-
   private void insertData(int filesCount) {
     insertData(tableName, filesCount);
   }
