@@ -22,6 +22,8 @@ import static org.apache.iceberg.ManifestContent.DATA;
 import static org.apache.iceberg.ManifestContent.DELETES;
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.io.File;
 import java.io.IOException;
@@ -91,7 +93,6 @@ import org.apache.spark.sql.catalyst.InternalRow;
 import org.apache.spark.sql.functions;
 import org.apache.spark.sql.internal.SQLConf;
 import org.apache.spark.sql.types.StructType;
-import org.assertj.core.api.Assertions;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Rule;
@@ -212,7 +213,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testEntriesTablePartitionedPrune() {
+  public void testEntriesTablePartitionedPrune() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, SPEC);
 
@@ -241,7 +242,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testEntriesTableDataFilePrune() {
+  public void testEntriesTableDataFilePrune() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, PartitionSpec.unpartitioned());
 
@@ -274,7 +275,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testEntriesTableDataFilePruneMulti() {
+  public void testEntriesTableDataFilePruneMulti() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, PartitionSpec.unpartitioned());
 
@@ -312,7 +313,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testFilesSelectMap() {
+  public void testFilesSelectMap() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, PartitionSpec.unpartitioned());
 
@@ -657,7 +658,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testAllMetadataTablesWithStagedCommits() {
+  public void testAllMetadataTablesWithStagedCommits() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "stage_aggregate_table_test");
     Table table = createTable(tableIdentifier, SCHEMA, SPEC);
 
@@ -704,7 +705,8 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
 
     Assert.assertTrue(
         "Stage table should have some snapshots", table.snapshots().iterator().hasNext());
-    Assert.assertNull("Stage table should have null currentSnapshot", table.currentSnapshot());
+    Assert.assertEquals(
+        "Stage table should have null currentSnapshot", null, table.currentSnapshot());
     Assert.assertEquals("Actual results should have two rows", 2, actualAllData.size());
     Assert.assertEquals("Actual results should have two rows", 2, actualAllManifests.size());
     Assert.assertEquals("Actual results should have two rows", 2, actualAllEntries.size());
@@ -1117,7 +1119,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
 
     if (!spark.version().startsWith("2")) {
       // Spark 2 isn't able to actually push down nested struct projections so this will not break
-      Assertions.assertThatThrownBy(
+      assertThatThrownBy(
               () ->
                   spark
                       .read()
@@ -1125,6 +1127,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
                       .load(loadLocation(tableIdentifier, "manifests"))
                       .select("partition_spec_id", "path", "partition_summaries.contains_null")
                       .collectAsList())
+          .as("Can't prune struct inside list")
           .isInstanceOf(SparkException.class)
           .hasMessageContaining("Cannot project a partial list element struct");
     }
@@ -1224,8 +1227,8 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
                 snapshotManifest ->
                     manifestRecord(
                         manifestTable, snapshotManifest.first(), snapshotManifest.second()))
-            .sorted(Comparator.comparing(o -> o.get("path").toString()))
             .collect(Collectors.toList());
+    expected.sort(Comparator.comparing(o -> o.get("path").toString()));
 
     Assert.assertEquals("Manifests table should have 5 manifest rows", 5, actual.size());
     for (int i = 0; i < expected.size(); i += 1) {
@@ -1496,16 +1499,15 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
             .orderBy("partition.id")
             .collectAsList();
 
+    List<DataFile> dataFiles = TestHelpers.dataFiles(table);
+    assertDataFilePartitions(dataFiles, Arrays.asList(1, 2, 2));
+
     GenericRecordBuilder builder =
         new GenericRecordBuilder(AvroSchemaUtil.convert(partitionsTable.schema(), "partitions"));
     GenericRecordBuilder partitionBuilder =
         new GenericRecordBuilder(
             AvroSchemaUtil.convert(
                 partitionsTable.schema().findType("partition").asStructType(), "partition"));
-
-    List<DataFile> dataFiles = TestHelpers.dataFiles(table);
-    assertDataFilePartitions(dataFiles, Arrays.asList(1, 2, 2));
-
     List<GenericData.Record> expected = Lists.newArrayList();
     expected.add(
         builder
@@ -1988,7 +1990,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testFilesTablePartitionId() {
+  public void testFilesTablePartitionId() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "files_test");
     Table table =
         createTable(
@@ -2028,7 +2030,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testAllManifestTableSnapshotFiltering() {
+  public void testAllManifestTableSnapshotFiltering() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "all_manifest_snapshot_filtering");
     Table table = createTable(tableIdentifier, SCHEMA, SPEC);
     Table manifestTable = loadTable(tableIdentifier, "all_manifests");
@@ -2097,8 +2099,8 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
                 snapshotManifest ->
                     manifestRecord(
                         manifestTable, snapshotManifest.first(), snapshotManifest.second()))
-            .sorted(Comparator.comparing(o -> o.get("path").toString()))
             .collect(Collectors.toList());
+    expected.sort(Comparator.comparing(o -> o.get("path").toString()));
 
     Assert.assertEquals("Manifests table should have 3 manifest rows", 3, actual.size());
     for (int i = 0; i < expected.size(); i += 1) {
@@ -2175,9 +2177,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
             .select("tmp_col")
             .filter(filterExpr)
             .collectAsList();
-    Assertions.assertThat(actual)
-        .as("Rows must match")
-        .containsExactlyInAnyOrderElementsOf(expected);
+    assertThat(actual).as("Rows must match").containsExactlyInAnyOrderElementsOf(expected);
   }
 
   private GenericData.Record manifestRecord(
