@@ -18,13 +18,13 @@
  */
 package org.apache.iceberg.spark.extensions;
 
-import static org.assertj.core.api.Assertions.assertThat;
-import static scala.collection.JavaConverters.seqAsJavaList;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.math.BigDecimal;
 import java.sql.Timestamp;
 import java.time.Instant;
 import java.util.List;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.catalyst.expressions.Expression;
@@ -39,17 +39,22 @@ import org.apache.spark.sql.catalyst.plans.logical.NamedArgument;
 import org.apache.spark.sql.catalyst.plans.logical.PositionalArgument;
 import org.apache.spark.sql.types.DataType;
 import org.apache.spark.sql.types.DataTypes;
-import org.assertj.core.api.Assertions;
-import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.BeforeAll;
-import org.junit.jupiter.api.Test;
+import org.junit.AfterClass;
+import org.junit.Assert;
+import org.junit.BeforeClass;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+import scala.collection.JavaConverters;
 
 public class TestCallStatementParser {
 
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
+
   private static SparkSession spark = null;
   private static ParserInterface parser = null;
 
-  @BeforeAll
+  @BeforeClass
   public static void startSpark() {
     TestCallStatementParser.spark =
         SparkSession.builder()
@@ -60,7 +65,7 @@ public class TestCallStatementParser {
     TestCallStatementParser.parser = spark.sessionState().sqlParser();
   }
 
-  @AfterAll
+  @AfterClass
   public static void stopSpark() {
     SparkSession currentSpark = TestCallStatementParser.spark;
     TestCallStatementParser.spark = null;
@@ -72,9 +77,10 @@ public class TestCallStatementParser {
   public void testCallWithPositionalArgs() throws ParseException {
     CallStatement call =
         (CallStatement) parser.parsePlan("CALL c.n.func(1, '2', 3L, true, 1.0D, 9.0e1, 900e-1BD)");
-    assertThat(seqAsJavaList(call.name())).containsExactly("c", "n", "func");
+    Assert.assertEquals(
+        ImmutableList.of("c", "n", "func"), JavaConverters.seqAsJavaList(call.name()));
 
-    assertThat(seqAsJavaList(call.args())).hasSize(7);
+    Assert.assertEquals(7, call.args().size());
 
     checkArg(call, 0, 1, DataTypes.IntegerType);
     checkArg(call, 1, "2", DataTypes.StringType);
@@ -89,9 +95,10 @@ public class TestCallStatementParser {
   public void testCallWithNamedArgs() throws ParseException {
     CallStatement call =
         (CallStatement) parser.parsePlan("CALL cat.system.func(c1 => 1, c2 => '2', c3 => true)");
-    assertThat(seqAsJavaList(call.name())).containsExactly("cat", "system", "func");
+    Assert.assertEquals(
+        ImmutableList.of("cat", "system", "func"), JavaConverters.seqAsJavaList(call.name()));
 
-    assertThat(seqAsJavaList(call.args())).hasSize(3);
+    Assert.assertEquals(3, call.args().size());
 
     checkArg(call, 0, "c1", 1, DataTypes.IntegerType);
     checkArg(call, 1, "c2", "2", DataTypes.StringType);
@@ -101,9 +108,10 @@ public class TestCallStatementParser {
   @Test
   public void testCallWithMixedArgs() throws ParseException {
     CallStatement call = (CallStatement) parser.parsePlan("CALL cat.system.func(c1 => 1, '2')");
-    assertThat(seqAsJavaList(call.name())).containsExactly("cat", "system", "func");
+    Assert.assertEquals(
+        ImmutableList.of("cat", "system", "func"), JavaConverters.seqAsJavaList(call.name()));
 
-    assertThat(seqAsJavaList(call.args())).hasSize(2);
+    Assert.assertEquals(2, call.args().size());
 
     checkArg(call, 0, "c1", 1, DataTypes.IntegerType);
     checkArg(call, 1, "2", DataTypes.StringType);
@@ -114,9 +122,10 @@ public class TestCallStatementParser {
     CallStatement call =
         (CallStatement)
             parser.parsePlan("CALL cat.system.func(TIMESTAMP '2017-02-03T10:37:30.00Z')");
-    assertThat(seqAsJavaList(call.name())).containsExactly("cat", "system", "func");
+    Assert.assertEquals(
+        ImmutableList.of("cat", "system", "func"), JavaConverters.seqAsJavaList(call.name()));
 
-    assertThat(seqAsJavaList(call.args())).hasSize(1);
+    Assert.assertEquals(1, call.args().size());
 
     checkArg(
         call, 0, Timestamp.from(Instant.parse("2017-02-03T10:37:30.00Z")), DataTypes.TimestampType);
@@ -126,16 +135,17 @@ public class TestCallStatementParser {
   public void testCallWithVarSubstitution() throws ParseException {
     CallStatement call =
         (CallStatement) parser.parsePlan("CALL cat.system.func('${spark.extra.prop}')");
-    assertThat(seqAsJavaList(call.name())).containsExactly("cat", "system", "func");
+    Assert.assertEquals(
+        ImmutableList.of("cat", "system", "func"), JavaConverters.seqAsJavaList(call.name()));
 
-    assertThat(seqAsJavaList(call.args())).hasSize(1);
+    Assert.assertEquals(1, call.args().size());
 
     checkArg(call, 0, "value", DataTypes.StringType);
   }
 
   @Test
   public void testCallParseError() {
-    Assertions.assertThatThrownBy(() -> parser.parsePlan("CALL cat.system radish kebab"))
+    assertThatThrownBy(() -> parser.parsePlan("CALL cat.system radish kebab"))
         .isInstanceOf(IcebergParseException.class)
         .hasMessageContaining("missing '(' at 'radish'");
   }
@@ -156,9 +166,10 @@ public class TestCallStatementParser {
             "CALL -- a line ending comment\n" + "cat.system.func('${spark.extra.prop}')");
     for (String sqlText : callStatementsWithComments) {
       CallStatement call = (CallStatement) parser.parsePlan(sqlText);
-      assertThat(seqAsJavaList(call.name())).containsExactly("cat", "system", "func");
+      Assert.assertEquals(
+          ImmutableList.of("cat", "system", "func"), JavaConverters.seqAsJavaList(call.name()));
 
-      assertThat(seqAsJavaList(call.args())).hasSize(1);
+      Assert.assertEquals(1, call.args().size());
 
       checkArg(call, 0, "value", DataTypes.StringType);
     }
@@ -178,7 +189,7 @@ public class TestCallStatementParser {
 
     if (expectedName != null) {
       NamedArgument arg = checkCast(call.args().apply(index), NamedArgument.class);
-      assertThat(arg.name()).isEqualTo(expectedName);
+      Assert.assertEquals(expectedName, arg.name());
     } else {
       CallArgument arg = call.args().apply(index);
       checkCast(arg, PositionalArgument.class);
@@ -186,8 +197,8 @@ public class TestCallStatementParser {
 
     Expression expectedExpr = toSparkLiteral(expectedValue, expectedType);
     Expression actualExpr = call.args().apply(index).expr();
-    assertThat(actualExpr.dataType()).as("Arg types must match").isEqualTo(expectedExpr.dataType());
-    assertThat(actualExpr).as("Arg must match").isEqualTo(expectedExpr);
+    Assert.assertEquals("Arg types must match", expectedExpr.dataType(), actualExpr.dataType());
+    Assert.assertEquals("Arg must match", expectedExpr, actualExpr);
   }
 
   private Literal toSparkLiteral(Object value, DataType dataType) {
@@ -195,7 +206,8 @@ public class TestCallStatementParser {
   }
 
   private <T> T checkCast(Object value, Class<T> expectedClass) {
-    assertThat(value).isInstanceOf(expectedClass);
+    Assert.assertTrue(
+        "Expected instance of " + expectedClass.getName(), expectedClass.isInstance(value));
     return expectedClass.cast(value);
   }
 }
