@@ -18,10 +18,11 @@
  */
 package org.apache.iceberg.spark.extensions;
 
-import static org.assertj.core.api.Assumptions.assumeThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.time.LocalDateTime;
 import java.util.List;
+import java.util.Map;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
@@ -29,18 +30,23 @@ import org.apache.spark.sql.AnalysisException;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchProcedureException;
-import org.assertj.core.api.Assertions;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.TestTemplate;
+import org.junit.After;
+import org.junit.Assume;
+import org.junit.Test;
 
-public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
+public class TestRollbackToTimestampProcedure extends SparkExtensionsTestBase {
 
-  @AfterEach
+  public TestRollbackToTimestampProcedure(
+      String catalogName, String implementation, Map<String, String> config) {
+    super(catalogName, implementation, config);
+  }
+
+  @After
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testRollbackToTimestampUsingPositionalArgs() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -78,7 +84,7 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testRollbackToTimestampUsingNamedArgs() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -116,7 +122,7 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testRollbackToTimestampRefreshesRelationCache() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -159,7 +165,7 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
     sql("UNCACHE TABLE tmp");
   }
 
-  @TestTemplate
+  @Test
   public void testRollbackToTimestampWithQuotedIdentifiers() {
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -205,9 +211,9 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testRollbackToTimestampWithoutExplicitCatalog() {
-    assumeThat(catalogName).as("Working only with the session catalog").isEqualTo("spark_catalog");
+    Assume.assumeTrue("Working only with the session catalog", "spark_catalog".equals(catalogName));
 
     sql("CREATE TABLE %s (id bigint NOT NULL, data string) USING iceberg", tableName);
     sql("INSERT INTO TABLE %s VALUES (1, 'a')", tableName);
@@ -246,11 +252,11 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         sql("SELECT * FROM %s ORDER BY id", tableName));
   }
 
-  @TestTemplate
+  @Test
   public void testInvalidRollbackToTimestampCases() {
     String timestamp = "TIMESTAMP '2007-12-03T10:15:30'";
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rollback_to_timestamp(namespace => 'n1', 't', %s)",
@@ -258,17 +264,16 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         .isInstanceOf(AnalysisException.class)
         .hasMessage("Named and positional arguments cannot be mixed");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () -> sql("CALL %s.custom.rollback_to_timestamp('n', 't', %s)", catalogName, timestamp))
         .isInstanceOf(NoSuchProcedureException.class)
         .hasMessage("Procedure custom.rollback_to_timestamp not found");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.rollback_to_timestamp('t')", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.rollback_to_timestamp('t')", catalogName))
         .isInstanceOf(AnalysisException.class)
         .hasMessage("Missing required parameters: [timestamp]");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rollback_to_timestamp(timestamp => %s)",
@@ -276,12 +281,11 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         .isInstanceOf(AnalysisException.class)
         .hasMessage("Missing required parameters: [table]");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.rollback_to_timestamp(table => 't')", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.rollback_to_timestamp(table => 't')", catalogName))
         .isInstanceOf(AnalysisException.class)
         .hasMessage("Missing required parameters: [timestamp]");
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "CALL %s.system.rollback_to_timestamp('n', 't', %s, 1L)",
@@ -289,8 +293,7 @@ public class TestRollbackToTimestampProcedure extends ExtensionsTestBase {
         .isInstanceOf(AnalysisException.class)
         .hasMessage("Too many arguments for procedure");
 
-    Assertions.assertThatThrownBy(
-            () -> sql("CALL %s.system.rollback_to_timestamp('t', 2.2)", catalogName))
+    assertThatThrownBy(() -> sql("CALL %s.system.rollback_to_timestamp('t', 2.2)", catalogName))
         .isInstanceOf(AnalysisException.class)
         .hasMessage("Wrong arg type for timestamp: cannot cast DecimalType(2,1) to TimestampType");
   }
