@@ -23,12 +23,11 @@ import static org.assertj.core.api.Assertions.assertThatNoException;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
 import java.util.List;
+import java.util.Map;
 import java.util.Random;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import org.apache.iceberg.IcebergBuild;
-import org.apache.iceberg.ParameterizedTestExtension;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.catalog.Namespace;
@@ -52,32 +51,30 @@ import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.sql.catalyst.catalog.SessionCatalog;
 import org.assertj.core.api.InstanceOfAssertFactories;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runners.Parameterized;
 
-@ExtendWith(ParameterizedTestExtension.class)
-public class TestViews extends ExtensionsTestBase {
+public class TestViews extends SparkExtensionsTestBase {
   private static final Namespace NAMESPACE = Namespace.of("default");
   private final String tableName = "table";
 
-  @BeforeEach
+  @Before
   public void before() {
-    super.before();
     spark.conf().set("spark.sql.defaultCatalog", catalogName);
     sql("USE %s", catalogName);
     sql("CREATE NAMESPACE IF NOT EXISTS %s", NAMESPACE);
     sql("CREATE TABLE %s (id INT, data STRING)", tableName);
   }
 
-  @AfterEach
+  @After
   public void removeTable() {
     sql("USE %s", catalogName);
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
+  @Parameterized.Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}")
   public static Object[][] parameters() {
     return new Object[][] {
       {
@@ -88,7 +85,11 @@ public class TestViews extends ExtensionsTestBase {
     };
   }
 
-  @TestTemplate
+  public TestViews(String catalog, String implementation, Map<String, String> properties) {
+    super(catalog, implementation, properties);
+  }
+
+  @Test
   public void readFromView() throws NoSuchTableException {
     insertRows(10);
     String viewName = "simpleView";
@@ -114,7 +115,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrderElementsOf(expected);
   }
 
-  @TestTemplate
+  @Test
   public void readFromTrinoView() throws NoSuchTableException {
     insertRows(10);
     String viewName = "trinoView";
@@ -139,7 +140,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrderElementsOf(expected);
   }
 
-  @TestTemplate
+  @Test
   public void readFromMultipleViews() throws NoSuchTableException {
     insertRows(6);
     String viewName = "firstView";
@@ -172,7 +173,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrder(row(4), row(5), row(6));
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewUsingNonExistingTable() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewWithNonExistingTable";
@@ -196,7 +197,7 @@ public class TestViews extends ExtensionsTestBase {
                 catalogName, NAMESPACE));
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewUsingNonExistingTableColumn() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewWithNonExistingColumn";
@@ -218,7 +219,7 @@ public class TestViews extends ExtensionsTestBase {
             "A column or function parameter with name `non_existing` cannot be resolved");
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewUsingInvalidSQL() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewWithInvalidSQL";
@@ -237,10 +238,10 @@ public class TestViews extends ExtensionsTestBase {
     assertThatThrownBy(() -> sql("SELECT * FROM %s", viewName))
         .isInstanceOf(AnalysisException.class)
         .hasMessageContaining(
-            String.format("The view `%s` cannot be displayed due to invalid view text", viewName));
+            String.format("Invalid view text: invalid SQL. The view %s", viewName));
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewWithStaleSchema() throws NoSuchTableException {
     insertRows(10);
     String viewName = "staleView";
@@ -266,7 +267,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("A column or function parameter with name `data` cannot be resolved");
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewHiddenByTempView() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewHiddenByTempView";
@@ -293,7 +294,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrderElementsOf(expected);
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewWithGlobalTempView() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewWithGlobalTempView";
@@ -323,7 +324,7 @@ public class TestViews extends ExtensionsTestBase {
             IntStream.rangeClosed(6, 10).mapToObj(this::row).collect(Collectors.toList()));
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewReferencingAnotherView() throws NoSuchTableException {
     insertRows(10);
     String firstView = "viewBeingReferencedInAnotherView";
@@ -354,7 +355,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row(5));
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewReferencingTempView() throws NoSuchTableException {
     insertRows(10);
     String tempView = "tempViewBeingReferencedInAnotherView";
@@ -390,7 +391,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("cannot be found");
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewReferencingAnotherViewHiddenByTempView() throws NoSuchTableException {
     insertRows(10);
     String innerViewName = "inner_view";
@@ -438,7 +439,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrderElementsOf(expectedViewRows);
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewReferencingGlobalTempView() throws NoSuchTableException {
     insertRows(10);
     String globalTempView = "globalTempViewBeingReferenced";
@@ -476,7 +477,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("cannot be found");
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewReferencingTempFunction() throws NoSuchTableException {
     insertRows(10);
     String viewName = viewName("viewReferencingTempFunction");
@@ -508,7 +509,7 @@ public class TestViews extends ExtensionsTestBase {
             String.format("Cannot load function: %s.%s.%s", catalogName, NAMESPACE, functionName));
   }
 
-  @TestTemplate
+  @Test
   public void readFromViewWithCTE() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewWithCTE";
@@ -531,7 +532,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SELECT * FROM %s", viewName)).hasSize(1).containsExactly(row(10, 1L));
   }
 
-  @TestTemplate
+  @Test
   public void rewriteFunctionIdentifier() {
     String viewName = "rewriteFunctionIdentifier";
     String sql = "SELECT iceberg_version() AS version";
@@ -557,7 +558,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row(IcebergBuild.version()));
   }
 
-  @TestTemplate
+  @Test
   public void builtinFunctionIdentifierNotRewritten() {
     String viewName = "builtinFunctionIdentifierNotRewritten";
     String sql = "SELECT trim('  abc   ') AS result";
@@ -576,7 +577,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SELECT * FROM %s", viewName)).hasSize(1).containsExactly(row("abc"));
   }
 
-  @TestTemplate
+  @Test
   public void rewriteFunctionIdentifierWithNamespace() {
     String viewName = "rewriteFunctionIdentifierWithNamespace";
     String sql = "SELECT system.bucket(100, 'a') AS bucket_result, 'a' AS value";
@@ -603,7 +604,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row(50, "a"));
   }
 
-  @TestTemplate
+  @Test
   public void fullFunctionIdentifier() {
     String viewName = "fullFunctionIdentifier";
     String sql =
@@ -627,7 +628,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row(50, "a"));
   }
 
-  @TestTemplate
+  @Test
   public void fullFunctionIdentifierNotRewrittenLoadFailure() {
     String viewName = "fullFunctionIdentifierNotRewrittenLoadFailure";
     String sql = "SELECT spark_catalog.system.bucket(100, 'a') AS bucket_result, 'a' AS value";
@@ -672,7 +673,7 @@ public class TestViews extends ExtensionsTestBase {
     return Spark3Util.loadIcebergCatalog(spark, catalogName);
   }
 
-  @TestTemplate
+  @Test
   public void renameView() throws NoSuchTableException {
     insertRows(10);
     String viewName = viewName("originalView");
@@ -698,7 +699,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrderElementsOf(expected);
   }
 
-  @TestTemplate
+  @Test
   public void renameViewHiddenByTempView() throws NoSuchTableException {
     insertRows(10);
     String viewName = viewName("originalView");
@@ -737,7 +738,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(viewCatalog.viewExists(TableIdentifier.of(NAMESPACE, renamedView))).isTrue();
   }
 
-  @TestTemplate
+  @Test
   public void renameViewToDifferentTargetCatalog() {
     String viewName = viewName("originalView");
     String renamedView = viewName("renamedView");
@@ -759,14 +760,14 @@ public class TestViews extends ExtensionsTestBase {
             "Cannot move view between catalogs: from=spark_with_views and to=spark_catalog");
   }
 
-  @TestTemplate
+  @Test
   public void renameNonExistingView() {
     assertThatThrownBy(() -> sql("ALTER VIEW non_existing RENAME TO target"))
         .isInstanceOf(AnalysisException.class)
         .hasMessageContaining("The table or view `non_existing` cannot be found");
   }
 
-  @TestTemplate
+  @Test
   public void renameViewTargetAlreadyExistsAsView() {
     String viewName = viewName("renameViewSource");
     String target = viewName("renameViewTarget");
@@ -796,7 +797,7 @@ public class TestViews extends ExtensionsTestBase {
             String.format("Cannot create view default.%s because it already exists", target));
   }
 
-  @TestTemplate
+  @Test
   public void renameViewTargetAlreadyExistsAsTable() {
     String viewName = viewName("renameViewSource");
     String target = viewName("renameViewTarget");
@@ -819,7 +820,7 @@ public class TestViews extends ExtensionsTestBase {
             String.format("Cannot create view default.%s because it already exists", target));
   }
 
-  @TestTemplate
+  @Test
   public void dropView() {
     String viewName = "viewToBeDropped";
     String sql = String.format("SELECT id FROM %s", tableName);
@@ -841,14 +842,14 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(viewCatalog.viewExists(identifier)).isFalse();
   }
 
-  @TestTemplate
+  @Test
   public void dropNonExistingView() {
     assertThatThrownBy(() -> sql("DROP VIEW non_existing"))
         .isInstanceOf(AnalysisException.class)
         .hasMessageContaining("The view %s.%s cannot be found", NAMESPACE, "non_existing");
   }
 
-  @TestTemplate
+  @Test
   public void dropViewIfExists() {
     String viewName = "viewToBeDropped";
     String sql = String.format("SELECT id FROM %s", tableName);
@@ -873,7 +874,7 @@ public class TestViews extends ExtensionsTestBase {
   }
 
   /** The purpose of this test is mainly to make sure that normal view deletion isn't messed up */
-  @TestTemplate
+  @Test
   public void dropGlobalTempView() {
     String globalTempView = "globalViewToBeDropped";
     sql("CREATE GLOBAL TEMPORARY VIEW %s AS SELECT id FROM %s", globalTempView, tableName);
@@ -884,7 +885,7 @@ public class TestViews extends ExtensionsTestBase {
   }
 
   /** The purpose of this test is mainly to make sure that normal view deletion isn't messed up */
-  @TestTemplate
+  @Test
   public void dropTempView() {
     String tempView = "tempViewToBeDropped";
     sql("CREATE TEMPORARY VIEW %s AS SELECT id FROM %s", tempView, tableName);
@@ -895,7 +896,7 @@ public class TestViews extends ExtensionsTestBase {
   }
 
   /** The purpose of this test is mainly to make sure that normal view deletion isn't messed up */
-  @TestTemplate
+  @Test
   public void dropV1View() {
     String v1View = "v1ViewToBeDropped";
     sql("USE spark_catalog");
@@ -926,7 +927,7 @@ public class TestViews extends ExtensionsTestBase {
     return viewName + new Random().nextInt(1000000);
   }
 
-  @TestTemplate
+  @Test
   public void createViewIfNotExists() {
     String viewName = "viewThatAlreadyExists";
     sql("CREATE VIEW %s AS SELECT id FROM %s", viewName, tableName);
@@ -943,7 +944,7 @@ public class TestViews extends ExtensionsTestBase {
             () -> sql("CREATE VIEW IF NOT EXISTS %s AS SELECT id FROM %s", viewName, tableName));
   }
 
-  @TestTemplate
+  @Test
   public void createOrReplaceView() throws NoSuchTableException {
     insertRows(6);
     String viewName = viewName("simpleView");
@@ -959,14 +960,14 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrder(row(4), row(5), row(6));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithInvalidSQL() {
     assertThatThrownBy(() -> sql("CREATE VIEW simpleViewWithInvalidSQL AS invalid SQL"))
         .isInstanceOf(AnalysisException.class)
         .hasMessageContaining("Syntax error");
   }
 
-  @TestTemplate
+  @Test
   public void createViewReferencingTempView() throws NoSuchTableException {
     insertRows(10);
     String tempView = "temporaryViewBeingReferencedInAnotherView";
@@ -985,7 +986,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(tempView);
   }
 
-  @TestTemplate
+  @Test
   public void createViewReferencingGlobalTempView() throws NoSuchTableException {
     insertRows(10);
     String globalTempView = "globalTemporaryViewBeingReferenced";
@@ -1009,7 +1010,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(String.format("%s.%s", "global_temp", globalTempView));
   }
 
-  @TestTemplate
+  @Test
   public void createViewReferencingTempFunction() {
     String viewName = viewName("viewReferencingTemporaryFunction");
     String functionName = "test_avg_func";
@@ -1028,7 +1029,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(functionName);
   }
 
-  @TestTemplate
+  @Test
   public void createViewReferencingQualifiedTempFunction() {
     String viewName = viewName("viewReferencingTemporaryFunction");
     String functionName = "test_avg_func_qualified";
@@ -1059,7 +1060,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(String.format("`%s`.`%s`", NAMESPACE, functionName));
   }
 
-  @TestTemplate
+  @Test
   public void createViewUsingNonExistingTable() {
     assertThatThrownBy(
             () -> sql("CREATE VIEW viewWithNonExistingTable AS SELECT id FROM non_existing"))
@@ -1067,7 +1068,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("The table or view `non_existing` cannot be found");
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithMismatchedColumnCounts() {
     String viewName = "viewWithMismatchedColumnCounts";
 
@@ -1090,7 +1091,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("Data columns: id, data");
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithColumnAliases() throws NoSuchTableException {
     insertRows(6);
     String viewName = "viewWithColumnAliases";
@@ -1126,7 +1127,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrder(row(1), row(2), row(3));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithDuplicateColumnNames() {
     assertThatThrownBy(
             () ->
@@ -1137,7 +1138,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("The column `new_id` already exists");
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithDuplicateQueryColumnNames() throws NoSuchTableException {
     insertRows(3);
     String viewName = "viewWithDuplicateQueryColumnNames";
@@ -1155,7 +1156,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactlyInAnyOrder(row(1, 1), row(2, 2), row(3, 3));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithCTE() throws NoSuchTableException {
     insertRows(10);
     String viewName = "simpleViewWithCTE";
@@ -1170,7 +1171,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SELECT * FROM %s", viewName)).hasSize(1).containsExactly(row(10, 1L));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithConflictingNamesForCTEAndTempView() throws NoSuchTableException {
     insertRows(10);
     String viewName = "viewWithConflictingNamesForCTEAndTempView";
@@ -1189,7 +1190,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SELECT * FROM %s", viewName)).hasSize(1).containsExactly(row(10, 1L));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithCTEReferencingTempView() {
     String viewName = "viewWithCTEReferencingTempView";
     String tempViewInCTE = "tempViewInCTE";
@@ -1209,7 +1210,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(tempViewInCTE);
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithCTEReferencingTempFunction() {
     String viewName = "viewWithCTEReferencingTempFunction";
     String functionName = "avg_function_in_cte";
@@ -1231,7 +1232,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(functionName);
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithNonExistingQueryColumn() {
     assertThatThrownBy(
             () ->
@@ -1243,7 +1244,7 @@ public class TestViews extends ExtensionsTestBase {
             "A column or function parameter with name `non_existing` cannot be resolved");
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithSubqueryExpressionUsingTempView() {
     String viewName = "viewWithSubqueryExpression";
     String tempView = "simpleTempView";
@@ -1260,7 +1261,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(tempView);
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithSubqueryExpressionUsingGlobalTempView() {
     String viewName = "simpleViewWithSubqueryExpression";
     String globalTempView = "simpleGlobalTempView";
@@ -1281,7 +1282,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(String.format("%s.%s", "global_temp", globalTempView));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithSubqueryExpressionUsingTempFunction() {
     String viewName = viewName("viewWithSubqueryExpression");
     String functionName = "avg_function_in_subquery";
@@ -1302,7 +1303,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining(functionName);
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithSubqueryExpressionInFilterThatIsRewritten()
       throws NoSuchTableException {
     insertRows(5);
@@ -1327,7 +1328,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row(5));
   }
 
-  @TestTemplate
+  @Test
   public void createViewWithSubqueryExpressionInQueryThatIsRewritten() throws NoSuchTableException {
     insertRows(3);
     String viewName = viewName("viewWithSubqueryExpression");
@@ -1352,7 +1353,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row(3), row(3), row(3));
   }
 
-  @TestTemplate
+  @Test
   public void describeView() {
     String viewName = "describeView";
 
@@ -1361,7 +1362,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsExactly(row("id", "int", ""), row("data", "string", ""));
   }
 
-  @TestTemplate
+  @Test
   public void describeExtendedView() {
     String viewName = "describeExtendedView";
     String sql = String.format("SELECT id, data FROM %s WHERE id <= 3", tableName);
@@ -1386,7 +1387,7 @@ public class TestViews extends ExtensionsTestBase {
                 ""));
   }
 
-  @TestTemplate
+  @Test
   public void showViewProperties() {
     String viewName = "showViewProps";
 
@@ -1397,7 +1398,7 @@ public class TestViews extends ExtensionsTestBase {
         .contains(row("key1", "val1"), row("key2", "val2"));
   }
 
-  @TestTemplate
+  @Test
   public void showViewPropertiesByKey() {
     String viewName = "showViewPropsByKey";
 
@@ -1416,7 +1417,7 @@ public class TestViews extends ExtensionsTestBase {
                     catalogName, NAMESPACE, viewName)));
   }
 
-  @TestTemplate
+  @Test
   public void showViews() throws NoSuchTableException {
     insertRows(6);
     String sql = String.format("SELECT * from %s", tableName);
@@ -1462,9 +1463,14 @@ public class TestViews extends ExtensionsTestBase {
         .contains(
             // spark stores temp views case-insensitive by default
             row("global_temp", "globalviewforlisting", true), tempView);
+
+    sql("USE spark_catalog");
+    assertThat(sql("SHOW VIEWS")).contains(tempView);
+
+    assertThat(sql("SHOW VIEWS IN default")).contains(tempView);
   }
 
-  @TestTemplate
+  @Test
   public void showViewsWithCurrentNamespace() {
     String namespaceOne = "show_views_ns1";
     String namespaceTwo = "show_views_ns2";
@@ -1495,7 +1501,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SHOW VIEWS LIKE 'viewTwo*'")).contains(v2).doesNotContain(v1);
   }
 
-  @TestTemplate
+  @Test
   public void showCreateSimpleView() {
     String viewName = "showCreateSimpleView";
     String sql = String.format("SELECT id, data FROM %s WHERE id <= 3", tableName);
@@ -1516,7 +1522,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SHOW CREATE TABLE %s", viewName)).containsExactly(row(expected));
   }
 
-  @TestTemplate
+  @Test
   public void showCreateComplexView() {
     String viewName = "showCreateComplexView";
     String sql = String.format("SELECT id, data FROM %s WHERE id <= 3", tableName);
@@ -1543,7 +1549,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(sql("SHOW CREATE TABLE %s", viewName)).containsExactly(row(expected));
   }
 
-  @TestTemplate
+  @Test
   public void alterViewSetProperties() {
     String viewName = "viewWithSetProperties";
 
@@ -1565,7 +1571,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsEntry("comment", "view comment");
   }
 
-  @TestTemplate
+  @Test
   public void alterViewSetReservedProperties() {
     String viewName = "viewWithSetReservedProperties";
 
@@ -1596,7 +1602,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("Cannot set reserved property: 'spark.query-column-names'");
   }
 
-  @TestTemplate
+  @Test
   public void alterViewUnsetProperties() {
     String viewName = "viewWithUnsetProperties";
     sql("CREATE VIEW %s AS SELECT id FROM %s WHERE id <= 3", viewName, tableName);
@@ -1617,7 +1623,7 @@ public class TestViews extends ExtensionsTestBase {
         .containsEntry("comment", "view comment");
   }
 
-  @TestTemplate
+  @Test
   public void alterViewUnsetUnknownProperty() {
     String viewName = "viewWithUnsetUnknownProp";
     sql("CREATE VIEW %s AS SELECT id FROM %s WHERE id <= 3", viewName, tableName);
@@ -1631,7 +1637,7 @@ public class TestViews extends ExtensionsTestBase {
             () -> sql("ALTER VIEW %s UNSET TBLPROPERTIES IF EXISTS ('unknown-key')", viewName));
   }
 
-  @TestTemplate
+  @Test
   public void alterViewUnsetReservedProperties() {
     String viewName = "viewWithUnsetReservedProperties";
 
@@ -1667,7 +1673,7 @@ public class TestViews extends ExtensionsTestBase {
         .hasMessageContaining("Cannot unset reserved property: 'spark.query-column-names'");
   }
 
-  @TestTemplate
+  @Test
   public void createOrReplaceViewWithColumnAliases() throws NoSuchTableException {
     insertRows(6);
     String viewName = viewName("viewWithColumnAliases");
@@ -1713,7 +1719,7 @@ public class TestViews extends ExtensionsTestBase {
     assertThat(second.doc()).isEqualTo("new ID");
   }
 
-  @TestTemplate
+  @Test
   public void alterViewIsNotSupported() throws NoSuchTableException {
     insertRows(6);
     String viewName = "alteredView";
@@ -1731,7 +1737,7 @@ public class TestViews extends ExtensionsTestBase {
             "ALTER VIEW <viewName> AS is not supported. Use CREATE OR REPLACE VIEW instead");
   }
 
-  @TestTemplate
+  @Test
   public void createOrReplaceViewKeepsViewHistory() {
     String viewName = viewName("viewWithHistoryAfterReplace");
     String sql = String.format("SELECT id, data FROM %s WHERE id <= 3", tableName);
@@ -1770,7 +1776,7 @@ public class TestViews extends ExtensionsTestBase {
                 .asStruct());
   }
 
-  @TestTemplate
+  @Test
   public void replacingTrinoViewShouldFail() {
     String viewName = viewName("trinoView");
     String sql = String.format("SELECT id FROM %s", tableName);
@@ -1793,7 +1799,7 @@ public class TestViews extends ExtensionsTestBase {
                 + "New dialects: [spark]");
   }
 
-  @TestTemplate
+  @Test
   public void replacingTrinoAndSparkViewShouldFail() {
     String viewName = viewName("trinoAndSparkView");
     String sql = String.format("SELECT id FROM %s", tableName);
@@ -1817,7 +1823,7 @@ public class TestViews extends ExtensionsTestBase {
                 + "New dialects: [spark]");
   }
 
-  @TestTemplate
+  @Test
   public void replacingViewWithDialectDropAllowed() {
     String viewName = viewName("trinoView");
     String sql = String.format("SELECT id FROM %s", tableName);
@@ -1866,6 +1872,93 @@ public class TestViews extends ExtensionsTestBase {
         .isEqualTo(ImmutableSQLViewRepresentation.builder().dialect("spark").sql(sql).build());
   }
 
+  @Test
+  public void createViewWithRecursiveCycle() {
+    String viewOne = viewName("viewOne");
+    String viewTwo = viewName("viewTwo");
+
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewOne, tableName);
+    // viewTwo points to viewOne
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewTwo, viewOne);
+
+    // viewOne points to viewTwo points to viewOne, creating a recursive cycle
+    String view1 = String.format("%s.%s.%s", catalogName, NAMESPACE, viewOne);
+    String view2 = String.format("%s.%s.%s", catalogName, NAMESPACE, viewTwo);
+    String cycle = String.format("%s -> %s -> %s", view1, view2, view1);
+    assertThatThrownBy(() -> sql("CREATE OR REPLACE VIEW %s AS SELECT * FROM %s", viewOne, view2))
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageStartingWith(
+            String.format("Recursive cycle in view detected: %s (cycle: %s)", view1, cycle));
+  }
+
+  @Test
+  public void createViewWithRecursiveCycleToV1View() {
+    String viewOne = viewName("view_one");
+    String viewTwo = viewName("view_two");
+
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewOne, tableName);
+    // viewTwo points to viewOne
+    sql("USE spark_catalog");
+    sql("CREATE VIEW %s AS SELECT * FROM %s.%s.%s", viewTwo, catalogName, NAMESPACE, viewOne);
+
+    sql("USE %s", catalogName);
+    // viewOne points to viewTwo points to viewOne, creating a recursive cycle
+    String view1 = String.format("%s.%s.%s", catalogName, NAMESPACE, viewOne);
+    String view2 = String.format("%s.%s.%s", "spark_catalog", NAMESPACE, viewTwo);
+    String cycle = String.format("%s -> %s -> %s", view1, view2, view1);
+    assertThatThrownBy(() -> sql("CREATE OR REPLACE VIEW %s AS SELECT * FROM %s", viewOne, view2))
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageStartingWith(
+            String.format("Recursive cycle in view detected: %s (cycle: %s)", view1, cycle));
+  }
+
+  @Test
+  public void createViewWithRecursiveCycleInCTE() {
+    String viewOne = viewName("viewOne");
+    String viewTwo = viewName("viewTwo");
+
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewOne, tableName);
+    // viewTwo points to viewOne
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewTwo, viewOne);
+
+    // CTE points to viewTwo
+    String sql =
+        String.format(
+            "WITH max_by_data AS (SELECT max(id) as max FROM %s) "
+                + "SELECT max, count(1) AS count FROM max_by_data GROUP BY max",
+            viewTwo);
+
+    // viewOne points to CTE, creating a recursive cycle
+    String view1 = String.format("%s.%s.%s", catalogName, NAMESPACE, viewOne);
+    String cycle = String.format("%s -> %s -> %s", view1, viewTwo, view1);
+    assertThatThrownBy(() -> sql("CREATE OR REPLACE VIEW %s AS %s", viewOne, sql))
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageStartingWith(
+            String.format("Recursive cycle in view detected: %s (cycle: %s)", view1, cycle));
+  }
+
+  @Test
+  public void createViewWithRecursiveCycleInSubqueryExpression() {
+    String viewOne = viewName("viewOne");
+    String viewTwo = viewName("viewTwo");
+
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewOne, tableName);
+    // viewTwo points to viewOne
+    sql("CREATE VIEW %s AS SELECT * FROM %s", viewTwo, viewOne);
+
+    // subquery expression points to viewTwo
+    String sql =
+        String.format("SELECT * FROM %s WHERE id = (SELECT id FROM %s)", tableName, viewTwo);
+
+    // viewOne points to subquery expression, creating a recursive cycle
+    String view1 = String.format("%s.%s.%s", catalogName, NAMESPACE, viewOne);
+    String cycle = String.format("%s -> %s -> %s", view1, viewTwo, view1);
+    assertThatThrownBy(() -> sql("CREATE OR REPLACE VIEW %s AS %s", viewOne, sql))
+        .isInstanceOf(AnalysisException.class)
+        .hasMessageStartingWith(
+            String.format("Recursive cycle in view detected: %s (cycle: %s)", view1, cycle));
+  }
+
   private void insertRows(int numRows) throws NoSuchTableException {
     List<SimpleRecord> records = Lists.newArrayListWithCapacity(numRows);
     for (int i = 1; i <= numRows; i++) {
