@@ -182,7 +182,7 @@ public class SparkTableUtil {
       Option<scala.collection.immutable.Map<String, String>> scalaPartitionFilter;
       if (partitionFilter != null && !partitionFilter.isEmpty()) {
         Builder<Tuple2<String, String>, scala.collection.immutable.Map<String, String>> builder =
-            Map$.MODULE$.<String, String>newBuilder();
+            Map$.MODULE$.newBuilder();
         partitionFilter.forEach((key, value) -> builder.$plus$eq(Tuple2.apply(key, value)));
         scalaPartitionFilter = Option.apply(builder.result());
       } else {
@@ -272,44 +272,7 @@ public class SparkTableUtil {
     }
   }
 
-  /**
-   * Returns the data files in a partition by listing the partition location.
-   *
-   * <p>For Parquet and ORC partitions, this will read metrics from the file footer. For Avro
-   * partitions, metrics are set to null.
-   *
-   * @param partition a partition
-   * @param conf a serializable Hadoop conf
-   * @param metricsConfig a metrics conf
-   * @return a List of DataFile
-   * @deprecated use {@link TableMigrationUtil#listPartition(Map, String, String, PartitionSpec,
-   *     Configuration, MetricsConfig, NameMapping)}
-   */
-  @Deprecated
-  public static List<DataFile> listPartition(
-      SparkPartition partition,
-      PartitionSpec spec,
-      SerializableConfiguration conf,
-      MetricsConfig metricsConfig) {
-    return listPartition(partition, spec, conf, metricsConfig, null);
-  }
-
-  /**
-   * Returns the data files in a partition by listing the partition location.
-   *
-   * <p>For Parquet and ORC partitions, this will read metrics from the file footer. For Avro
-   * partitions, metrics are set to null.
-   *
-   * @param partition a partition
-   * @param conf a serializable Hadoop conf
-   * @param metricsConfig a metrics conf
-   * @param mapping a name mapping
-   * @return a List of DataFile
-   * @deprecated use {@link TableMigrationUtil#listPartition(Map, String, String, PartitionSpec,
-   *     Configuration, MetricsConfig, NameMapping)}
-   */
-  @Deprecated
-  public static List<DataFile> listPartition(
+  private static List<DataFile> listPartition(
       SparkPartition partition,
       PartitionSpec spec,
       SerializableConfiguration conf,
@@ -694,18 +657,6 @@ public class SparkTableUtil {
         .run(item -> io.deleteFile(item.path()));
   }
 
-  /**
-   * Loads a metadata table.
-   *
-   * @deprecated since 0.14.0, will be removed in 0.15.0; use {@link
-   *     #loadMetadataTable(SparkSession, Table, MetadataTableType)}.
-   */
-  @Deprecated
-  public static Dataset<Row> loadCatalogMetadataTable(
-      SparkSession spark, Table table, MetadataTableType type) {
-    return loadMetadataTable(spark, table, type);
-  }
-
   public static Dataset<Row> loadMetadataTable(
       SparkSession spark, Table table, MetadataTableType type) {
     return loadMetadataTable(spark, table, type, ImmutableMap.of());
@@ -754,7 +705,7 @@ public class SparkTableUtil {
     return PropertyUtil.propertyAsBoolean(
         table.properties(),
         TableProperties.WRITE_AUDIT_PUBLISH_ENABLED,
-        Boolean.getBoolean(TableProperties.WRITE_AUDIT_PUBLISH_ENABLED_DEFAULT));
+        Boolean.parseBoolean(TableProperties.WRITE_AUDIT_PUBLISH_ENABLED_DEFAULT));
   }
 
   /** Class representing a table partition. */
