@@ -56,8 +56,8 @@ public class MigrateTableSparkAction extends BaseTableCreationSparkAction<Migrat
 
   private final StagingTableCatalog destCatalog;
   private final Identifier destTableIdent;
-  private final Identifier backupIdent;
 
+  private Identifier backupIdent;
   private boolean dropBackup = false;
 
   MigrateTableSparkAction(
@@ -102,6 +102,12 @@ public class MigrateTableSparkAction extends BaseTableCreationSparkAction<Migrat
     return this;
   }
 
+  @Override
+  public MigrateTableSparkAction backupTableName(String tableName) {
+    this.backupIdent = Identifier.of(sourceTableIdent().namespace(), tableName);
+    return this;
+  }
+
   @Override
   public MigrateTable.Result execute() {
     String desc = String.format("Migrating table %s", destTableIdent().toString());
