@@ -18,10 +18,6 @@
  */
 package org.apache.iceberg.spark.source;
 
-import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.assertThatThrownBy;
-
-import java.io.File;
 import java.io.IOException;
 import java.util.Comparator;
 import java.util.List;
@@ -37,9 +33,6 @@ import org.apache.iceberg.Files;
 import org.apache.iceberg.MetadataColumns;
 import org.apache.iceberg.MetadataTableType;
 import org.apache.iceberg.MetadataTableUtils;
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.ParameterizedTestExtension;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.PartitionField;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Partitioning;
@@ -61,11 +54,12 @@ import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableSet;
+import org.apache.iceberg.relocated.com.google.common.collect.Iterables;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
-import org.apache.iceberg.spark.CatalogTestBase;
 import org.apache.iceberg.spark.PositionDeletesRewriteCoordinator;
 import org.apache.iceberg.spark.ScanTaskSetManager;
 import org.apache.iceberg.spark.SparkCatalogConfig;
+import org.apache.iceberg.spark.SparkCatalogTestBase;
 import org.apache.iceberg.spark.SparkReadOptions;
 import org.apache.iceberg.spark.SparkStructLike;
 import org.apache.iceberg.spark.SparkWriteOptions;
@@ -79,11 +73,15 @@ import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
 import org.apache.spark.sql.functions;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.Assert;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TemporaryFolder;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
 
-@ExtendWith(ParameterizedTestExtension.class)
-public class TestPositionDeletesTable extends CatalogTestBase {
+@RunWith(Parameterized.class)
+public class TestPositionDeletesTable extends SparkCatalogTestBase {
 
   public static final Schema SCHEMA =
       new Schema(
@@ -97,10 +95,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
   private static final List<String> NON_PATH_COLS =
       ImmutableList.of("file_path", "pos", "row", "partition", "spec_id");
 
-  @Parameter(index = 3)
-  private FileFormat format;
+  private final FileFormat format;
 
-  @Parameters(name = "catalogName = {1}, implementation = {2}, config = {3}, fileFormat = {4}")
+  @Parameterized.Parameters(
+      name =
+          "formatVersion = {0}, catalogName = {1}, implementation = {2}, config = {3}, fileFormat = {4}")
   public static Object[][] parameters() {
     return new Object[][] {
       {
@@ -124,7 +123,15 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     };
   }
 
-  @TestTemplate
+  public TestPositionDeletesTable(
+      String catalogName, String implementation, Map<String, String> config, FileFormat format) {
+    super(catalogName, implementation, config);
+    this.format = format;
+  }
+
+  @Rule public TemporaryFolder temp = new TemporaryFolder();
+
+  @Test
   public void testNullRows() throws IOException {
     String tableName = "null_rows";
     Table tab = createTable(tableName, SCHEMA, PartitionSpec.unpartitioned());
@@ -137,10 +144,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     deletes.add(Pair.of(dFile.path(), 1L));
     Pair<DeleteFile, CharSequenceSet> posDeletes =
         FileHelpers.writeDeleteFile(
-            tab,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-            TestHelpers.Row.of(0),
-            deletes);
+            tab, Files.localOutput(temp.newFile()), TestHelpers.Row.of(0), deletes);
     tab.newRowDelta().addDeletes(posDeletes.first()).commit();
 
     StructLikeSet actual = actual(tableName, tab);
@@ -150,11 +154,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expected =
         expected(tab, expectedDeletes, null, posDeletes.first().path().toString());
 
-    assertThat(actual).as("Position Delete table should contain expected rows").isEqualTo(expected);
+    Assert.assertEquals("Position Delete table should contain expected rows", expected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedTable() throws IOException {
     // Create table with two partitions
     String tableName = "partitioned_table";
@@ -179,11 +183,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expected =
         expected(tab, deletesB.first(), partitionB, deletesB.second().path().toString());
 
-    assertThat(actual).as("Position Delete table should contain expected rows").isEqualTo(expected);
+    Assert.assertEquals("Position Delete table should contain expected rows", expected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSelect() throws IOException {
     // Create table with two partitions
     String tableName = "select";
@@ -240,14 +244,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         };
     actual.sort(comp);
     expected.sort(comp);
-    assertThat(actual)
-        .as("Position Delete table should contain expected rows")
-        .usingRecursiveComparison()
-        .isEqualTo(expected);
+    assertEquals("Position Delete table should contain expected rows", expected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSplitTasks() throws IOException {
     String tableName = "big_table";
     Table tab = createTable(tableName, SCHEMA, PartitionSpec.unpartitioned());
@@ -262,7 +263,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     DataFile dFile =
         FileHelpers.writeDataFile(
             tab,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
+            Files.localOutput(temp.newFile()),
             org.apache.iceberg.TestHelpers.Row.of(),
             dataRecords);
     tab.newAppend().appendFile(dFile).commit();
@@ -273,33 +274,31 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     }
     DeleteFile posDeletes =
         FileHelpers.writePosDeleteFile(
-            tab,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-            TestHelpers.Row.of(0),
-            deletes);
+            tab, Files.localOutput(temp.newFile()), TestHelpers.Row.of(0), deletes);
     tab.newRowDelta().addDeletes(posDeletes).commit();
 
     Table deleteTable =
         MetadataTableUtils.createMetadataTableInstance(tab, MetadataTableType.POSITION_DELETES);
 
     if (format.equals(FileFormat.AVRO)) {
-      assertThat(deleteTable.newBatchScan().planTasks())
-          .as("Position delete scan should produce more than one split")
-          .hasSizeGreaterThan(1);
+      Assert.assertTrue(
+          "Position delete scan should produce more than one split",
+          Iterables.size(deleteTable.newBatchScan().planTasks()) > 1);
     } else {
-      assertThat(deleteTable.newBatchScan().planTasks())
-          .as("Position delete scan should produce one split")
-          .hasSize(1);
+      Assert.assertEquals(
+          "Position delete scan should produce one split",
+          1,
+          Iterables.size(deleteTable.newBatchScan().planTasks()));
     }
 
     StructLikeSet actual = actual(tableName, tab);
     StructLikeSet expected = expected(tab, deletes, null, posDeletes.path().toString());
 
-    assertThat(actual).as("Position Delete table should contain expected rows").isEqualTo(expected);
+    Assert.assertEquals("Position Delete table should contain expected rows", expected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionFilter() throws IOException {
     // Create table with two partitions
     String tableName = "partition_filter";
@@ -332,20 +331,16 @@ public class TestPositionDeletesTable extends CatalogTestBase {
 
     // Select deletes from all partitions
     StructLikeSet actual = actual(tableName, tab);
-    assertThat(actual)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(allExpected);
+    Assert.assertEquals("Position Delete table should contain expected rows", allExpected, actual);
 
     // Select deletes from one partition
     StructLikeSet actual2 = actual(tableName, tab, "partition.data = 'a' AND pos >= 0");
 
-    assertThat(actual2)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actual2);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionTransformFilter() throws IOException {
     // Create table with two partitions
     String tableName = "partition_filter";
@@ -379,20 +374,16 @@ public class TestPositionDeletesTable extends CatalogTestBase {
 
     // Select deletes from all partitions
     StructLikeSet actual = actual(tableName, tab);
-    assertThat(actual)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(allExpected);
+    Assert.assertEquals("Position Delete table should contain expected rows", allExpected, actual);
 
     // Select deletes from one partition
     StructLikeSet actual2 = actual(tableName, tab, "partition.data_trunc = 'a' AND pos >= 0");
 
-    assertThat(actual2)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actual2);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionEvolutionReplace() throws Exception {
     // Create table with spec (data)
     String tableName = "partition_evolution";
@@ -426,9 +417,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expectedA =
         expected(tab, deletesA.first(), partitionA, dataSpec, deletesA.second().path().toString());
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a' AND pos >= 0");
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // Query partition of new spec
     Record partition10 = partitionRecordTemplate.copy("id", 10);
@@ -441,13 +430,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
             deletes10.second().path().toString());
     StructLikeSet actual10 = actual(tableName, tab, "partition.id = 10 AND pos >= 0");
 
-    assertThat(actual10)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expected10);
+    Assert.assertEquals("Position Delete table should contain expected rows", expected10, actual10);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionEvolutionAdd() throws Exception {
     // Create unpartitioned table
     String tableName = "partition_evolution_add";
@@ -480,9 +467,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expectedA =
         expected(tab, deletesA.first(), partitionA, specId1, deletesA.second().path().toString());
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a' AND pos >= 0");
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // Select deletes from 'unpartitioned' data
     Record unpartitionedRecord = partitionRecordTemplate.copy("data", null);
@@ -496,13 +481,14 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet actualUnpartitioned =
         actual(tableName, tab, "partition.data IS NULL and pos >= 0");
 
-    assertThat(actualUnpartitioned)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedUnpartitioned);
+    Assert.assertEquals(
+        "Position Delete table should contain expected rows",
+        expectedUnpartitioned,
+        actualUnpartitioned);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionEvolutionRemove() throws Exception {
     // Create table with spec (data)
     String tableName = "partition_evolution_remove";
@@ -536,9 +522,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expectedA =
         expected(tab, deletesA.first(), partitionA, specId0, deletesA.second().path().toString());
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a' AND pos >= 0");
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // Select deletes from 'unpartitioned' spec
     Record unpartitionedRecord = partitionRecordTemplate.copy("data", null);
@@ -552,13 +536,14 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet actualUnpartitioned =
         actual(tableName, tab, "partition.data IS NULL and pos >= 0");
 
-    assertThat(actualUnpartitioned)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedUnpartitioned);
+    Assert.assertEquals(
+        "Position Delete table should contain expected rows",
+        expectedUnpartitioned,
+        actualUnpartitioned);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSpecIdFilter() throws Exception {
     // Create table with spec (data)
     String tableName = "spec_id_filter";
@@ -595,9 +580,10 @@ public class TestPositionDeletesTable extends CatalogTestBase {
             deletesUnpartitioned.second().path().toString());
     StructLikeSet actualUnpartitioned =
         actual(tableName, tab, String.format("spec_id = %d", unpartitionedSpec));
-    assertThat(actualUnpartitioned)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedUnpartitioned);
+    Assert.assertEquals(
+        "Position Delete table should contain expected rows",
+        expectedUnpartitioned,
+        actualUnpartitioned);
 
     // Select deletes from 'data' partition spec
     StructLike partitionA = partitionRecordTemplate.copy("data", "a");
@@ -608,11 +594,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         expected(tab, deletesB.first(), partitionB, dataSpec, deletesB.second().path().toString()));
 
     StructLikeSet actual = actual(tableName, tab, String.format("spec_id = %d", dataSpec));
-    assertThat(actual).as("Position Delete table should contain expected rows").isEqualTo(expected);
+    Assert.assertEquals("Position Delete table should contain expected rows", expected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSchemaEvolutionAdd() throws Exception {
     // Create table with original schema
     String tableName = "schema_evolution_add";
@@ -661,9 +647,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expectedA =
         expected(tab, expectedDeletesA, partitionA, deletesA.second().path().toString());
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a' AND pos >= 0");
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // Select deletes from new schema
     Record partitionC = partitionRecordTemplate.copy("data", "c");
@@ -671,13 +655,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         expected(tab, deletesC.first(), partitionC, deletesC.second().path().toString());
     StructLikeSet actualC = actual(tableName, tab, "partition.data = 'c' and pos >= 0");
 
-    assertThat(actualC)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedC);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedC, actualC);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testSchemaEvolutionRemove() throws Exception {
     // Create table with original schema
     String tableName = "schema_evolution_remove";
@@ -727,9 +709,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expectedA =
         expected(tab, expectedDeletesA, partitionA, deletesA.second().path().toString());
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a' AND pos >= 0");
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // Select deletes from new schema
     Record partitionC = partitionRecordTemplate.copy("data", "c");
@@ -737,13 +717,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         expected(tab, deletesC.first(), partitionC, deletesC.second().path().toString());
     StructLikeSet actualC = actual(tableName, tab, "partition.data = 'c' and pos >= 0");
 
-    assertThat(actualC)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedC);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedC, actualC);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWrite() throws IOException, NoSuchTableException {
     String tableName = "test_write";
     PartitionSpec spec = PartitionSpec.builderFor(SCHEMA).identity("data").build();
@@ -775,7 +753,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
                 .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
                 .load(posDeletesTableName);
 
-        assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+        Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
         scanDF
             .writeTo(posDeletesTableName)
             .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -801,13 +779,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
 
     // Compare values without 'delete_file_path' as these have been rewritten
     StructLikeSet actual = actual(tableName, tab, null, NON_PATH_COLS);
-    assertThat(actual)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(allExpected);
+    Assert.assertEquals("Position Delete table should contain expected rows", allExpected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWriteUnpartitionedNullRows() throws Exception {
     String tableName = "write_null_rows";
     Table tab = createTable(tableName, SCHEMA, PartitionSpec.unpartitioned());
@@ -820,10 +796,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     deletes.add(Pair.of(dFile.path(), 1L));
     Pair<DeleteFile, CharSequenceSet> posDeletes =
         FileHelpers.writeDeleteFile(
-            tab,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-            TestHelpers.Row.of(0),
-            deletes);
+            tab, Files.localOutput(temp.newFile()), TestHelpers.Row.of(0), deletes);
     tab.newRowDelta().addDeletes(posDeletes.first()).commit();
 
     Table posDeletesTable =
@@ -840,7 +813,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
               .option(SparkReadOptions.SCAN_TASK_SET_ID, fileSetID)
               .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
               .load(posDeletesTableName);
-      assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+      Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
       scanDF
           .writeTo(posDeletesTableName)
           .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -857,11 +830,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         Lists.newArrayList(positionDelete(dFile.path(), 0L), positionDelete(dFile.path(), 1L));
     StructLikeSet expected = expected(tab, expectedDeletes, null, null);
 
-    assertThat(actual).as("Position Delete table should contain expected rows").isEqualTo(expected);
+    Assert.assertEquals("Position Delete table should contain expected rows", expected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWriteMixedRows() throws Exception {
     String tableName = "write_mixed_rows";
     PartitionSpec spec = PartitionSpec.builderFor(SCHEMA).identity("data").build();
@@ -877,10 +850,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     deletes.add(Pair.of(dataFileA.path(), 1L));
     Pair<DeleteFile, CharSequenceSet> deletesWithoutRow =
         FileHelpers.writeDeleteFile(
-            tab,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-            TestHelpers.Row.of("a"),
-            deletes);
+            tab, Files.localOutput(temp.newFile()), TestHelpers.Row.of("a"), deletes);
 
     Pair<List<PositionDelete<?>>, DeleteFile> deletesWithRow = deleteFile(tab, dataFileB, "b");
 
@@ -904,7 +874,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
                 .format("iceberg")
                 .option(SparkReadOptions.SCAN_TASK_SET_ID, fileSetID)
                 .load(posDeletesTableName);
-        assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+        Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
         scanDF
             .writeTo(posDeletesTableName)
             .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -940,13 +910,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
             null));
     allExpected.addAll(expected(tab, deletesWithRow.first(), partitionB, null));
 
-    assertThat(actual)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(allExpected);
+    Assert.assertEquals("Position Delete table should contain expected rows", allExpected, actual);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWritePartitionEvolutionAdd() throws Exception {
     // Create unpartitioned table
     String tableName = "write_partition_evolution_add";
@@ -990,7 +958,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
               .option(SparkReadOptions.SCAN_TASK_SET_ID, fileSetID)
               .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
               .load(posDeletesTableName);
-      assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+      Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
       scanDF
           .writeTo(posDeletesTableName)
           .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -1007,9 +975,10 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         expected(tab, deletesUnpartitioned.first(), unpartitionedRecord, specId0, null);
     StructLikeSet actualUnpartitioned =
         actual(tableName, tab, "partition.data IS NULL", NON_PATH_COLS);
-    assertThat(actualUnpartitioned)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedUnpartitioned);
+    Assert.assertEquals(
+        "Position Delete table should contain expected rows",
+        expectedUnpartitioned,
+        actualUnpartitioned);
 
     // Read/write back new partition spec (data)
     for (String partValue : ImmutableList.of("a", "b")) {
@@ -1024,7 +993,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
                 .option(SparkReadOptions.SCAN_TASK_SET_ID, fileSetID)
                 .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
                 .load(posDeletesTableName);
-        assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+        Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
         scanDF
             .writeTo(posDeletesTableName)
             .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -1047,13 +1016,13 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     expectedAll.addAll(expected(tab, deletesB.first(), partitionB, specId1, null));
     StructLikeSet actualAll =
         actual(tableName, tab, "partition.data = 'a' OR partition.data = 'b'", NON_PATH_COLS);
-    assertThat(actualAll)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedAll);
+    Assert.assertEquals(
+        "Position Delete table should contain expected rows", expectedAll, actualAll);
+
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWritePartitionEvolutionDisallowed() throws Exception {
     // Create unpartitioned table
     String tableName = "write_partition_evolution_write";
@@ -1082,31 +1051,24 @@ public class TestPositionDeletesTable extends CatalogTestBase {
               .option(SparkReadOptions.SCAN_TASK_SET_ID, fileSetID)
               .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
               .load(posDeletesTableName);
-      assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+      Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
 
       // Add partition field to render the original un-partitioned dataset un-commitable
       tab.updateSpec().addField("data").commit();
     }
 
-    assertThatThrownBy(
-            () ->
-                scanDF
-                    .writeTo(posDeletesTableName)
-                    .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
-                    .append())
-        .isInstanceOf(AnalysisException.class)
-        .hasMessage(
-            "[INCOMPATIBLE_DATA_FOR_TABLE.CANNOT_FIND_DATA] Cannot write incompatible data for the table `"
-                + catalogName
-                + "`.`default`.`"
-                + tableName
-                + "`.`position_deletes`"
-                + ": Cannot find data for the output column `partition`.");
+    Assert.assertThrows(
+        AnalysisException.class,
+        () ->
+            scanDF
+                .writeTo(posDeletesTableName)
+                .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
+                .append());
 
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWriteSchemaEvolutionAdd() throws Exception {
     // Create table with original schema
     String tableName = "write_schema_evolution_add";
@@ -1154,7 +1116,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
               .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
               .load(posDeletesTableName);
 
-      assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+      Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
       scanDF
           .writeTo(posDeletesTableName)
           .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -1180,9 +1142,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         });
     StructLikeSet expectedA = expected(tab, expectedDeletesA, partitionA, null);
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a'", NON_PATH_COLS);
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // rewrite files of new schema
     try (CloseableIterable<ScanTask> tasks = tasks(posDeletesTable, "data", "c")) {
@@ -1197,7 +1157,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
               .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
               .load(posDeletesTableName);
 
-      assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+      Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
       scanDF
           .writeTo(posDeletesTableName)
           .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -1211,13 +1171,11 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     StructLikeSet expectedC = expected(tab, deletesC.first(), partitionC, null);
     StructLikeSet actualC = actual(tableName, tab, "partition.data = 'c'", NON_PATH_COLS);
 
-    assertThat(actualC)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedC);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedC, actualC);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testWriteSchemaEvolutionRemove() throws Exception {
     // Create table with original schema
     String tableName = "write_schema_evolution_remove";
@@ -1268,7 +1226,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
                 .option(SparkReadOptions.SCAN_TASK_SET_ID, fileSetID)
                 .option(SparkReadOptions.FILE_OPEN_COST, Integer.MAX_VALUE)
                 .load(posDeletesTableName);
-        assertThat(scanDF.javaRDD().getNumPartitions()).isEqualTo(1);
+        Assert.assertEquals(1, scanDF.javaRDD().getNumPartitions());
         scanDF
             .writeTo(posDeletesTableName)
             .option(SparkWriteOptions.REWRITTEN_FILE_SCAN_TASK_SET_ID, fileSetID)
@@ -1293,22 +1251,18 @@ public class TestPositionDeletesTable extends CatalogTestBase {
         });
     StructLikeSet expectedA = expected(tab, expectedDeletesA, partitionA, null);
     StructLikeSet actualA = actual(tableName, tab, "partition.data = 'a'", NON_PATH_COLS);
-    assertThat(actualA)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedA);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedA, actualA);
 
     // Select deletes from new schema
     Record partitionC = partitionRecordTemplate.copy("data", "c");
     StructLikeSet expectedC = expected(tab, deletesC.first(), partitionC, null);
     StructLikeSet actualC = actual(tableName, tab, "partition.data = 'c'", NON_PATH_COLS);
 
-    assertThat(actualC)
-        .as("Position Delete table should contain expected rows")
-        .isEqualTo(expectedC);
+    Assert.assertEquals("Position Delete table should contain expected rows", expectedC, actualC);
     dropTable(tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testNormalWritesNotAllowed() throws IOException {
     String tableName = "test_normal_write_not_allowed";
     PartitionSpec spec = PartitionSpec.builderFor(SCHEMA).identity("data").build();
@@ -1324,9 +1278,10 @@ public class TestPositionDeletesTable extends CatalogTestBase {
 
     Dataset<Row> scanDF = spark.read().format("iceberg").load(posDeletesTableName);
 
-    assertThatThrownBy(() -> scanDF.writeTo(posDeletesTableName).append())
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Can only write to " + posDeletesTableName + " via actions");
+    Assert.assertThrows(
+        "position_deletes table can only be written by RewriteDeleteFiles",
+        IllegalArgumentException.class,
+        () -> scanDF.writeTo(posDeletesTableName).append());
 
     dropTable(tableName);
   }
@@ -1502,10 +1457,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
 
     TestHelpers.Row partitionInfo = TestHelpers.Row.of(partFieldValues);
     return FileHelpers.writeDataFile(
-        tab,
-        Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-        partitionInfo,
-        records);
+        tab, Files.localOutput(temp.newFile()), partitionInfo, records);
   }
 
   private Pair<List<PositionDelete<?>>, DeleteFile> deleteFile(
@@ -1553,10 +1505,7 @@ public class TestPositionDeletesTable extends CatalogTestBase {
 
     DeleteFile deleteFile =
         FileHelpers.writePosDeleteFile(
-            tab,
-            Files.localOutput(File.createTempFile("junit", null, temp.toFile())),
-            partitionInfo,
-            deletes);
+            tab, Files.localOutput(temp.newFile()), partitionInfo, deletes);
     return Pair.of(deletes, deleteFile);
   }
 
@@ -1580,16 +1529,14 @@ public class TestPositionDeletesTable extends CatalogTestBase {
     Set<DeleteFile> addedFiles = rewriteCoordinator.fetchNewFiles(posDeletesTable, fileSetID);
 
     // Assert new files and old files are equal in number but different in paths
-    assertThat(rewrittenFiles).hasSize(expectedSourceFiles);
-    assertThat(addedFiles).hasSize(expectedTargetFiles);
+    Assert.assertEquals(expectedSourceFiles, rewrittenFiles.size());
+    Assert.assertEquals(expectedTargetFiles, addedFiles.size());
 
     List<String> sortedAddedFiles =
         addedFiles.stream().map(f -> f.path().toString()).sorted().collect(Collectors.toList());
     List<String> sortedRewrittenFiles =
         rewrittenFiles.stream().map(f -> f.path().toString()).sorted().collect(Collectors.toList());
-    assertThat(sortedRewrittenFiles)
-        .as("Lists should not be the same")
-        .isNotEqualTo(sortedAddedFiles);
+    Assert.assertNotEquals("Lists should not be the same", sortedAddedFiles, sortedRewrittenFiles);
 
     baseTab
         .newRewrite()
