@@ -28,15 +28,11 @@ import static org.apache.spark.sql.functions.date_add;
 import static org.apache.spark.sql.functions.expr;
 import static org.assertj.core.api.Assertions.assertThat;
 
-import org.apache.iceberg.Parameter;
-import org.apache.iceberg.ParameterizedTestExtension;
-import org.apache.iceberg.Parameters;
 import org.apache.iceberg.Table;
 import org.apache.iceberg.TableProperties;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.spark.Spark3Util;
-import org.apache.iceberg.spark.SparkCatalogConfig;
-import org.apache.iceberg.spark.TestBaseWithCatalog;
+import org.apache.iceberg.spark.SparkTestBaseWithCatalog;
 import org.apache.iceberg.spark.functions.BucketFunction;
 import org.apache.iceberg.spark.functions.DaysFunction;
 import org.apache.iceberg.spark.functions.HoursFunction;
@@ -62,52 +58,38 @@ import org.apache.spark.sql.connector.read.Statistics;
 import org.apache.spark.sql.connector.read.SupportsPushDownV2Filters;
 import org.apache.spark.sql.types.DataTypes;
 import org.apache.spark.sql.util.CaseInsensitiveStringMap;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestTemplate;
-import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.After;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.Parameterized;
 
-@ExtendWith(ParameterizedTestExtension.class)
-public class TestSparkScan extends TestBaseWithCatalog {
+@RunWith(Parameterized.class)
+public class TestSparkScan extends SparkTestBaseWithCatalog {
 
-  @Parameter(index = 3)
-  private String format;
+  private final String format;
 
-  @Parameters(name = "catalogName = {0}, implementation = {1}, config = {2}, format = {3}")
-  public static Object[][] parameters() {
-    return new Object[][] {
-      {
-        SparkCatalogConfig.HADOOP.catalogName(),
-        SparkCatalogConfig.HADOOP.implementation(),
-        SparkCatalogConfig.HADOOP.properties(),
-        "parquet"
-      },
-      {
-        SparkCatalogConfig.HADOOP.catalogName(),
-        SparkCatalogConfig.HADOOP.implementation(),
-        SparkCatalogConfig.HADOOP.properties(),
-        "avro"
-      },
-      {
-        SparkCatalogConfig.HADOOP.catalogName(),
-        SparkCatalogConfig.HADOOP.implementation(),
-        SparkCatalogConfig.HADOOP.properties(),
-        "orc"
-      }
-    };
+  @Parameterized.Parameters(name = "format = {0}")
+  public static Object[] parameters() {
+    return new Object[] {"parquet", "avro", "orc"};
   }
 
-  @BeforeEach
+  public TestSparkScan(String format) {
+    this.format = format;
+  }
+
+  @Before
   public void useCatalog() {
     sql("USE %s", catalogName);
   }
 
-  @AfterEach
+  @After
   public void removeTables() {
     sql("DROP TABLE IF EXISTS %s", tableName);
   }
 
-  @TestTemplate
+  @Test
   public void testEstimatedRowCount() throws NoSuchTableException {
     sql(
         "CREATE TABLE %s (id BIGINT, date DATE) USING iceberg TBLPROPERTIES('%s' = '%s')",
@@ -127,10 +109,10 @@ public class TestSparkScan extends TestBaseWithCatalog {
     SparkScan scan = (SparkScan) scanBuilder.build();
     Statistics stats = scan.estimateStatistics();
 
-    assertThat(stats.numRows().getAsLong()).isEqualTo(10000L);
+    Assert.assertEquals(10000L, stats.numRows().getAsLong());
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedYears() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -158,7 +140,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedYears() throws Exception {
     createPartitionedTable(spark, tableName, "years(ts)");
 
@@ -186,7 +168,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(5);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedMonths() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -215,7 +197,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedMonths() throws Exception {
     createPartitionedTable(spark, tableName, "months(ts)");
 
@@ -244,7 +226,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(5);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedDays() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -272,7 +254,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedDays() throws Exception {
     createPartitionedTable(spark, tableName, "days(ts)");
 
@@ -300,7 +282,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(5);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedHours() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -328,7 +310,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedHours() throws Exception {
     createPartitionedTable(spark, tableName, "hours(ts)");
 
@@ -356,7 +338,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(2);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedBucketLong() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -380,7 +362,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedBucketLong() throws Exception {
     createPartitionedTable(spark, tableName, "bucket(5, id)");
 
@@ -404,7 +386,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(4);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedBucketString() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -428,7 +410,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedBucketString() throws Exception {
     createPartitionedTable(spark, tableName, "bucket(5, data)");
 
@@ -452,7 +434,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(4);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedTruncateString() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -476,7 +458,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedTruncateString() throws Exception {
     createPartitionedTable(spark, tableName, "truncate(4, data)");
 
@@ -500,7 +482,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(5);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedIsNull() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -524,7 +506,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedIsNull() throws Exception {
     createPartitionedTable(spark, tableName, "truncate(4, data)");
 
@@ -548,7 +530,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedIsNotNull() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -572,7 +554,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedIsNotNull() throws Exception {
     createPartitionedTable(spark, tableName, "truncate(4, data)");
 
@@ -596,7 +578,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(0);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedAnd() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -626,7 +608,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedAnd() throws Exception {
     createPartitionedTable(spark, tableName, "years(ts), bucket(5, id)");
 
@@ -656,7 +638,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(9);
   }
 
-  @TestTemplate
+  @Test
   public void testUnpartitionedOr() throws Exception {
     createUnpartitionedTable(spark, tableName);
 
@@ -686,7 +668,7 @@ public class TestSparkScan extends TestBaseWithCatalog {
     assertThat(scan.planInputPartitions().length).isEqualTo(10);
   }
 
-  @TestTemplate
+  @Test
   public void testPartitionedOr() throws Exception {
     createPartitionedTable(spark, tableName, "years(ts), bucket(5, id)");
 
